pub enum WordSchema {
Simple {
type: SchemaType,
default_value: Option<Word>,
},
Composite {
value: [FeltSchema; 4],
},
}Expand description
Defines how a word slot is described within the component’s storage schema.
Each word schema can either describe a whole-word typed value supplied at instantiation time
(Simple) or a composite word that explicitly defines each felt element (Composite).
Variants
Simple
A whole-word typed value supplied at instantiation time.
Composite
A composed word that may mix defaults and typed fields.
Fields
value: [FeltSchema; 4]Implementations
Sourceimpl WordSchema
impl WordSchema
pub fn new_simple(type: SchemaType) -> WordSchema
pub fn new_simple_with_default( type: SchemaType, default_value: Word, ) -> WordSchema
pub fn new_value(value: impl Into<[FeltSchema; 4]>) -> WordSchema
pub fn value(&self) -> Option<&[FeltSchema; 4]>
Sourcepub fn word_type(&self) -> SchemaType
pub fn word_type(&self) -> SchemaType
Returns the schema type associated with whole-word init-supplied values.