pub struct AccountProcedureRoot(/* private fields */);Expand description
The MAST root of a public procedure in an account’s interface.
Implementations
Sourceimpl AccountProcedureRoot
impl AccountProcedureRoot
Sourcepub fn from_raw(word: Word) -> AccountProcedureRoot
pub fn from_raw(word: Word) -> AccountProcedureRoot
Construct without further checks from a given Word.
Warning
This requires the caller to uphold the guarantees/invariants of this type (if any). Check the type-level documentation for guarantees/invariants.
Sourcepub fn as_elements(&self) -> &[Felt]
pub fn as_elements(&self) -> &[Felt]
Returns the elements representation of this value.
Sourceimpl AccountProcedureRoot
impl AccountProcedureRoot
Sourcepub const NUM_ELEMENTS: usize = 4
pub const NUM_ELEMENTS: usize = 4
The number of field elements that represent an AccountProcedureRoot in kernel memory.