pub struct AuthEcdsaK256KeccakMultisig { /* private fields */ }Expand description
An AccountComponent implementing a multisig based on ECDSA signatures.
It enforces a threshold of approver signatures for every transaction, with optional per-procedure thresholds overrides. Non-uniform thresholds (especially a threshold of one) should be used with caution for private multisig accounts, as a single approver could withhold the new state from other approvers, effectively locking them out.
The storage layout is:
- Slot 0(value): [threshold, num_approvers, 0, 0]
- Slot 1(map): A map with approver public keys (index -> pubkey)
- Slot 2(map): A map which stores executed transactions
- Slot 3(map): A map which stores procedure thresholds (PROC_ROOT -> threshold)
This component supports all account types.
Implementations
Sourceimpl AuthEcdsaK256KeccakMultisig
impl AuthEcdsaK256KeccakMultisig
Sourcepub fn new(
config: AuthEcdsaK256KeccakMultisigConfig,
) -> Result<AuthEcdsaK256KeccakMultisig, AccountError>
pub fn new( config: AuthEcdsaK256KeccakMultisigConfig, ) -> Result<AuthEcdsaK256KeccakMultisig, AccountError>
Creates a new AuthEcdsaK256KeccakMultisig component from the provided configuration.
Sourcepub fn threshold_config_slot() -> &'static StorageSlotName
pub fn threshold_config_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the threshold configuration is stored.
Sourcepub fn approver_public_keys_slot() -> &'static StorageSlotName
pub fn approver_public_keys_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the approver public keys are stored.
Sourcepub fn executed_transactions_slot() -> &'static StorageSlotName
pub fn executed_transactions_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the executed transactions are stored.
Sourcepub fn procedure_thresholds_slot() -> &'static StorageSlotName
pub fn procedure_thresholds_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the procedure thresholds are stored.