pub struct BasicFungibleFaucet { /* private fields */ }Expand description
An AccountComponent implementing a basic fungible faucet.
It reexports the procedures from miden::standards::faucets::basic_fungible. When linking
against this component, the miden library (i.e.
ProtocolLib) must be available to the assembler which is the
case when using CodeBuilder. The procedures of this component are:
mint_and_send, which mints an assets and create a note for the provided recipient.burn, which burns the provided asset.
The mint_and_send procedure can be called from a transaction script and requires
authentication via the authentication component. The burn procedure can only be called from a
note script and requires the calling note to contain the asset to be burned.
This component must be combined with an authentication component.
This component supports accounts of type AccountType::FungibleFaucet.
Storage Layout
Self::metadata_slot: StoresTokenMetadata.
Implementations
Sourceimpl BasicFungibleFaucet
impl BasicFungibleFaucet
Sourcepub const NAME: &'static str = "miden::standards::components::faucets::basic_fungible_faucet"
pub const NAME: &'static str = "miden::standards::components::faucets::basic_fungible_faucet"
The name of the component.
Sourcepub const MAX_DECIMALS: u8 = TokenMetadata::MAX_DECIMALS
pub const MAX_DECIMALS: u8 = TokenMetadata::MAX_DECIMALS
The maximum number of decimals supported by the component.
Sourcepub fn new(
symbol: TokenSymbol,
decimals: u8,
max_supply: Felt,
) -> Result<BasicFungibleFaucet, FungibleFaucetError>
pub fn new( symbol: TokenSymbol, decimals: u8, max_supply: Felt, ) -> Result<BasicFungibleFaucet, FungibleFaucetError>
Creates a new BasicFungibleFaucet component from the given pieces of metadata and with
an initial token supply of zero.
Errors
Returns an error if:
- the decimals parameter exceeds maximum value of
Self::MAX_DECIMALS. - the max supply parameter exceeds maximum possible amount for a fungible asset
(
miden_protocol::asset::FungibleAsset::MAX_AMOUNT)
Sourcepub fn from_metadata(metadata: TokenMetadata) -> BasicFungibleFaucet
pub fn from_metadata(metadata: TokenMetadata) -> BasicFungibleFaucet
Creates a new BasicFungibleFaucet component from the given TokenMetadata.
This is a convenience constructor that allows creating a faucet from pre-validated metadata.
Sourcepub fn metadata_slot() -> &'static StorageSlotName
pub fn metadata_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the BasicFungibleFaucet’s metadata is stored.
Sourcepub fn metadata_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn metadata_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the metadata slot.
Sourcepub fn metadata(&self) -> &TokenMetadata
pub fn metadata(&self) -> &TokenMetadata
Returns the token metadata.
Sourcepub fn symbol(&self) -> &TokenSymbol
pub fn symbol(&self) -> &TokenSymbol
Returns the symbol of the faucet.
Sourcepub fn max_supply(&self) -> Felt
pub fn max_supply(&self) -> Felt
Returns the max supply (in base units) of the faucet.
This is the highest amount of tokens that can be minted from this faucet.
Sourcepub fn token_supply(&self) -> Felt
pub fn token_supply(&self) -> Felt
Returns the token supply (in base units) of the faucet.
This is the amount of tokens that were minted from the faucet so far. Its value can never
exceed Self::max_supply.
Sourcepub fn mint_and_send_digest() -> Word
pub fn mint_and_send_digest() -> Word
Returns the digest of the mint_and_send account procedure.
Sourcepub fn burn_digest() -> Word
pub fn burn_digest() -> Word
Returns the digest of the burn account procedure.
Sourcepub fn component_metadata() -> AccountComponentMetadata
pub fn component_metadata() -> AccountComponentMetadata
Returns the AccountComponentMetadata for this component.
Sourcepub fn with_token_supply(
self,
token_supply: Felt,
) -> Result<BasicFungibleFaucet, FungibleFaucetError>
pub fn with_token_supply( self, token_supply: Felt, ) -> Result<BasicFungibleFaucet, FungibleFaucetError>
Sets the token_supply (in base units) of the basic fungible faucet.
Errors
Returns an error if:
- the token supply exceeds the max supply.