pub struct BasicWallet;Expand description
An AccountComponent implementing a basic wallet.
It reexports the procedures from miden::standards::wallets::basic. When linking against this
component, the miden library (i.e. ProtocolLib) must be
available to the assembler which is the case when using CodeBuilder. The procedures
of this component are:
receive_asset, which can be used to add an asset to the account.move_asset_to_note, which can be used to remove the specified asset from the account and add it to the output note with the specified index.
All methods require authentication. Thus, this component must be combined with a component providing authentication.
This component supports all account types.
Implementations
Sourceimpl BasicWallet
impl BasicWallet
Sourcepub fn receive_asset_digest() -> Word
pub fn receive_asset_digest() -> Word
Returns the digest of the receive_asset wallet procedure.
Sourcepub fn move_asset_to_note_digest() -> Word
pub fn move_asset_to_note_digest() -> Word
Returns the digest of the move_asset_to_note wallet procedure.