pub struct FeltSchema { /* private fields */ }Expand description
Supported element schema descriptors for a component’s storage entries.
Each felt element in a composed word slot is typed, can have an optional default value, and can optionally be named to allow overriding at instantiation time.
To avoid non-overridable constants, unnamed elements are allowed only when type = "void",
which always evaluates to 0 and does not require init data.
Implementations
Sourceimpl FeltSchema
impl FeltSchema
Sourcepub fn new_typed(type: SchemaType, name: impl Into<String>) -> FeltSchema
pub fn new_typed(type: SchemaType, name: impl Into<String>) -> FeltSchema
Creates a new required typed felt field.
Sourcepub fn new_typed_with_default(
type: SchemaType,
name: impl Into<String>,
default_value: Felt,
) -> FeltSchema
pub fn new_typed_with_default( type: SchemaType, name: impl Into<String>, default_value: Felt, ) -> FeltSchema
Creates a new typed felt field with a default value.
Sourcepub fn new_void() -> FeltSchema
pub fn new_void() -> FeltSchema
Creates an unnamed void felt element.
Sourcepub fn felt(name: impl Into<String>) -> FeltSchema
pub fn felt(name: impl Into<String>) -> FeltSchema
Creates a new required felt field typed as SchemaType::native_felt().
Sourcepub fn word(name: impl Into<String>) -> FeltSchema
pub fn word(name: impl Into<String>) -> FeltSchema
Creates a new required felt field typed as SchemaType::native_word().
Sourcepub fn u8(name: impl Into<String>) -> FeltSchema
pub fn u8(name: impl Into<String>) -> FeltSchema
Creates a new required felt field typed as SchemaType::u8().
Sourcepub fn u16(name: impl Into<String>) -> FeltSchema
pub fn u16(name: impl Into<String>) -> FeltSchema
Creates a new required felt field typed as SchemaType::u16().
Sourcepub fn u32(name: impl Into<String>) -> FeltSchema
pub fn u32(name: impl Into<String>) -> FeltSchema
Creates a new required felt field typed as SchemaType::u32().
Sourcepub fn bool(name: impl Into<String>) -> FeltSchema
pub fn bool(name: impl Into<String>) -> FeltSchema
Creates a new required felt field typed as SchemaType::bool().
Sourcepub fn with_default(self, default_value: Felt) -> FeltSchema
pub fn with_default(self, default_value: Felt) -> FeltSchema
Sets the default value of the FeltSchema and returns self.
Sourcepub fn with_description(self, description: impl Into<String>) -> FeltSchema
pub fn with_description(self, description: impl Into<String>) -> FeltSchema
Sets the description of the FeltSchema and returns self.
Sourcepub fn felt_type(&self) -> SchemaType
pub fn felt_type(&self) -> SchemaType
Returns the felt type.
pub fn name(&self) -> Option<&str>
pub fn description(&self) -> Option<&String>
pub fn default_value(&self) -> Option<Felt>