pub struct MinBurnAmount { /* private fields */ }Expand description
The min_burn_amount burn policy account component.
Pair with a crate::account::policies::TokenPolicyManager whose allowed burn-policies map
includes MinBurnAmount::root. When active, a burn is rejected unless its amount meets or
exceeds the configured minimum burn amount, which is stored in this component’s value slot
(MinBurnAmount::slot_name) and can be updated through the authority-gated
set_min_burn_amount procedure (authorized via the account-wide
Authority component).
Implementations
Sourceimpl MinBurnAmount
impl MinBurnAmount
Sourcepub const NAME: &'static str = "miden::standards::components::faucets::policies::burn::min_burn_amount"
pub const NAME: &'static str = "miden::standards::components::faucets::policies::burn::min_burn_amount"
The name of the component.
Sourcepub fn new(min_burn_amount: AssetAmount) -> MinBurnAmount
pub fn new(min_burn_amount: AssetAmount) -> MinBurnAmount
Creates a new min_burn_amount burn policy with the given initial minimum burn amount.
Sourcepub const fn name() -> AccountComponentName
pub const fn name() -> AccountComponentName
Returns the canonical AccountComponentName of this component.
Sourcepub fn code() -> &'static AccountComponentCode
pub fn code() -> &'static AccountComponentCode
Returns the AccountComponentCode of this component.
Sourcepub fn root() -> AccountProcedureRoot
pub fn root() -> AccountProcedureRoot
Returns the procedure root of the check_policy burn policy procedure.
Sourcepub fn set_min_burn_amount_root() -> AccountProcedureRoot
pub fn set_min_burn_amount_root() -> AccountProcedureRoot
Returns the procedure root of the set_min_burn_amount account procedure.
Sourcepub fn get_min_burn_amount_root() -> AccountProcedureRoot
pub fn get_min_burn_amount_root() -> AccountProcedureRoot
Returns the procedure root of the get_min_burn_amount account procedure.
Sourcepub fn slot_name() -> &'static StorageSlotName
pub fn slot_name() -> &'static StorageSlotName
Returns the StorageSlotName where the minimum burn amount is stored.
Sourcepub fn min_burn_amount(&self) -> AssetAmount
pub fn min_burn_amount(&self) -> AssetAmount
Returns the configured minimum burn amount.
Sourcepub fn slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the minimum burn amount slot.
Sourcepub fn component_metadata() -> AccountComponentMetadata
pub fn component_metadata() -> AccountComponentMetadata
Returns the AccountComponentMetadata for this component.