pub struct NetworkFungibleFaucet { /* private fields */ }Expand description
An AccountComponent implementing a network fungible faucet.
It reexports the procedures from miden::standards::faucets::network_fungible. When linking
against this component, the miden library (i.e.
ProtocolLib) must be available to the assembler which is the
case when using CodeBuilder. The procedures of this component are:
distribute, which mints an assets and create a note for the provided recipient.burn, which burns the provided asset.
Both distribute and burn can only be called from note scripts. distribute requires
authentication while burn does not require authentication and can be called by anyone.
Thus, this component must be combined with a component providing authentication.
Storage Layout
Self::metadata_slot: Fungible faucet metadata.Self::owner_config_slot: The owner account of this network faucet.
Implementations
Sourceimpl NetworkFungibleFaucet
impl NetworkFungibleFaucet
Sourcepub const MAX_DECIMALS: u8 = 12
pub const MAX_DECIMALS: u8 = 12
The maximum number of decimals supported by the component.
Sourcepub fn new(
symbol: TokenSymbol,
decimals: u8,
max_supply: BaseElement,
owner_account_id: AccountId,
) -> Result<NetworkFungibleFaucet, FungibleFaucetError>
pub fn new( symbol: TokenSymbol, decimals: u8, max_supply: BaseElement, owner_account_id: AccountId, ) -> Result<NetworkFungibleFaucet, FungibleFaucetError>
Creates a new NetworkFungibleFaucet component from the given pieces of metadata.
Errors:
Returns an error if:
- the decimals parameter exceeds maximum value of
Self::MAX_DECIMALS. - the max supply parameter exceeds maximum possible amount for a fungible asset
(
miden_protocol::asset::FungibleAsset::MAX_AMOUNT)
Sourcepub fn metadata_slot() -> &'static StorageSlotName
pub fn metadata_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the NetworkFungibleFaucet’s metadata is stored.
Sourcepub fn owner_config_slot() -> &'static StorageSlotName
pub fn owner_config_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the NetworkFungibleFaucet’s owner configuration is
stored.
Sourcepub fn symbol(&self) -> TokenSymbol
pub fn symbol(&self) -> TokenSymbol
Returns the symbol of the faucet.
Sourcepub fn max_supply(&self) -> BaseElement
pub fn max_supply(&self) -> BaseElement
Returns the max supply of the faucet.
Sourcepub fn owner_account_id(&self) -> AccountId
pub fn owner_account_id(&self) -> AccountId
Returns the owner account ID of the faucet.
Sourcepub fn distribute_digest() -> Word
pub fn distribute_digest() -> Word
Returns the digest of the distribute account procedure.
Sourcepub fn burn_digest() -> Word
pub fn burn_digest() -> Word
Returns the digest of the burn account procedure.