pub struct NoAuth;Expand description
An AccountComponent implementing a no-authentication scheme.
This component provides no authentication! It only checks if the account state has actually changed during transaction execution by comparing the initial account commitment with the current commitment and increments the nonce if they differ. This avoids unnecessary nonce increments for transactions that don’t modify the account state.
It exports the procedure auth_no_auth, which:
- Checks if the account state has changed by comparing initial and final commitments
- Only increments the nonce if the account state has actually changed
- Provides no cryptographic authentication
This component supports all account types.
Implementations