pub struct SchemaType(/* private fields */);Expand description
A newtype wrapper around a String, representing a schema type.
A valid schema type is a name in the style of Rust namespaces, composed of one or more
non-empty segments separated by ::. Each segment can contain only ASCII alphanumerics or _.
Some examples:
u32feltmiden::standards::auth::pub_keymiden::standards::auth::scheme
Implementations
Sourceimpl SchemaType
impl SchemaType
Sourcepub fn new(s: impl Into<String>) -> Result<SchemaType, SchemaTypeError>
pub fn new(s: impl Into<String>) -> Result<SchemaType, SchemaTypeError>
Creates a new SchemaType from a String.
The name must follow a Rust-style namespace format, consisting of one or more segments
(non-empty, and alphanumerical) separated by double-colon (::) delimiters.
Errors
- If the identifier is empty.
- If any segment is empty or contains something other than alphanumerical characters/underscores.
Sourcepub fn void() -> SchemaType
pub fn void() -> SchemaType
Returns the schema type for the void type.
The void type always parses to 0 and is intended to model reserved or padding felts.
Sourcepub fn native_felt() -> SchemaType
pub fn native_felt() -> SchemaType
Returns the schema type for the native Felt type.
Sourcepub fn native_word() -> SchemaType
pub fn native_word() -> SchemaType
Returns the schema type for the native Word type.
Sourcepub fn u8() -> SchemaType
pub fn u8() -> SchemaType
Returns the schema type for the native u8 type.
Sourcepub fn u16() -> SchemaType
pub fn u16() -> SchemaType
Returns the schema type for the native u16 type.
Sourcepub fn u32() -> SchemaType
pub fn u32() -> SchemaType
Returns the schema type for the native u32 type.
Sourcepub fn bool() -> SchemaType
pub fn bool() -> SchemaType
Returns the schema type for the native bool type.
Sourcepub fn auth_scheme() -> SchemaType
pub fn auth_scheme() -> SchemaType
Returns the schema type for auth scheme identifiers.
Sourcepub fn pub_key() -> SchemaType
pub fn pub_key() -> SchemaType
Returns the schema type for public key commitments.
Sourcepub fn token_symbol() -> SchemaType
pub fn token_symbol() -> SchemaType
Returns the schema type for fungible faucet token symbols.