pub struct StorageSchema { /* private fields */ }Expand description
Describes the storage schema of an account component in terms of its named storage slots.
Implementations
Sourceimpl StorageSchema
impl StorageSchema
Sourcepub fn new(
slots: impl IntoIterator<Item = (StorageSlotName, StorageSlotSchema)>,
) -> Result<StorageSchema, ComponentMetadataError>
pub fn new( slots: impl IntoIterator<Item = (StorageSlotName, StorageSlotSchema)>, ) -> Result<StorageSchema, ComponentMetadataError>
Creates a new StorageSchema.
Errors
- If
fieldscontains duplicate slot names. - If any slot schema is invalid.
- If multiple schema fields map to the same init value name.
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = (&StorageSlotName, &StorageSlotSchema)>
pub fn iter( &self, ) -> impl Iterator<Item = (&StorageSlotName, &StorageSlotSchema)>
Returns an iterator over (slot_name, schema) pairs in slot-id order.
Sourcepub fn slots(&self) -> &BTreeMap<StorageSlotName, StorageSlotSchema>
pub fn slots(&self) -> &BTreeMap<StorageSlotName, StorageSlotSchema>
Returns a reference to the underlying slots map.
Sourcepub fn build_storage_slots(
&self,
init_storage_data: &InitStorageData,
) -> Result<Vec<StorageSlot>, ComponentMetadataError>
pub fn build_storage_slots( &self, init_storage_data: &InitStorageData, ) -> Result<Vec<StorageSlot>, ComponentMetadataError>
Builds the initial StorageSlots for this schema using the provided initialization data.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns a commitment to this storage schema definition.
The commitment is computed over the serialized schema and does not include defaults.
Sourcepub fn schema_requirements(
&self,
) -> Result<BTreeMap<StorageValueName, SchemaRequirement>, ComponentMetadataError>
pub fn schema_requirements( &self, ) -> Result<BTreeMap<StorageValueName, SchemaRequirement>, ComponentMetadataError>
Returns init-value requirements for the entire schema.
The returned map includes both required values (no default_value) and optional values
(with default_value), and excludes map entries.