pub enum AccountIdPrefix {
V0(AccountIdPrefixV0),
}Expand description
The prefix of an AccountId, i.e. its first field element.
See the AccountId documentation for details.
The serialization formats of AccountIdPrefix and AccountId are compatible. In
particular, a prefix can be deserialized from the serialized bytes of a full id.
Variants
Implementations
Sourceimpl AccountIdPrefix
impl AccountIdPrefix
Sourcepub const SERIALIZED_SIZE: usize = 8
pub const SERIALIZED_SIZE: usize = 8
The serialized size of an AccountIdPrefix in bytes.
Sourcepub fn new_unchecked(prefix: BaseElement) -> AccountIdPrefix
pub fn new_unchecked(prefix: BaseElement) -> AccountIdPrefix
Constructs a new AccountIdPrefix from the given prefix without checking its
validity.
Warning
Validity of the ID prefix must be ensured by the caller. An invalid ID may lead to panics.
Panics
Panics if the prefix does not contain a known account ID version.
If debug_assertions are enabled (e.g. in debug mode), this function panics if the given
felt is invalid according to the constraints in the AccountId
documentation.
Sourcepub fn new(prefix: BaseElement) -> Result<AccountIdPrefix, AccountIdError>
pub fn new(prefix: BaseElement) -> Result<AccountIdPrefix, AccountIdError>
Constructs a new AccountIdPrefix from the given prefix and checks its validity.
Errors
Returns an error if any of the ID constraints are not met. See the constraints documentation for details.
Sourcepub const fn as_felt(&self) -> BaseElement
pub const fn as_felt(&self) -> BaseElement
Returns the Felt that represents this prefix.
Sourcepub const fn account_type(&self) -> AccountType
pub const fn account_type(&self) -> AccountType
Returns the type of this account ID.
Sourcepub fn is_faucet(&self) -> bool
pub fn is_faucet(&self) -> bool
Returns true if an account with this ID is a faucet (can issue assets).
Sourcepub fn is_regular_account(&self) -> bool
pub fn is_regular_account(&self) -> bool
Returns true if an account with this ID is a regular account.
Sourcepub fn storage_mode(&self) -> AccountStorageMode
pub fn storage_mode(&self) -> AccountStorageMode
Returns the storage mode of this account ID.
Sourcepub fn has_public_state(&self) -> bool
pub fn has_public_state(&self) -> bool
Returns true if the full state of the account is public on chain, i.e. if the modes are
AccountStorageMode::Public or AccountStorageMode::Network, false otherwise.
Sourcepub fn is_public(&self) -> bool
pub fn is_public(&self) -> bool
Returns true if the storage mode is AccountStorageMode::Public, false otherwise.
Sourcepub fn is_network(&self) -> bool
pub fn is_network(&self) -> bool
Returns true if the storage mode is AccountStorageMode::Network, false otherwise.
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Returns true if self is a private account, false otherwise.
Sourcepub fn version(&self) -> AccountIdVersion
pub fn version(&self) -> AccountIdVersion
Returns the version of this account ID.