#[repr(u8)]pub enum AccountStorageMode {
Public = 0,
Network = 1,
Private = 2,
}Expand description
Describes where the state of the account is stored.
Variants
Public = 0
The account’s full state is stored on-chain.
Network = 1
The account’s full state is stored on-chain. Additionally, the network monitors this account
and creates network transactions against it. It is otherwise the same as Self::Public.
Private = 2
The account’s state is stored off-chain, and only a commitment to it is stored on-chain.
Implementations
Sourceimpl AccountStorageMode
impl AccountStorageMode
Sourcepub fn has_public_state(&self) -> bool
pub fn has_public_state(&self) -> bool
Returns true if the full state of the account is public on chain, i.e. if the modes are
Self::Public or Self::Network, false otherwise.
Sourcepub fn is_public(&self) -> bool
pub fn is_public(&self) -> bool
Returns true if the storage mode is Self::Public, false otherwise.
Sourcepub fn is_network(&self) -> bool
pub fn is_network(&self) -> bool
Returns true if the storage mode is Self::Network, false otherwise.
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Returns true if the storage mode is Self::Private, false otherwise.