#[non_exhaustive]#[repr(u16)]pub enum AddressInterface {
BasicWallet = 0,
}Expand description
The account interface of an Address.
An interface specifies the set of procedures of an account, which determines which notes it is able to receive and consume.
The enum is non-exhaustive so it can be extended in the future without it being a breaking change. Users are expected to match on the variants that they are able to handle and ignore the remaining ones.
Guarantees
An interface encodes to a u16, but is guaranteed to take up at most 11 of its bits. This
constraint allows encoding the interface into an address efficiently.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BasicWallet = 0
The basic wallet interface.