#[non_exhaustive]#[repr(u8)]pub enum AddressType {
AccountId = 232,
}Expand description
The type of an Address in Miden.
The byte values of this address type should be chosen as a multiple of 8. That way, the first
character of the bech32 string after the 1 separator will be different for every address type.
This makes the type of the address conveniently human-readable.
For instance, AddressType::AccountId is chosen as 232 which is 0b1110_1000 in binary. Base32
encodes one character for every 5 bits and 0b11101 (= 29) translates to a. So, every account
ID address will start with mm1a.
See the table in the bech32 spec for a convenient overview.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccountId = 232