pub enum StorageSlotContent {
Value(Word),
Map(StorageMap),
}Expand description
Represents the contents of a StorageSlot.
The content of a storage slot can be of two types:
- A simple value which contains a single word (4 field elements or ~32 bytes).
- A key value map where both keys and values are words. The capacity of such storage slot is theoretically unlimited.
Variants
Value(Word)
Map(StorageMap)
Implementations
Sourceimpl StorageSlotContent
impl StorageSlotContent
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Returns true if this storage slot has a value equal to the default of its type.
Sourcepub fn default_word(&self) -> Word
pub fn default_word(&self) -> Word
Returns the empty Word for a storage slot of this type
Sourcepub fn empty_value() -> StorageSlotContent
pub fn empty_value() -> StorageSlotContent
Returns a StorageSlotContent::Value with an empty word.
Sourcepub fn empty_map() -> StorageSlotContent
pub fn empty_map() -> StorageSlotContent
Returns an empty StorageSlotContent::Map.
Sourcepub fn value(&self) -> Word
pub fn value(&self) -> Word
Returns this storage slot value as a Word
Returns:
- For
StorageSlotContent::Valuethe value. - For
StorageSlotContent::Mapthe root of the StorageMap.
Sourcepub fn slot_type(&self) -> StorageSlotType
pub fn slot_type(&self) -> StorageSlotType
Returns the type of this storage slot