pub enum StorageSlotDelta {
Value(Word),
Map(StorageMapDelta),
}Expand description
The delta of a single storage slot.
StorageSlotDelta::Valuecontains the value to which a value slot is updated.StorageSlotDelta::Mapcontains theStorageMapDeltawhich contains the key-value pairs that were updated in a map slot.
Variants
Value(Word)
Map(StorageMapDelta)
Implementations
Sourceimpl StorageSlotDelta
impl StorageSlotDelta
Sourcepub fn with_empty_value() -> StorageSlotDelta
pub fn with_empty_value() -> StorageSlotDelta
Returns a new StorageSlotDelta::Value with an empty value.
Sourcepub fn with_empty_map() -> StorageSlotDelta
pub fn with_empty_map() -> StorageSlotDelta
Returns a new StorageSlotDelta::Map with an empty map delta.
Sourcepub fn slot_type(&self) -> StorageSlotType
pub fn slot_type(&self) -> StorageSlotType
Returns the StorageSlotType of this slot delta.
Sourcepub fn is_value(&self) -> bool
pub fn is_value(&self) -> bool
Returns true if the slot delta is of type StorageSlotDelta::Value, false otherwise.
Sourcepub fn is_map(&self) -> bool
pub fn is_map(&self) -> bool
Returns true if the slot delta is of type StorageSlotDelta::Map, false otherwise.
Sourcepub fn unwrap_value(self) -> Word
pub fn unwrap_value(self) -> Word
Unwraps a value slot delta into a Word.
Panics
Panics if:
selfis not of typeStorageSlotDelta::Value.
Sourcepub fn unwrap_map(self) -> StorageMapDelta
pub fn unwrap_map(self) -> StorageMapDelta
Unwraps a map slot delta into a StorageMapDelta.
Panics
Panics if:
selfis not of typeStorageSlotDelta::Map.