Module auth

Module auth 

Structs

AuthGuardedMultisig
An AccountComponent implementing multisig authentication integrated with a state guardian.
AuthGuardedMultisigConfig
Configuration for AuthGuardedMultisig component.
AuthMultisig
An AccountComponent implementing a multisig authentication.
AuthMultisigConfig
Configuration for AuthMultisig component.
AuthMultisigSmart
An AccountComponent implementing a multisig auth component with smart-policy slots.
AuthMultisigSmartConfig
Configuration for AuthMultisigSmart component.
AuthNetworkAccount
An AccountComponent implementing an authentication scheme that restricts what notes an account can consume to a fixed allowlist of note script roots, and what transaction scripts may run against the account to a fixed allowlist of tx script roots.
AuthSingleSig
An AccountComponent implementing the signature scheme for authentication of transactions.
AuthSingleSigAcl
An AccountComponent implementing a procedure-based Access Control List (ACL) using either the EcdsaK256Keccak or Falcon512 Poseidon2 signature scheme for authentication of transactions.
AuthSingleSigAclConfig
Configuration for AuthSingleSigAcl component.
GuardianConfig
Public configuration for the guardian signer.
NetworkAccount
A wrapper around an Account that is guaranteed to be a network account.
NetworkAccountNoteAllowlist
A standardized storage slot holding the allowlist of input-note script roots that a network account is willing to consume.
NetworkAccountTxScriptAllowlist
A standardized storage slot holding the allowlist of transaction script roots that a network account is willing to execute.
NoAuth
An AccountComponent implementing a no-authentication scheme.

Enums

NetworkAccountNoteAllowlistError
Errors that can occur when constructing a NetworkAccountNoteAllowlist or reconstructing one from storage.
NetworkAccountTxScriptAllowlistError
Errors that can occur when reconstructing a NetworkAccountTxScriptAllowlist from storage.