pub struct AuthGuardedMultisigConfig { /* private fields */ }Expand description
Configuration for AuthGuardedMultisig component.
Implementations
Sourceimpl AuthGuardedMultisigConfig
impl AuthGuardedMultisigConfig
Sourcepub fn new(
approvers: Vec<(PublicKeyCommitment, AuthScheme)>,
default_threshold: u32,
guardian_config: GuardianConfig,
) -> Result<AuthGuardedMultisigConfig, AccountError>
pub fn new( approvers: Vec<(PublicKeyCommitment, AuthScheme)>, default_threshold: u32, guardian_config: GuardianConfig, ) -> Result<AuthGuardedMultisigConfig, AccountError>
Creates a new configuration with the given approvers, default threshold and guardian signer.
The default_threshold must be at least 1 and at most the number of approvers.
The guardian public key must be different from all approver public keys.
Sourcepub fn with_proc_thresholds(
self,
proc_thresholds: Vec<(AccountProcedureRoot, u32)>,
) -> Result<AuthGuardedMultisigConfig, AccountError>
pub fn with_proc_thresholds( self, proc_thresholds: Vec<(AccountProcedureRoot, u32)>, ) -> Result<AuthGuardedMultisigConfig, AccountError>
Attaches a per-procedure threshold map. Each procedure threshold must be at least 1 and at most the number of approvers.
pub fn approvers(&self) -> &[(PublicKeyCommitment, AuthScheme)]
pub fn default_threshold(&self) -> u32
pub fn proc_thresholds(&self) -> &[(AccountProcedureRoot, u32)]
pub fn guardian_config(&self) -> GuardianConfig