Module fees

Module fees 

Fee policy configuration and fee policy account components.

Structs

BasicConstantFeePolicy
The basic_constant_fee fee policy account component.
ConstantFeeManager
Account component that exposes the set_note_fee admin procedure gated by the account-wide crate::account::access::Authority component via exec.authority::assert_authorized.
FeePolicy
Descriptor for a fee policy registered with a super::FeePolicyManager.
FeePolicyManager
The fee policy configuration of a network account: the policy defining the fee estimation for notes, which policies it may be switched to, and the asset that fees are charged in.
FeePolicyManagerBuilder
Use builder syntax to set the inputs and finish with build().

Enums

FeePolicyError
Errors returned by FeePolicy::custom.