pub struct FeePolicy { /* private fields */ }Expand description
Descriptor for a fee policy registered with a super::FeePolicyManager.
Binds the procedure root the manager dispatches to (via dyncall) with any companion
AccountComponents that must be installed for the procedure to work.
Construct from a concrete policy (e.g. via From<BasicConstantFeePolicy>) or via
Self::custom. Pass to the super::FeePolicyManager builder via active_fee_policy or
allowed_fee_policy.
Implementations
Sourceimpl FeePolicy
impl FeePolicy
Sourcepub fn custom<I>(
root: AccountProcedureRoot,
components: I,
) -> Result<FeePolicy, FeePolicyError>
pub fn custom<I>( root: AccountProcedureRoot, components: I, ) -> Result<FeePolicy, FeePolicyError>
Returns a fee policy resolving to root and shipping the provided companion
components (anything that can be converted into an AccountComponent).
Errors
Returns FeePolicyError::RootNotInComponents if root is not the procedure root of
any procedure exported by the provided components.
Sourcepub fn root(&self) -> AccountProcedureRoot
pub fn root(&self) -> AccountProcedureRoot
Returns the procedure root of the policy this descriptor resolves to.