Module interface

Module interface 

Structs

AccountInterface
An AccountInterface describes the exported, callable procedures of an account.

Enums

AccountComponentInterface
The enum holding all possible account interfaces which could be loaded to some account.
AccountInterfaceError
Account interface related errors.

Traits

AccountComponentInterfaceExt
An extension for AccountComponentInterface that allows instantiation from a set of procedure roots.
AccountInterfaceExt
An extension for AccountInterface that allows instantiation from higher-level types.