Module wallets

Module wallets 

Structs

BasicWallet
An AccountComponent implementing a basic wallet.

Enums

BasicWalletError
Basic wallet related errors.

Functions

create_basic_wallet
Creates a new account with basic wallet interface, the specified authentication scheme and the account storage type. Basic wallets can be specified to have either mutable or immutable code.