create_basic_wallet

Function create_basic_wallet 

pub fn create_basic_wallet(
    init_seed: [u8; 32],
    approver: Approver,
    account_type: AccountType,
) -> Result<Account, AccountError>
Creates a new account with a basic wallet interface, single signature authentication and the specified account type.

The basic wallet interface exposes two procedures:

  • receive_asset, which can be used to add an asset to the account.
  • move_asset_to_note, which can be used to remove the specified asset from the account and add it to the output note with the specified index.

All methods require authentication, which is provided by an AuthSingleSig component configured with the given approver.