pub struct AccountBuilder { /* private fields */ }Expand description
A convenient builder for an Account allowing for safe construction of an account by
combining multiple AccountComponents.
This will build a valid new account with these properties:
- An empty
AssetVault. - The nonce set to
Felt::ZERO. - A seed which results in an
AccountIdvalid for the configured account type and storage mode.
By default, the builder is initialized with:
- The
account_typeset toAccountType::RegularAccountUpdatableCode. - The
storage_modeset toAccountStorageMode::Private. - The
versionset toAccountIdVersion::Version0.
The methods that are required to be called are:
AccountBuilder::with_auth_component,AccountBuilder::with_component, which must be called at least once.
Under the testing feature, it is possible to:
- Build an existing account using [
AccountBuilder::build_existing] which will set the account’s nonce to1by default, or to the configured value. - Add assets to the account’s vault, however this will only succeed when using
[
AccountBuilder::build_existing].
Storage Slot Order
Note that the components are merged together in the same order as with_component is called,
except for the auth component. It is always moved to the first position, due to the requirement
that the auth procedure must be at procedure index 0 within an AccountCode. That also
affects the storage slot order and means the auth component’s storage comes first, if it has any
storage.
Faucet accounts have a protocol-reserved storage slot which is at index 0. This means user-defined storage slots start at index 1.
Implementations
Sourceimpl AccountBuilder
impl AccountBuilder
Sourcepub fn new(init_seed: [u8; 32]) -> AccountBuilder
pub fn new(init_seed: [u8; 32]) -> AccountBuilder
Creates a new builder for an account and sets the initial seed from which the grinding
process for that account’s AccountId will start.
This initial seed should come from a cryptographic random number generator.
Sourcepub fn version(self, version: AccountIdVersion) -> AccountBuilder
pub fn version(self, version: AccountIdVersion) -> AccountBuilder
Sets the AccountIdVersion of the account ID.
Sourcepub fn account_type(self, account_type: AccountType) -> AccountBuilder
pub fn account_type(self, account_type: AccountType) -> AccountBuilder
Sets the type of the account.
Sourcepub fn storage_mode(self, storage_mode: AccountStorageMode) -> AccountBuilder
pub fn storage_mode(self, storage_mode: AccountStorageMode) -> AccountBuilder
Sets the storage mode of the account.
Sourcepub fn with_component(
self,
account_component: impl Into<AccountComponent>,
) -> AccountBuilder
pub fn with_component( self, account_component: impl Into<AccountComponent>, ) -> AccountBuilder
Adds an AccountComponent to the builder. This method can be called multiple times and
must be called at least once since an account must export at least one procedure.
All components will be merged to form the final code and storage of the built account.
Sourcepub fn with_auth_component(
self,
account_component: impl Into<AccountComponent>,
) -> AccountBuilder
pub fn with_auth_component( self, account_component: impl Into<AccountComponent>, ) -> AccountBuilder
Adds a designated authentication AccountComponent to the builder.
This component may contain multiple procedures, but is expected to contain exactly one
authentication procedure (named auth_*).
Calling this method multiple times will override the previous auth component.
Procedures from this component will be placed at the beginning of the account procedure list.
Sourcepub fn storage_schemas(&self) -> impl Iterator<Item = &StorageSchema>
pub fn storage_schemas(&self) -> impl Iterator<Item = &StorageSchema>
Returns an iterator of storage schemas attached to the builder’s components, if any.
Components constructed without metadata will not contribute a schema.
Sourcepub fn build(self) -> Result<Account, AccountError>
pub fn build(self) -> Result<Account, AccountError>
Builds an Account out of the configured builder.
Errors
Returns an error if:
- The init seed is not set.
- Any of the components does not support the set account type.
- The number of procedures in all merged components is 0 or exceeds
AccountCode::MAX_NUM_PROCEDURES. - Two or more libraries export a procedure with the same MAST root.
- Authentication component is missing.
- Multiple authentication procedures are found.
- The number of
StorageSlots of all components exceeds 255. MastForest::mergefails on the given components.- If duplicate assets were added to the builder (only under the
testingfeature). - If the vault is not empty on new accounts (only under the
testingfeature).