pub struct AccountFile {
pub account: Account,
pub auth_secret_keys: Vec<AuthSecretKey>,
}Expand description
Account file contains a complete description of an account, including the Account struct as
well as account seed and account authentication info.
The account authentication info consists of a list of AuthSecretKey that the account may
use within its code.
The intent of this struct is to provide an easy way to serialize and deserialize all account-related data as a single unit (e.g., to/from files).
Fields
account: Accountauth_secret_keys: Vec<AuthSecretKey>Implementations
Sourceimpl AccountFile
impl AccountFile
pub fn new(account: Account, auth_keys: Vec<AuthSecretKey>) -> AccountFile
Sourceimpl AccountFile
impl AccountFile