pub struct AccountHeader { /* private fields */ }Expand description
A header of an account which contains information that succinctly describes the state of the components of the account.
The AccountHeader is composed of:
- id: the account ID (
AccountId) of the account. - nonce: the nonce of the account.
- vault_root: a commitment to the account’s vault (super::AssetVault).
- storage_commitment: a commitment to the account’s storage (super::AccountStorage).
- code_commitment: a commitment to the account’s code (super::AccountCode).
Implementations
Sourceimpl AccountHeader
impl AccountHeader
Sourcepub fn new(
id: AccountId,
nonce: BaseElement,
vault_root: Word,
storage_commitment: Word,
code_commitment: Word,
) -> AccountHeader
pub fn new( id: AccountId, nonce: BaseElement, vault_root: Word, storage_commitment: Word, code_commitment: Word, ) -> AccountHeader
Creates a new AccountHeader.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns the commitment of this account.
The commitment of an account is computed as hash(id, nonce, vault_root, storage_commitment, code_commitment). Computing the account commitment requires 2 permutations of the hash function.
Sourcepub fn nonce(&self) -> BaseElement
pub fn nonce(&self) -> BaseElement
Returns the nonce of this account.
Sourcepub fn vault_root(&self) -> Word
pub fn vault_root(&self) -> Word
Returns the vault root of this account.
Sourcepub fn storage_commitment(&self) -> Word
pub fn storage_commitment(&self) -> Word
Returns the storage commitment of this account.
Sourcepub fn code_commitment(&self) -> Word
pub fn code_commitment(&self) -> Word
Returns the code commitment of this account.
Sourcepub fn as_elements(&self) -> Vec<BaseElement>
pub fn as_elements(&self) -> Vec<BaseElement>
Converts the account header into a vector of field elements.
This is done by first converting the account header data into an array of Words as follows:
[
[account_id_suffix, account_id_prefix, 0, account_nonce]
[VAULT_ROOT]
[STORAGE_COMMITMENT]
[CODE_COMMITMENT]
]And then concatenating the resulting elements into a single vector.