pub struct AccountStorage { /* private fields */ }Expand description
Account storage is composed of a variable number of name-addressable StorageSlots up to
255 slots in total.
Each slot consists of a StorageSlotName and StorageSlotContent which defines its size
and structure. Currently, the following content types are supported:
StorageSlotContent::Value: contains a singleWordof data (i.e., 32 bytes).StorageSlotContent::Map: contains aStorageMapwhich is a key-value map where both keys and values are Words. The value of a storage slot containing a map is the commitment to the underlying map.
Slots are sorted by StorageSlotName (or StorageSlotId equivalently). This order is
necessary to:
- Simplify lookups of slots in the transaction kernel (using
std::collections::sorted_arrayfrom the miden core library) - Allow the
AccountStorageDeltato work only with slot names instead of slot indices. - Make it simple to check for duplicates by iterating the slots and checking that no two adjacent items have the same slot name.
Implementations
Sourceimpl AccountStorage
impl AccountStorage
Sourcepub const MAX_NUM_STORAGE_SLOTS: usize = 255
pub const MAX_NUM_STORAGE_SLOTS: usize = 255
The maximum number of storage slots allowed in an account storage.
Sourcepub fn new(slots: Vec<StorageSlot>) -> Result<AccountStorage, AccountError>
pub fn new(slots: Vec<StorageSlot>) -> Result<AccountStorage, AccountError>
Returns a new instance of account storage initialized with the provided storage slots.
This function sorts the slots by StorageSlotName.
Errors
Returns an error if:
- The number of
StorageSlots exceeds 255. - There are multiple storage slots with the same
StorageSlotName.
Sourcepub fn faucet_sysdata_slot() -> &'static StorageSlotName
pub fn faucet_sysdata_slot() -> &'static StorageSlotName
Returns the StorageSlotName of the faucet’s protocol system data.
Sourcepub fn to_elements(&self) -> Vec<BaseElement>
pub fn to_elements(&self) -> Vec<BaseElement>
Converts storage slots of this account storage into a vector of field elements.
Each storage slot is represented by exactly 8 elements:
[[0, slot_type, slot_id_suffix, slot_id_prefix], SLOT_VALUE]Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Returns the commitment to the AccountStorage.
Sourcepub fn slots(&self) -> &[StorageSlot]
pub fn slots(&self) -> &[StorageSlot]
Returns a reference to the storage slots.
Sourcepub fn into_slots(self) -> Vec<StorageSlot>
pub fn into_slots(self) -> Vec<StorageSlot>
Consumes self and returns the storage slots of the account storage.
Sourcepub fn to_header(&self) -> AccountStorageHeader
pub fn to_header(&self) -> AccountStorageHeader
Returns an AccountStorageHeader for this account storage.
Sourcepub fn get(&self, slot_name: &StorageSlotName) -> Option<&StorageSlot>
pub fn get(&self, slot_name: &StorageSlotName) -> Option<&StorageSlot>
Returns a reference to the storage slot with the provided name, if it exists, None
otherwise.
Sourcepub fn get_item(
&self,
slot_name: &StorageSlotName,
) -> Result<Word, AccountError>
pub fn get_item( &self, slot_name: &StorageSlotName, ) -> Result<Word, AccountError>
Returns an item from the storage slot with the given name.
Errors
Returns an error if:
- A slot with the provided name does not exist.
Sourcepub fn get_map_item(
&self,
slot_name: &StorageSlotName,
key: Word,
) -> Result<Word, AccountError>
pub fn get_map_item( &self, slot_name: &StorageSlotName, key: Word, ) -> Result<Word, AccountError>
Returns a map item from the map in the storage slot with the given name.
Errors
Returns an error if:
- A slot with the provided name does not exist.
- If the
StorageSlotis notStorageSlotType::Map.
Sourcepub fn set_item(
&mut self,
slot_name: &StorageSlotName,
value: Word,
) -> Result<Word, AccountError>
pub fn set_item( &mut self, slot_name: &StorageSlotName, value: Word, ) -> Result<Word, AccountError>
Updates the value of the storage slot with the given name.
This method should be used only to update value slots. For updating values
in storage maps, please see AccountStorage::set_map_item.
Errors
Returns an error if:
- A slot with the provided name does not exist.
- The
StorageSlotis notStorageSlotType::Value.
Sourcepub fn set_map_item(
&mut self,
slot_name: &StorageSlotName,
raw_key: Word,
value: Word,
) -> Result<(Word, Word), AccountError>
pub fn set_map_item( &mut self, slot_name: &StorageSlotName, raw_key: Word, value: Word, ) -> Result<(Word, Word), AccountError>
Updates the value of a key-value pair of a storage map with the given name.
This method should be used only to update storage maps. For updating values in storage slots, please see AccountStorage::set_item().
Errors
Returns an error if:
- A slot with the provided name does not exist.
- If the
StorageSlotis notStorageSlotType::Map.