pub struct PartialStorage { /* private fields */ }Expand description
A partial representation of an account storage, containing only a subset of the storage data.
Partial storage is used to provide verifiable access to specific segments of account storage without the need to provide the full storage data. It contains all needed parts for loading account storage data into the transaction kernel.
Implementations
Sourceimpl PartialStorage
impl PartialStorage
Sourcepub fn new(
storage_header: AccountStorageHeader,
storage_maps: impl IntoIterator<Item = PartialStorageMap>,
) -> Result<PartialStorage, AccountError>
pub fn new( storage_header: AccountStorageHeader, storage_maps: impl IntoIterator<Item = PartialStorageMap>, ) -> Result<PartialStorage, AccountError>
Returns a new instance of partial storage with the specified header and storage map SMTs.
The storage commitment is computed during instantiation based on the provided header. Additionally, this function validates that the passed SMTs correspond to one of the map roots in the storage header.
Sourcepub fn new_full(account_storage: AccountStorage) -> PartialStorage
pub fn new_full(account_storage: AccountStorage) -> PartialStorage
Converts an AccountStorage into a partial storage representation.
This creates a partial storage that contains the full proofs for all key-value pairs in all map slots of the account storage.
Sourcepub fn new_minimal(account_storage: &AccountStorage) -> PartialStorage
pub fn new_minimal(account_storage: &AccountStorage) -> PartialStorage
Converts an AccountStorage into a partial storage representation.
For every storage map, a single unspecified key-value pair is tracked so that the
PartialStorageMap represents the correct root.
Sourcepub fn header(&self) -> &AccountStorageHeader
pub fn header(&self) -> &AccountStorageHeader
Returns a reference to the header of this partial storage.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns the commitment of this partial storage.
Sourcepub fn into_parts(
self,
) -> (Word, AccountStorageHeader, BTreeMap<Word, PartialStorageMap>)
pub fn into_parts( self, ) -> (Word, AccountStorageHeader, BTreeMap<Word, PartialStorageMap>)
Consumes self and returns the underlying parts.
Sourcepub fn inner_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
pub fn inner_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
Returns an iterator over inner nodes of all storage map proofs contained in this partial storage.
Sourcepub fn maps(&self) -> impl Iterator<Item = &PartialStorageMap>
pub fn maps(&self) -> impl Iterator<Item = &PartialStorageMap>
Iterator over every PartialStorageMap in this partial storage.