pub struct RoleSymbol(/* private fields */);Expand description
Represents a role symbol for role-based access control.
Role symbols can consist of up to 12 uppercase Latin characters and underscores, e.g. “MINTER”, “BURNER”, “MINTER_ADMIN”.
The label is stored internally as a validated short string (A–Z and _) and can be
converted to a Felt encoding via as_element().
Implementations
Sourceimpl RoleSymbol
impl RoleSymbol
Sourcepub const ALPHABET: &'static str = "ABCDEFGHIJKLMNOPQRSTUVWXYZ_"
pub const ALPHABET: &'static str = "ABCDEFGHIJKLMNOPQRSTUVWXYZ_"
Alphabet used for role symbols (A-Z and _).
Sourcepub const MIN_ENCODED_VALUE: u64 = 1
pub const MIN_ENCODED_VALUE: u64 = 1
The minimum integer value of an encoded RoleSymbol.
This value encodes the “A” role symbol.
Sourcepub const MAX_ENCODED_VALUE: u64 = 4052555153018976252
pub const MAX_ENCODED_VALUE: u64 = 4052555153018976252
The maximum integer value of an encoded RoleSymbol.
This value encodes the “____________” role symbol (12 underscores).
Sourcepub fn new_unchecked(role_symbol: &str) -> RoleSymbol
pub fn new_unchecked(role_symbol: &str) -> RoleSymbol
Constructs a new RoleSymbol from a string, panicking on invalid input.
Panics
Panics if:
- The length of the provided string is less than 1 or greater than 12.
- The provided role symbol contains characters outside
A-Zand_.
Sourcepub fn new(role_symbol: &str) -> Result<RoleSymbol, RoleSymbolError>
pub fn new(role_symbol: &str) -> Result<RoleSymbol, RoleSymbolError>
Creates a new RoleSymbol from the provided role symbol string.
Errors
Returns an error if:
- The length of the provided string is less than 1 or greater than 12.
- The provided role symbol contains characters outside
A-Zand_.
Sourcepub fn as_element(&self) -> Felt
pub fn as_element(&self) -> Felt
Returns the Felt encoding of this role symbol.