pub struct StorageMapDelta(/* private fields */);Expand description
StorageMapDelta stores the differences between two states of account storage maps.
The differences are represented as leaf updates: a map of updated item key (Word) to value (Word). For cleared items the value is EMPTY_WORD.
Implementations
Sourceimpl StorageMapDelta
impl StorageMapDelta
Sourcepub fn new(map: BTreeMap<StorageMapKey, Word>) -> StorageMapDelta
pub fn new(map: BTreeMap<StorageMapKey, Word>) -> StorageMapDelta
Creates a new storage map delta from the provided leaves.
Sourcepub fn num_entries(&self) -> usize
pub fn num_entries(&self) -> usize
Returns the number of changed entries in this map delta.
Sourcepub fn entries(&self) -> &BTreeMap<StorageMapKey, Word>
pub fn entries(&self) -> &BTreeMap<StorageMapKey, Word>
Returns a reference to the updated entries in this storage map delta.
Note that the returned key is the StorageMapKey.
Sourcepub fn insert(&mut self, key: StorageMapKey, value: Word)
pub fn insert(&mut self, key: StorageMapKey, value: Word)
Inserts an item into the storage map delta.
Sourcepub fn merge(&mut self, other: StorageMapDelta)
pub fn merge(&mut self, other: StorageMapDelta)
Merge other into this delta, giving precedence to other.
Sourcepub fn as_map_mut(&mut self) -> &mut BTreeMap<StorageMapKey, Word>
pub fn as_map_mut(&mut self) -> &mut BTreeMap<StorageMapKey, Word>
Returns a mutable reference to the underlying map.