pub struct StorageMapKeyHash(/* private fields */);Expand description
A hashed key for a StorageMap.
This is produced by hashing a StorageMapKey and is used as the actual key in the
underlying SMT. Wrapping the hashed key in a distinct type prevents accidentally using a raw
key where a hashed key is expected and vice-versa.
Implementations
Sourceimpl StorageMapKeyHash
impl StorageMapKeyHash
Sourcepub fn from_raw(word: Word) -> StorageMapKeyHash
pub fn from_raw(word: Word) -> StorageMapKeyHash
Construct without further checks from a given Word.
Warning
This requires the caller to uphold the guarantees/invariants of this type (if any). Check the type-level documentation for guarantees/invariants.
Sourcepub fn as_elements(&self) -> &[Felt]
pub fn as_elements(&self) -> &[Felt]
Returns the elements representation of this value.
Sourceimpl StorageMapKeyHash
impl StorageMapKeyHash
Sourcepub fn to_leaf_index(
&self,
) -> LeafIndex<miden_protocol::::account::storage::map::key::{impl#5}::to_leaf_index::{constant#0}>
pub fn to_leaf_index( &self, ) -> LeafIndex<miden_protocol::::account::storage::map::key::{impl#5}::to_leaf_index::{constant#0}>
Returns the leaf index in the SMT for this hashed key.