pub struct StorageMapWitness { /* private fields */ }Expand description
A witness of an asset in a StorageMap.
It proves inclusion of a certain storage item in the map.
Guarantees
This type guarantees that the raw key-value pairs it contains are all present in the
contained SMT proof. Note that the inverse is not necessarily true. The proof may contain more
entries than the map because to prove inclusion of a given raw key A an
SmtLeaf::Multiple may be present that contains
both keys hash(A) and hash(B). However, B may not be present in the key-value pairs and this is
a valid state.
Implementations
Sourceimpl StorageMapWitness
impl StorageMapWitness
Sourcepub fn new(
proof: SmtProof,
keys: impl IntoIterator<Item = StorageMapKey>,
) -> Result<StorageMapWitness, StorageMapError>
pub fn new( proof: SmtProof, keys: impl IntoIterator<Item = StorageMapKey>, ) -> Result<StorageMapWitness, StorageMapError>
Creates a new StorageMapWitness from an SMT proof and a provided set of map keys.
Errors
Returns an error if:
- Any of the map keys is not contained in the proof.
Sourcepub fn new_unchecked(
proof: SmtProof,
key_values: impl IntoIterator<Item = (StorageMapKey, Word)>,
) -> StorageMapWitness
pub fn new_unchecked( proof: SmtProof, key_values: impl IntoIterator<Item = (StorageMapKey, Word)>, ) -> StorageMapWitness
Creates a new StorageMapWitness from an SMT proof and a set of key value pairs.
Warning
This does not validate any of the guarantees of this type. See the type-level docs for more details.
Sourcepub fn get(&self, key: StorageMapKey) -> Option<Word>
pub fn get(&self, key: StorageMapKey) -> Option<Word>
Looks up the provided key in this witness and returns:
- a non-empty
Wordif the key is tracked by this witness and exists in it, Word::emptyif the key is tracked by this witness and does not exist,Noneif the key is not tracked by this witness.
Sourcepub fn entries(&self) -> impl Iterator<Item = (&StorageMapKey, &Word)>
pub fn entries(&self) -> impl Iterator<Item = (&StorageMapKey, &Word)>
Returns an iterator over the key-value pairs in this witness.
Sourcepub fn authenticated_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
pub fn authenticated_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
Returns an iterator over every inner node of this witness’ merkle path.