pub struct StorageSlotId { /* private fields */ }Expand description
The partial hash of a StorageSlotName.
The ID of a slot are the first (suffix) and second (prefix) field elements of the
blake3-hashed slot name.
The slot ID is used to uniquely identify a storage slot and is used to sort slots in account storage.
Implementations
Sourceimpl StorageSlotId
impl StorageSlotId
Sourcepub fn new(suffix: BaseElement, prefix: BaseElement) -> StorageSlotId
pub fn new(suffix: BaseElement, prefix: BaseElement) -> StorageSlotId
Creates a new StorageSlotId from the provided felts.
Sourcepub fn suffix(&self) -> BaseElement
pub fn suffix(&self) -> BaseElement
Returns the suffix of the StorageSlotId.
Sourcepub fn prefix(&self) -> BaseElement
pub fn prefix(&self) -> BaseElement
Returns the prefix of the StorageSlotId.