pub struct StorageSlotName { /* private fields */ }Expand description
The name of an account storage slot.
A typical slot name looks like this:
miden::standards::fungible_faucets::metadataThe double-colon (::) serves as a separator and the strings in between the separators are
called components.
It is generally recommended that slot names have at least three components and follow this structure:
project_name::component_name::slot_nameRequirements
For a string to be a valid slot name it needs to satisfy the following criteria:
- Its length must be less than 255.
- It needs to have at least 2 components.
- Each component must consist of at least one character.
- Each component must only consist of the characters
atoz,AtoZ,0to9or_(underscore). - Each component must not start with an underscore.
Implementations
Sourceimpl StorageSlotName
impl StorageSlotName
Sourcepub fn new(
name: impl Into<Arc<str>>,
) -> Result<StorageSlotName, StorageSlotNameError>
pub fn new( name: impl Into<Arc<str>>, ) -> Result<StorageSlotName, StorageSlotNameError>
Constructs a new StorageSlotName from a string.
Errors
Returns an error if:
- the slot name is invalid (see the type-level docs for the requirements).
Sourcepub fn id(&self) -> StorageSlotId
pub fn id(&self) -> StorageSlotId
Returns the StorageSlotId derived from the slot name.