AccountBuilderSchemaCommitmentExt

Trait AccountBuilderSchemaCommitmentExt 

pub trait AccountBuilderSchemaCommitmentExt {
    // Required method
    fn build_with_schema_commitment(self) -> Result<Account, AccountError>;
}
An extension trait for AccountBuilder that provides a convenience method for building an account with an AccountSchemaCommitment component.

Required Methods

fn build_with_schema_commitment(self) -> Result<Account, AccountError>

Builds an Account out of the configured builder after computing the storage schema commitment from all components currently in the builder and adding an AccountSchemaCommitment component.

Errors

Returns an error if:

  • The components’ storage schemas contain conflicting definitions for the same slot name.
  • AccountBuilder::build fails.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors