Module address

Module address 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides types for working with addresses within the Miden network.

Structs

Address
A user-facing address in Miden.
CustomNetworkId
A wrapper around bech32 HRP(human-readable part) for custom network identifiers.
RoutingParameters
Parameters that define how a sender should route a note to the AddressId in an Address.

Enums

AddressId
The identifier of an Address.
AddressInterface
The account interface of an Address.
NetworkId
The identifier of a Miden network.