Module config_note

Module config_note 

CONFIG_AGG_BRIDGE note creation utilities.

This module provides helpers for creating CONFIG_AGG_BRIDGE notes, which are used to register faucets in the bridge’s faucet registry.

Structs

ConfigAggBridgeNote
CONFIG_AGG_BRIDGE note.
ConversionMetadata
The conversion metadata registered on the bridge for a single faucet.