pub enum AgglayerNote {
CLAIM,
B2AGG,
CONFIG_AGG_BRIDGE,
DEREGISTER_AGG_FAUCET,
UPDATE_GER,
REMOVE_GER,
}Expand description
The enum holding the types of notes provided by miden-agglayer, mirroring
StandardNote.
Variants
Implementations
Sourceimpl AgglayerNote
impl AgglayerNote
Sourcepub fn from_script_root(root: NoteScriptRoot) -> Option<AgglayerNote>
pub fn from_script_root(root: NoteScriptRoot) -> Option<AgglayerNote>
Returns an AgglayerNote instance based on the provided script root. Returns None
if the provided root does not match any agglayer note script.
Sourcepub fn name(&self) -> &'static str
pub fn name(&self) -> &'static str
Returns the name of this AgglayerNote variant as a string.
Sourcepub fn script(&self) -> NoteScript
pub fn script(&self) -> NoteScript
Returns the note script of the current AgglayerNote instance.
Sourcepub fn script_root(&self) -> NoteScriptRoot
pub fn script_root(&self) -> NoteScriptRoot
Returns the script root of the current AgglayerNote instance.
Sourcepub fn note_cost(root: NoteScriptRoot) -> Option<NoteCost>
pub fn note_cost(root: NoteScriptRoot) -> Option<NoteCost>
Returns the benchmarked consumption cost of the agglayer note with the given script
root, or None if the root does not match an agglayer note.
The NetworkNotePricer in miden-tx combines this lookup with the standard notes’
(StandardNote::note_cost) to resolve the cost of any priced note.