Module remove_ger_note

Module remove_ger_note 

REMOVE_GER note creation utilities.

This module provides helpers for creating REMOVE_GER notes, which are used to remove a Global Exit Root from the bridge account and fold it into the running removed-GER keccak256 hash chain.

Structs

RemoveGerNote
REMOVE_GER note.