UPDATE_GER note creation utilities.
This module provides helpers for creating UPDATE_GER notes, which are used to update the Global Exit Root in the bridge account.
Structs
- Update
GerNote - UPDATE_GER note.
UPDATE_GER note creation utilities.
This module provides helpers for creating UPDATE_GER notes, which are used to update the Global Exit Root in the bridge account.