Module assembly

Module assembly 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides types and utilities for working with Miden Assembly.

Structs

Assembler
The Assembler produces a Merkelized Abstract Syntax Tree (MAST) from Miden Assembly sources, as an artifact of one of three types:
CodeBuilder
A builder for compiling account components, note scripts, and transaction scripts with optional library dependencies.
DefaultSourceManager
Library
Represents a library where all modules were compiled into a MastForest.
MastForest
Represents one or more procedures, represented as a collection of MastNodes.
Module
The abstract syntax tree for a single Miden Assembly module.
Path
A borrowed reference to a subset of a path, e.g. another Path or a PathBuf
PrintDiagnostic
A type that can be used to render a super::Diagnostic via core::fmt::Display
Report
Core Diagnostic wrapper type.

Enums

ModuleKind
Represents the kind of a Module.

Traits

MastNodeExt
SourceManagerSync
SourceManagerSync is a marker trait for SourceManager implementations that are also Send + Sync, and is automatically implemented for any SourceManager that meets those requirements.