#[repr(u8)]pub enum ModuleKind {
Library = 0,
Executable = 1,
Kernel = 2,
}Expand description
Represents the kind of a Module.
The three different kinds have slightly different rules on what syntax is allowed, as well as what operations can be performed in the body of procedures defined in the module. See the documentation for each variant for a summary of these differences.
Variants
Library = 0
A library is a simple container of code that must be included into an executable module to form a complete program.
Library modules cannot use the begin..end syntax, which is used to define the
entrypoint procedure for an executable. Aside from this, they are free to use all other
MASM syntax.
Executable = 1
An executable is the root module of a program, and provides the entrypoint for executing that program.
As the executable module is the root module, it may not export procedures for other modules to depend on, it may only import and call externally-defined procedures, or private locally-defined procedures.
An executable module must contain a begin..end block.
Kernel = 2
A kernel is like a library module, but is special in a few ways:
-
Its code always executes in the root context, so it is stateful in a way that normal libraries cannot replicate. This can be used to provide core services that would otherwise not be possible to implement.
-
The procedures exported from the kernel may be the target of the
syscallinstruction, and in fact must be called that way. -
Kernels may not use
syscallorcallinstructions internally.
Implementations
Sourceimpl ModuleKind
impl ModuleKind
pub fn is_executable(&self) -> bool
pub fn is_kernel(&self) -> bool
pub fn is_library(&self) -> bool