pub enum Asset {
Fungible(FungibleAsset),
NonFungible(NonFungibleAsset),
}Expand description
A fungible or a non-fungible asset.
All assets are encoded using a single word (4 elements) such that it is easy to determine the type of an asset both inside and outside Miden VM. Specifically:
Element 1 of the asset will be:
- ZERO for a fungible asset.
- non-ZERO for a non-fungible asset.
Element 3 of both asset types is an AccountIdPrefix or equivalently, the prefix of an
AccountId, which can be used to distinguish assets
based on AccountIdPrefix::account_type.
For element 3 of the vault keys of assets, the bit at index 5 (referred to as the “fungible bit” will be):
1for a fungible asset.0for a non-fungible asset.
The above properties guarantee that there can never be a collision between a fungible and a non-fungible asset.
The methodology for constructing fungible and non-fungible assets is described below.
Fungible assets
- A fungible asset’s data layout is:
[amount, 0, faucet_id_suffix, faucet_id_prefix]. - A fungible asset’s vault key layout is:
[0, 0, faucet_id_suffix, faucet_id_prefix].
The most significant elements of a fungible asset are set to the prefix (faucet_id_prefix) and
suffix (faucet_id_suffix) of the ID of the faucet which issues the asset. This guarantees the
properties described above (the fungible bit is 1).
The least significant element is set to the amount of the asset. This amount cannot be greater
than FungibleAsset::MAX_AMOUNT and thus fits into a felt.
Elements 1 and 2 are set to ZERO.
It is impossible to find a collision between two fungible assets issued by different faucets as the faucet_id is included in the description of the asset and this is guaranteed to be different for each faucet as per the faucet creation logic.
Non-fungible assets
- A non-fungible asset’s data layout is:
[hash0, hash1, hash2, faucet_id_prefix]. - A non-fungible asset’s vault key layout is:
[faucet_id_prefix, hash1, hash2, hash0'], wherehash0'is equivalent tohash0with the fungible bit set to0. SeeNonFungibleAsset::vault_keyfor more details.
The 4 elements of non-fungible assets are computed as follows:
- First the asset data is hashed. This compresses an asset of an arbitrary length to 4 field
elements:
[hash0, hash1, hash2, hash3]. hash3is then replaced with the prefix of the faucet ID (faucet_id_prefix) which issues the asset:[hash0, hash1, hash2, faucet_id_prefix].
It is impossible to find a collision between two non-fungible assets issued by different faucets as the faucet_id is included in the description of the non-fungible asset and this is guaranteed to be different as per the faucet creation logic. Collision resistance for non-fungible assets issued by the same faucet is ~2^95.
Variants
Fungible(FungibleAsset)
NonFungible(NonFungibleAsset)
Implementations
Sourceimpl Asset
impl Asset
Sourcepub fn is_same(&self, other: &Asset) -> bool
pub fn is_same(&self, other: &Asset) -> bool
Returns true if this asset is the same as the specified asset.
Two assets are defined to be the same if:
- For fungible assets, if they were issued by the same faucet.
- For non-fungible assets, if the assets are identical.
Sourcepub const fn is_fungible(&self) -> bool
pub const fn is_fungible(&self) -> bool
Returns true if this asset is a fungible asset.
Sourcepub const fn is_non_fungible(&self) -> bool
pub const fn is_non_fungible(&self) -> bool
Returns true if this asset is a non fungible asset.
Sourcepub fn faucet_id_prefix(&self) -> AccountIdPrefix
pub fn faucet_id_prefix(&self) -> AccountIdPrefix
Returns the prefix of the faucet ID which issued this asset.
To get the full AccountId of a fungible asset the asset
must be matched on.
Sourcepub fn vault_key(&self) -> AssetVaultKey
pub fn vault_key(&self) -> AssetVaultKey
Returns the key which is used to store this asset in the account vault.
Sourcepub fn unwrap_fungible(&self) -> FungibleAsset
pub fn unwrap_fungible(&self) -> FungibleAsset
Sourcepub fn unwrap_non_fungible(&self) -> NonFungibleAsset
pub fn unwrap_non_fungible(&self) -> NonFungibleAsset