pub struct AccountStorageDelta { /* private fields */ }Expand description
The AccountStorageDelta stores the differences between two states of account storage.
The delta consists of a map from StorageSlotName to StorageSlotDelta.
Implementations
Sourceimpl AccountStorageDelta
impl AccountStorageDelta
Sourcepub fn new() -> AccountStorageDelta
pub fn new() -> AccountStorageDelta
Creates a new, empty storage delta.
Sourcepub fn from_raw(
deltas: BTreeMap<StorageSlotName, StorageSlotDelta>,
) -> AccountStorageDelta
pub fn from_raw( deltas: BTreeMap<StorageSlotName, StorageSlotDelta>, ) -> AccountStorageDelta
Creates a new storage delta from the provided slot deltas.
Sourcepub fn get(&self, slot_name: &StorageSlotName) -> Option<&StorageSlotDelta>
pub fn get(&self, slot_name: &StorageSlotName) -> Option<&StorageSlotDelta>
Returns the delta for the provided slot name, or None if no delta exists.
Sourcepub fn values(&self) -> impl Iterator<Item = (&StorageSlotName, &Word)>
pub fn values(&self) -> impl Iterator<Item = (&StorageSlotName, &Word)>
Returns an iterator over the updated values in this storage delta.
Sourcepub fn maps(&self) -> impl Iterator<Item = (&StorageSlotName, &StorageMapDelta)>
pub fn maps(&self) -> impl Iterator<Item = (&StorageSlotName, &StorageMapDelta)>
Returns an iterator over the updated maps in this storage delta.
Sourcepub fn set_item(
&mut self,
slot_name: StorageSlotName,
new_slot_value: Word,
) -> Result<(), AccountDeltaError>
pub fn set_item( &mut self, slot_name: StorageSlotName, new_slot_value: Word, ) -> Result<(), AccountDeltaError>
Tracks a slot change.
This does not (and cannot) validate that the slot name exists or that it points to a value slot in the corresponding account.
Errors
Returns an error if:
- the slot name points to an existing slot that is not of type value.
Sourcepub fn set_map_item(
&mut self,
slot_name: StorageSlotName,
key: Word,
new_value: Word,
) -> Result<(), AccountDeltaError>
pub fn set_map_item( &mut self, slot_name: StorageSlotName, key: Word, new_value: Word, ) -> Result<(), AccountDeltaError>
Tracks a map item change.
This does not (and cannot) validate that the slot name exists or that it points to a map slot in the corresponding account.
Errors
Returns an error if:
- the slot name points to an existing slot that is not of type map.
Sourcepub fn insert_empty_map_delta(&mut self, slot_name: StorageSlotName)
pub fn insert_empty_map_delta(&mut self, slot_name: StorageSlotName)
Inserts an empty storage map delta for the provided slot name.
This is useful for full state deltas to represent an empty map in the delta.
This overwrites the existing slot delta, if any.
Sourcepub fn merge(
&mut self,
other: AccountStorageDelta,
) -> Result<(), AccountDeltaError>
pub fn merge( &mut self, other: AccountStorageDelta, ) -> Result<(), AccountDeltaError>
Merges another delta into this one, overwriting any existing values.
Sourcepub fn into_map(self) -> BTreeMap<StorageSlotName, StorageSlotDelta>
pub fn into_map(self) -> BTreeMap<StorageSlotName, StorageSlotDelta>
Consumes self and returns the underlying map of the storage delta.