pub struct AccountVaultDelta { /* private fields */ }Expand description
AccountVaultDelta stores the difference between the initial and final account vault states.
The difference is represented as a map of AssetDeltas keyed by the ID of the asset they
change. The AssetId orders the assets in the same way as the in-kernel account delta.
Purpose
The purpose of a vault delta is to represent the changes to the vault that a transaction results
in and provide a way to commit to and sign these changes. Unlike an
AccountVaultPatch, a delta cannot be applied to an
account and multiple deltas cannot be merged, since that isn’t necessary for signing.
Limitations
The delta does not include the functionality to merge or split assets. This would mainly be needed to merge deltas, which isn’t supported. Additionally, once custom assets are supported, their merge and split logic will be defined in the issuing faucet, and the delta would not be able to (easily) invoke this logic.
Implementations
Sourceimpl AccountVaultDelta
impl AccountVaultDelta
Sourcepub const MAX_ASSETS_PER_DELTA_OP: u16 = 1024
pub const MAX_ASSETS_PER_DELTA_OP: u16 = 1024
Maximum number of added or removed assets in a vault delta.
Sourcepub fn new(
asset_deltas: impl IntoIterator<Item = AssetDelta>,
) -> Result<AccountVaultDelta, AccountDeltaError>
pub fn new( asset_deltas: impl IntoIterator<Item = AssetDelta>, ) -> Result<AccountVaultDelta, AccountDeltaError>
Validates and creates an AccountVaultDelta from the given asset deltas.
Errors
Returns an error if:
- the same asset is changed by more than one delta.
- the number of added or removed assets exceeds
Self::MAX_ASSETS_PER_DELTA_OP.
Sourcepub fn num_assets(&self) -> usize
pub fn num_assets(&self) -> usize
Returns the number of assets changed in this delta.
Sourcepub fn iter(&self) -> impl Iterator<Item = &AssetDelta>
pub fn iter(&self) -> impl Iterator<Item = &AssetDelta>
Returns an iterator over the asset deltas, sorted by asset ID.
Sourcepub fn added_assets(&self) -> impl Iterator<Item = Asset>
pub fn added_assets(&self) -> impl Iterator<Item = Asset>
Returns an iterator over the added assets in this delta.
Sourcepub fn removed_assets(&self) -> impl Iterator<Item = Asset>
pub fn removed_assets(&self) -> impl Iterator<Item = Asset>
Returns an iterator over the removed assets in this delta.