pub struct Asset { /* private fields */ }Expand description
Assets are encoded as an AssetId and an AssetValue, each encodable as one word.
The AssetId uniquely identifies the asset and contains the AccountId of the issuer and
the AssetClass, which can further divide a single account’s assets into different classes.
It also contains the AssetComposition, which describes how assets compose, meaning whether
they can be merged or split. For example, cominbing two fungible assets with the same ID and
amounts 3 and 4 into a single one with amount 7 is called “merging”. Splitting would be the
reverse operation.
It is impossible to find a collision between two fungible assets issued by different faucets as
the faucet ID is part of the asset’s ID and the protocol’s
AccountTree guarantees that account IDs are
globally unique.
Assets are generally opaque to the protocol, with the [FungibleAsset] being the exception.
It is built-in in the sense that the tx kernel knows how to merge and split such assets without
requiring a procedure call to the issuing account, which improves performance.
Fungible assets
All assets carrying AssetComposition::Fungible are interpreted as a fungible
asset, and this composition allows merging and splitting of assets.
- A fungible asset’s value layout is:
[amount, 0, 0, 0]. - A fungible asset’s ID layout is:
[0, 0, faucet_id_suffix_and_metadata, faucet_id_prefix].
Where:
amountis theAssetAmountthat the asset holds and cannot be greater thanAssetAmount::MAXand thus fits into a felt.- the remaining elements in the value word must be zero.
faucet_id_prefixis the prefix of the faucet ID which issues the asset.faucet_id_suffix_and_metadatais the suffix of the faucet ID which issues the asset and the asset metadata, which is the encoding version together with theAssetComposition. SeeAssetIdfor more details on the ID’s layout.- the asset class limbs must be zero, which means two instances of the same fungible asset have the same asset ID and will be merged together when stored in the same account’s vault.
Implementations
Sourceimpl Asset
impl Asset
Sourcepub fn new(id: AssetId, value: Word) -> Result<Asset, AssetError>
pub fn new(id: AssetId, value: Word) -> Result<Asset, AssetError>
Creates an asset from the provided ID and value.
The value of a fungible asset is validated, see FungibleAsset::from_id_and_value. The
value of any other asset is opaque to the protocol and therefore not validated.
Errors
Returns an error if:
- The asset is fungible and
FungibleAsset::from_id_and_valuefails.
Sourcepub fn from_id_and_value_words(
id: Word,
value: Word,
) -> Result<Asset, AssetError>
pub fn from_id_and_value_words( id: Word, value: Word, ) -> Result<Asset, AssetError>
Sourcepub fn is_same(&self, other: &Asset) -> bool
pub fn is_same(&self, other: &Asset) -> bool
Returns true if this asset is the same as the specified asset.
Two assets are defined to be the same if their asset IDs match.
Sourcepub fn is_fungible(&self) -> bool
pub fn is_fungible(&self) -> bool
Returns true if this asset has AssetComposition::Fungible, false otherwise.
Sourcepub fn is_non_fungible(&self) -> bool
pub fn is_non_fungible(&self) -> bool
Returns true if this asset has AssetComposition::None, false otherwise.
Sourcepub fn id(&self) -> AssetId
pub fn id(&self) -> AssetId
Returns the AssetId which uniquely identifies this asset in the account vault.
Sourcepub fn value(&self) -> AssetValue
pub fn value(&self) -> AssetValue
Returns the AssetValue of this asset.
Sourcepub fn to_id_word(&self) -> Word
pub fn to_id_word(&self) -> Word
Sourcepub fn to_value_word(&self) -> Word
pub fn to_value_word(&self) -> Word
Returns the asset’s value encoded to a Word.
Sourcepub fn as_elements(&self) -> [Felt; 8]
pub fn as_elements(&self) -> [Felt; 8]
Returns the asset encoded as elements.
The first four elements contain the asset ID and the last four elements contain the asset value.
Sourcepub fn as_fungible(&self) -> Option<FungibleAsset>
pub fn as_fungible(&self) -> Option<FungibleAsset>
Returns this asset as a FungibleAsset, or None if the asset is not a valid fungible
asset.
Sourcepub fn unwrap_fungible(&self) -> FungibleAsset
pub fn unwrap_fungible(&self) -> FungibleAsset