pub struct AssetAmount(/* private fields */);Expand description
A validated fungible asset amount.
Wraps a u64 that is guaranteed to be at most AssetAmount::MAX. This type is used in
FungibleAsset to ensure the amount is always valid.
Implementations
Sourceimpl AssetAmount
impl AssetAmount
Sourcepub const MAX: AssetAmount
pub const MAX: AssetAmount
The maximum value an asset amount can represent.
Equal to 2^63 - 2^31. This was chosen so that the amount fits as both a positive and negative value in a field element.
Sourcepub const ZERO: AssetAmount
pub const ZERO: AssetAmount
The zero amount.
Sourcepub fn new(amount: u64) -> Result<AssetAmount, AssetError>
pub fn new(amount: u64) -> Result<AssetAmount, AssetError>