pub struct AssetId { /* private fields */ }Expand description
The unique identifier of an Asset in the AssetVault.
Its Word layout is:
[
asset_class_suffix (64 bits),
asset_class_prefix (64 bits),
[faucet_id_suffix (56 bits) | reserved (6 bits) | composition (2 bits)],
faucet_id_prefix (64 bits)
]The composition is the discriminator between assets and so it is placed at a static offset much like the version in an account ID. This makes it slightly easier to change the asset metadata in the future without affecting identification of previous assets.
Use AssetId::hash to produce the corresponding AssetIdHash that is used as
the key in the asset vault’s underlying SMT. Hashing ensures a uniform distribution across
leaves regardless of how faucet IDs or asset classes are chosen.
Implementations
Sourceimpl AssetId
impl AssetId
Sourcepub const SERIALIZED_SIZE: usize = Word::SERIALIZED_SIZE
pub const SERIALIZED_SIZE: usize = Word::SERIALIZED_SIZE
Sourcepub fn new(
asset_class: AssetClass,
faucet_id: AccountId,
composition: AssetComposition,
) -> Result<AssetId, AssetError>
pub fn new( asset_class: AssetClass, faucet_id: AccountId, composition: AssetComposition, ) -> Result<AssetId, AssetError>
Creates an AssetId from its parts with the given AssetComposition.
Errors
Returns an error if:
- the asset class limbs are not zero when
compositionisAssetComposition::Fungible. - the composition is
AssetComposition::Custom, which is disallowed until its support is enabled in the tx kernel.
Sourcepub fn new_fungible(faucet_id: AccountId) -> AssetId
pub fn new_fungible(faucet_id: AccountId) -> AssetId
Constructs a fungible asset’s ID from a faucet ID.
Sourcepub fn to_word(&self) -> Word
pub fn to_word(&self) -> Word
Returns the word representation of the asset ID.
See the type-level documentation for details.
Sourcepub fn asset_class(&self) -> AssetClass
pub fn asset_class(&self) -> AssetClass
Returns the AssetClass of the asset ID that distinguishes different assets issued by
the same faucet.
Sourcepub fn faucet_id(&self) -> AccountId
pub fn faucet_id(&self) -> AccountId
Returns the AccountId of the faucet that issued the asset.
Sourcepub fn callback_flag(&self) -> AssetCallbackFlag
pub fn callback_flag(&self) -> AssetCallbackFlag
Returns the AssetCallbackFlag of the faucet that issued the asset.
Sourcepub fn composition(&self) -> AssetComposition
pub fn composition(&self) -> AssetComposition
Returns the AssetComposition of the asset ID.
Sourcepub fn hash(&self) -> AssetIdHash
pub fn hash(&self) -> AssetIdHash
Hashes this raw asset ID to produce the AssetIdHash used as the key in the asset
vault’s underlying SMT.