pub struct AssetVault { /* private fields */ }Expand description
A container for an unlimited number of assets.
An asset vault can contain an unlimited number of assets. The assets are stored in a Sparse
Merkle Tree, keyed by the hash of the AssetId (see AssetId::hash).
Hashing the raw asset ID gives a uniform leaf distribution: in particular it prevents
non-fungible assets issued by the same faucet from sharing a leaf, which would otherwise happen
because their raw asset IDs share their fourth element (the faucet ID prefix) - the element the
SMT uses to determine leaf membership.
The raw (unhashed) AssetIds are retained alongside the SMT to allow iteration and
proof reconstruction.
An asset vault can be reduced to a single hash which is the root of the Sparse Merkle Tree.
Implementations
Sourceimpl AssetVault
impl AssetVault
Sourcepub fn new(assets: &[Asset]) -> Result<AssetVault, AssetVaultError>
pub fn new(assets: &[Asset]) -> Result<AssetVault, AssetVaultError>
Returns a new AssetVault initialized with the provided assets.
Sourcepub fn get(&self, asset_id: AssetId) -> Option<Asset>
pub fn get(&self, asset_id: AssetId) -> Option<Asset>
Returns the asset corresponding to the provided asset ID, or None if the asset
doesn’t exist.
Sourcepub fn has_non_fungible_asset(
&self,
asset: NonFungibleAsset,
) -> Result<bool, AssetVaultError>
pub fn has_non_fungible_asset( &self, asset: NonFungibleAsset, ) -> Result<bool, AssetVaultError>
Returns true if the specified non-fungible asset is stored in this vault.
Sourcepub fn get_balance(&self, asset_id: AssetId) -> Result<AssetAmount, AssetError>
pub fn get_balance(&self, asset_id: AssetId) -> Result<AssetAmount, AssetError>
Returns the balance of the fungible asset identified by asset_id.
If the vault does not contain the asset, zero is returned.
Errors
Returns an error if asset_id’s composition is not AssetComposition::Fungible.
Sourcepub fn assets(&self) -> impl Iterator<Item = Asset>
pub fn assets(&self) -> impl Iterator<Item = Asset>
Returns an iterator over the assets stored in the vault.
Sourcepub fn inner_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
pub fn inner_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
Returns an iterator over the inner nodes of the underlying Smt.
Sourcepub fn open(&self, asset_id: AssetId) -> AssetWitness
pub fn open(&self, asset_id: AssetId) -> AssetWitness
Returns an opening of the leaf associated with asset_id.
The asset_id can be obtained with Asset::id.
Sourcepub fn num_leaves(&self) -> usize
pub fn num_leaves(&self) -> usize
Returns the number of non-empty leaves in the underlying Smt.
Note that this may return a different value from Self::num_assets() as a single leaf may contain more than one asset.
Sourcepub fn num_assets(&self) -> usize
pub fn num_assets(&self) -> usize
Returns the number of assets in this vault.
Note that this may return a different value from Self::num_leaves() as a single leaf may contain more than one asset.
Sourcepub fn apply_patch(
&mut self,
patch: &AccountVaultPatch,
) -> Result<(), AssetVaultError>
pub fn apply_patch( &mut self, patch: &AccountVaultPatch, ) -> Result<(), AssetVaultError>
Applies the specified patch to the asset vault.
This updates each asset that is contained in the patch to its new value.
Errors
Returns an error if the maximum number of leaves per asset is exceeded.
Sourcepub fn insert_asset(&mut self, asset: Asset) -> Result<Word, AssetVaultError>
pub fn insert_asset(&mut self, asset: Asset) -> Result<Word, AssetVaultError>
Inserts the specified asset into the vault, overwriting the asset value at the same asset ID. Returns the value of the asset previously.
Errors
- The maximum number of leaves per asset is exceeded.
Sourcepub fn add_asset(&mut self, asset: Asset) -> Result<Asset, AssetVaultError>
pub fn add_asset(&mut self, asset: Asset) -> Result<Asset, AssetVaultError>
Add the specified asset to the vault.
Errors
- If the total value of the added assets is greater than
FungibleAsset::MAX_AMOUNT. - If the vault already contains the same non-fungible asset.
- The maximum number of leaves per asset is exceeded.
Sourcepub fn remove_asset(
&mut self,
asset: Asset,
) -> Result<Option<Asset>, AssetVaultError>
pub fn remove_asset( &mut self, asset: Asset, ) -> Result<Option<Asset>, AssetVaultError>
Remove the specified asset from the vault and returns the remaining asset, if any.
- For fungible assets, returns
Some(Asset::Fungible(remaining))with the remaining balance (which may have amount 0). - For non-fungible assets, returns
Nonesince non-fungible assets are either fully present or absent.
Errors
- The fungible asset is not found in the vault.
- The amount of the fungible asset in the vault is less than the amount to be removed.
- The non-fungible asset is not found in the vault.