pub struct AssetWitness(/* private fields */);Expand description
A witness of an asset in an AssetVault.
It proves inclusion of a certain asset in the vault.
Implementations
Sourceimpl AssetWitness
impl AssetWitness
Sourcepub fn new(smt_proof: SmtProof) -> Result<AssetWitness, AssetError>
pub fn new(smt_proof: SmtProof) -> Result<AssetWitness, AssetError>
Creates a new AssetWitness from an SMT proof.
Errors
Returns an error if:
- any of the entries in the SMT leaf is not a valid asset.
- any of the entries’ vault keys does not match the expected vault key of the asset.
Sourcepub fn new_unchecked(smt_proof: SmtProof) -> AssetWitness
pub fn new_unchecked(smt_proof: SmtProof) -> AssetWitness
Creates a new AssetWitness from an SMT proof without checking that the proof contains
valid assets.
Prefer AssetWitness::new whenever possible.
Sourcepub fn authenticates_asset_vault_key(&self, vault_key: AssetVaultKey) -> bool
pub fn authenticates_asset_vault_key(&self, vault_key: AssetVaultKey) -> bool
Returns true if this AssetWitness authenticates the provided AssetVaultKey, i.e.
if its leaf index matches, false otherwise.
Sourcepub fn find(&self, vault_key: AssetVaultKey) -> Option<Asset>
pub fn find(&self, vault_key: AssetVaultKey) -> Option<Asset>
Searches for an Asset in the witness with the given vault_key.
Sourcepub fn assets(&self) -> impl Iterator<Item = Asset>
pub fn assets(&self) -> impl Iterator<Item = Asset>
Returns an iterator over the Assets in this witness.
Sourcepub fn authenticated_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
pub fn authenticated_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
Returns an iterator over every inner node of this witness’ merkle path.