FungibleAsset

Struct FungibleAsset 

pub struct FungibleAsset { /* private fields */ }
A fungible asset.

A fungible asset consists of a faucet ID of the faucet which issued the asset as well as the asset amount. Asset amount is guaranteed to be 2^63 - 1 or smaller.

Implementations

Source

impl FungibleAsset

pub const MAX_AMOUNT: u64

Specifies the maximum amount a fungible asset can represent.

This number was chosen so that it can be represented as a positive and negative number in a field element. See account_delta.masm for more details on how this number was chosen.

pub const SERIALIZED_SIZE: usize

The serialized size of a FungibleAsset in bytes.

Currently an account ID (15 bytes) plus an amount (u64).

pub const fn new( faucet_id: AccountId, amount: u64, ) -> Result<FungibleAsset, AssetError>

Returns a fungible asset instantiated with the provided faucet ID and amount.

Errors

Returns an error if:

  • The faucet_id is not a valid fungible faucet ID.
  • The provided amount is greater than 2^63 - 1.
pub fn faucet_id(&self) -> AccountId

Return ID of the faucet which issued this asset.

pub fn faucet_id_prefix(&self) -> AccountIdPrefix

Return ID prefix of the faucet which issued this asset.

pub fn amount(&self) -> u64

Returns the amount of this asset.

pub fn is_from_same_faucet(&self, other: &FungibleAsset) -> bool

Returns true if this and the other assets were issued from the same faucet.

pub fn vault_key(&self) -> AssetVaultKey

Returns the key which is used to store this asset in the account vault.

pub fn add(self, other: FungibleAsset) -> Result<FungibleAsset, AssetError>

Adds two fungible assets together and returns the result.

Errors

Returns an error if:

  • The assets were not issued by the same faucet.
  • The total value of assets is greater than or equal to 2^63.
pub fn sub(self, other: FungibleAsset) -> Result<FungibleAsset, AssetError>

Subtracts a fungible asset from another and returns the result.

Errors

Returns an error if:

  • The assets were not issued by the same faucet.
  • The final amount would be negative.