pub struct FungibleAssetDelta(/* private fields */);Expand description
A binary tree map of fungible asset balance changes in the account vault.
Implementations
Sourceimpl FungibleAssetDelta
impl FungibleAssetDelta
Sourcepub fn new(
map: BTreeMap<AccountId, i64>,
) -> Result<FungibleAssetDelta, AccountDeltaError>
pub fn new( map: BTreeMap<AccountId, i64>, ) -> Result<FungibleAssetDelta, AccountDeltaError>
Validates and creates a new fungible asset delta.
Errors
Returns an error if the delta does not pass the validation.
Sourcepub fn add(&mut self, asset: FungibleAsset) -> Result<(), AccountDeltaError>
pub fn add(&mut self, asset: FungibleAsset) -> Result<(), AccountDeltaError>
Sourcepub fn remove(&mut self, asset: FungibleAsset) -> Result<(), AccountDeltaError>
pub fn remove(&mut self, asset: FungibleAsset) -> Result<(), AccountDeltaError>
Sourcepub fn amount(&self, faucet_id: &AccountId) -> Option<i64>
pub fn amount(&self, faucet_id: &AccountId) -> Option<i64>
Returns the amount of the fungible asset with the given faucet ID.
Sourcepub fn num_assets(&self) -> usize
pub fn num_assets(&self) -> usize
Returns the number of fungible assets affected in the delta.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&AccountId, &i64)>
pub fn iter(&self) -> impl Iterator<Item = (&AccountId, &i64)>
Returns an iterator over the (key, value) pairs of the map.
Sourcepub fn merge(
&mut self,
other: FungibleAssetDelta,
) -> Result<(), AccountDeltaError>
pub fn merge( &mut self, other: FungibleAssetDelta, ) -> Result<(), AccountDeltaError>
Merges another delta into this one, overwriting any existing values.
The result is validated as part of the merge.
Errors
Returns an error if the result did not pass validation.