pub struct NonFungibleAsset { /* private fields */ }Expand description
A commitment to a non-fungible asset.
See Asset for details on how it is constructed.
NonFungibleAsset itself does not contain the actual asset data. The container for this data
is NonFungibleAssetDetails.
The non-fungible asset can have callbacks to the faucet enabled or disabled, depending on
AssetCallbackFlag. See AssetCallbacks for more details.
Implementations
Sourceimpl NonFungibleAsset
impl NonFungibleAsset
Sourcepub const SERIALIZED_SIZE: usize
pub const SERIALIZED_SIZE: usize
The serialized size of a NonFungibleAsset in bytes.
An account ID (15 bytes) plus a word (32 bytes) plus a callbacks flag (1 byte).
Sourcepub fn new(
details: &NonFungibleAssetDetails,
) -> Result<NonFungibleAsset, AssetError>
pub fn new( details: &NonFungibleAssetDetails, ) -> Result<NonFungibleAsset, AssetError>
Returns a non-fungible asset created from the specified asset details.
Errors
Returns an error if the provided faucet ID is not for a non-fungible asset faucet.
Sourcepub fn from_parts(
faucet_id: AccountId,
value: Word,
) -> Result<NonFungibleAsset, AssetError>
pub fn from_parts( faucet_id: AccountId, value: Word, ) -> Result<NonFungibleAsset, AssetError>
Return a non-fungible asset created from the specified faucet and using the provided hash of the asset’s data.
Hash of the asset’s data is expected to be computed from the binary representation of the asset’s data.
Errors
Returns an error if the provided faucet ID is not for a non-fungible asset faucet.
Sourcepub fn from_key_value(
key: AssetVaultKey,
value: Word,
) -> Result<NonFungibleAsset, AssetError>
pub fn from_key_value( key: AssetVaultKey, value: Word, ) -> Result<NonFungibleAsset, AssetError>
Creates a non-fungible asset from the provided key and value.
Errors
Returns an error if:
- The provided key does not contain a valid faucet ID.
- The provided key’s asset ID limbs are not equal to the provided value’s first and second element.
- The faucet ID is not a non-fungible faucet ID.
Sourcepub fn from_key_value_words(
key: Word,
value: Word,
) -> Result<NonFungibleAsset, AssetError>
pub fn from_key_value_words( key: Word, value: Word, ) -> Result<NonFungibleAsset, AssetError>
Creates a non-fungible asset from the provided key and value.
Prefer Self::from_key_value for more type safety.
Errors
Returns an error if:
- The provided key does not contain a valid faucet ID.
Self::from_key_valuefails.
Sourcepub fn with_callbacks(self, callbacks: AssetCallbackFlag) -> NonFungibleAsset
pub fn with_callbacks(self, callbacks: AssetCallbackFlag) -> NonFungibleAsset
Returns a copy of this asset with the given AssetCallbackFlag.
Sourcepub fn vault_key(&self) -> AssetVaultKey
pub fn vault_key(&self) -> AssetVaultKey
Returns the vault key of the NonFungibleAsset.
See Asset docs for details on the key.
Sourcepub fn callbacks(&self) -> AssetCallbackFlag
pub fn callbacks(&self) -> AssetCallbackFlag
Returns the AssetCallbackFlag of this asset.
Sourcepub fn to_key_word(&self) -> Word
pub fn to_key_word(&self) -> Word
Returns the asset’s key encoded to a Word.
Sourcepub fn to_value_word(&self) -> Word
pub fn to_value_word(&self) -> Word
Returns the asset’s value encoded to a Word.