pub struct NonFungibleAssetDelta(/* private fields */);Expand description
A binary tree map of non-fungible asset changes (addition and removal) in the account vault.
The LexicographicWord wrapper is necessary to order the assets in the same way as the
in-kernel account delta which uses a link map.
Implementations
Sourceimpl NonFungibleAssetDelta
impl NonFungibleAssetDelta
Sourcepub const fn new(
map: BTreeMap<LexicographicWord<NonFungibleAsset>, NonFungibleDeltaAction>,
) -> NonFungibleAssetDelta
pub const fn new( map: BTreeMap<LexicographicWord<NonFungibleAsset>, NonFungibleDeltaAction>, ) -> NonFungibleAssetDelta
Creates a new non-fungible asset delta.
Sourcepub fn add(&mut self, asset: NonFungibleAsset) -> Result<(), AccountDeltaError>
pub fn add(&mut self, asset: NonFungibleAsset) -> Result<(), AccountDeltaError>
Adds a new non-fungible asset to the delta.
Errors
Returns an error if the delta already contains the asset addition.
Sourcepub fn remove(
&mut self,
asset: NonFungibleAsset,
) -> Result<(), AccountDeltaError>
pub fn remove( &mut self, asset: NonFungibleAsset, ) -> Result<(), AccountDeltaError>
Removes a non-fungible asset from the delta.
Errors
Returns an error if the delta already contains the asset removal.
Sourcepub fn num_assets(&self) -> usize
pub fn num_assets(&self) -> usize
Returns the number of non-fungible assets affected in the delta.
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = (&NonFungibleAsset, &NonFungibleDeltaAction)>
pub fn iter( &self, ) -> impl Iterator<Item = (&NonFungibleAsset, &NonFungibleDeltaAction)>
Returns an iterator over the (key, value) pairs of the map.
Sourcepub fn merge(
&mut self,
other: NonFungibleAssetDelta,
) -> Result<(), AccountDeltaError>
pub fn merge( &mut self, other: NonFungibleAssetDelta, ) -> Result<(), AccountDeltaError>
Merges another delta into this one, overwriting any existing values.
The result is validated as part of the merge.
Errors
Returns an error if duplicate non-fungible assets are added or removed.