pub struct NonFungibleAssetDetails { /* private fields */ }Expand description
Details about a non-fungible asset.
Unlike NonFungibleAsset struct, this struct contains full details of a non-fungible asset.
Implementations
Sourceimpl NonFungibleAssetDetails
impl NonFungibleAssetDetails
Sourcepub fn new(
faucet_id: AccountIdPrefix,
asset_data: Vec<u8>,
) -> Result<NonFungibleAssetDetails, AssetError>
pub fn new( faucet_id: AccountIdPrefix, asset_data: Vec<u8>, ) -> Result<NonFungibleAssetDetails, AssetError>
Returns asset details instantiated from the specified faucet ID and asset data.
Errors
Returns an error if the provided faucet ID is not for a non-fungible asset faucet.
Sourcepub fn faucet_id(&self) -> AccountIdPrefix
pub fn faucet_id(&self) -> AccountIdPrefix
Returns ID of the faucet which issued this asset.
Sourcepub fn asset_data(&self) -> &[u8] ⓘ
pub fn asset_data(&self) -> &[u8] ⓘ
Returns asset data in binary format.