pub struct PartialVault { /* private fields */ }Expand description
A partial representation of an AssetVault, containing only proofs for a subset of assets.
Partial vault is used to provide verifiable access to specific assets in a vault without the need to provide the full vault data. It contains all required data for loading vault data into the transaction kernel for transaction execution.
Implementations
Sourceimpl PartialVault
impl PartialVault
Sourcepub fn new(root: Word) -> PartialVault
pub fn new(root: Word) -> PartialVault
Constructs a PartialVault from an AssetVault root.
For conversion from an AssetVault, prefer Self::new_minimal to be more explicit.
Sourcepub fn new_full(vault: AssetVault) -> PartialVault
pub fn new_full(vault: AssetVault) -> PartialVault
Converts an AssetVault into a partial vault representation.
The resulting PartialVault will contain the full merkle paths of the original asset
vault.
Sourcepub fn new_minimal(vault: &AssetVault) -> PartialVault
pub fn new_minimal(vault: &AssetVault) -> PartialVault
Converts an AssetVault into a partial vault representation.
The resulting PartialVault will represent the root of the asset vault, but not track any
key-value pairs, which means it is the most minimal representation of the asset vault.
Sourcepub fn inner_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
pub fn inner_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
Returns an iterator over all inner nodes in the Sparse Merkle Tree proofs.
This is useful for reconstructing parts of the Sparse Merkle Tree or for verification purposes.
Sourcepub fn leaves(&self) -> impl Iterator<Item = &SmtLeaf>
pub fn leaves(&self) -> impl Iterator<Item = &SmtLeaf>
Returns an iterator over all leaves in the Sparse Merkle Tree proofs.
Each item returned is a tuple containing the leaf index and a reference to the leaf.
Sourcepub fn open(
&self,
vault_key: AssetVaultKey,
) -> Result<AssetWitness, PartialAssetVaultError>
pub fn open( &self, vault_key: AssetVaultKey, ) -> Result<AssetWitness, PartialAssetVaultError>
Returns an opening of the leaf associated with vault_key.
The vault_key can be obtained with Asset::vault_key.
Errors
Returns an error if:
- the key is not tracked by this partial vault.
Sourcepub fn get(
&self,
vault_key: AssetVaultKey,
) -> Result<Option<Asset>, MerkleError>
pub fn get( &self, vault_key: AssetVaultKey, ) -> Result<Option<Asset>, MerkleError>
Sourcepub fn add(
&mut self,
witness: AssetWitness,
) -> Result<(), PartialAssetVaultError>
pub fn add( &mut self, witness: AssetWitness, ) -> Result<(), PartialAssetVaultError>
Adds an AssetWitness to this PartialVault.
Errors
Returns an error if:
- the new root after the insertion of the leaf and the path does not match the existing root (except when the first leaf is added).