pub struct StorageSlotHeader { /* private fields */ }Expand description
The header of a StorageSlot, storing only the slot name (or ID), slot type and value of the
slot.
The stored value differs based on the slot type:
StorageSlotType::Value: The value of the slot itself.StorageSlotType::Map: The root of the SMT that represents the storage map.
Implementations
Sourceimpl StorageSlotHeader
impl StorageSlotHeader
Sourcepub fn new(
name: StorageSlotName,
type: StorageSlotType,
value: Word,
) -> StorageSlotHeader
pub fn new( name: StorageSlotName, type: StorageSlotType, value: Word, ) -> StorageSlotHeader
Returns a new instance of storage slot header.
Sourcepub fn with_empty_value(name: StorageSlotName) -> StorageSlotHeader
pub fn with_empty_value(name: StorageSlotName) -> StorageSlotHeader
Returns a new instance of storage slot header with an empty value slot.
Sourcepub fn with_empty_map(name: StorageSlotName) -> StorageSlotHeader
pub fn with_empty_map(name: StorageSlotName) -> StorageSlotHeader
Returns a new instance of storage slot header with an empty map slot.
Sourcepub fn name(&self) -> &StorageSlotName
pub fn name(&self) -> &StorageSlotName
Returns a reference to the slot name.
Sourcepub fn id(&self) -> StorageSlotId
pub fn id(&self) -> StorageSlotId
Returns the slot ID.
Sourcepub fn slot_type(&self) -> StorageSlotType
pub fn slot_type(&self) -> StorageSlotType
Returns the slot type.