pub struct TokenSymbol(/* private fields */);Expand description
Represents a token symbol (e.g. “POL”, “ETH”).
Token Symbols can consist of up to 12 capital Latin characters, e.g. “C”, “ETH”, “MIDEN”.
The symbol is stored as a String and can be converted to a Felt encoding via
as_element().
Implementations
Sourceimpl TokenSymbol
impl TokenSymbol
Sourcepub const MAX_SYMBOL_LENGTH: usize = 12
pub const MAX_SYMBOL_LENGTH: usize = 12
Maximum allowed length of the token string.
Sourcepub const ALPHABET_LENGTH: u64 = 26
pub const ALPHABET_LENGTH: u64 = 26
The length of the set of characters that can be used in a token’s name.
Sourcepub const MIN_ENCODED_VALUE: u64 = 1
pub const MIN_ENCODED_VALUE: u64 = 1
The minimum integer value of an encoded TokenSymbol.
This value encodes the “A” token symbol.
Sourcepub const MAX_ENCODED_VALUE: u64 = 2481152873203736562
pub const MAX_ENCODED_VALUE: u64 = 2481152873203736562
The maximum integer value of an encoded TokenSymbol.
This value encodes the “ZZZZZZZZZZZZ” token symbol.
Sourcepub fn new_unchecked(symbol: &str) -> TokenSymbol
pub fn new_unchecked(symbol: &str) -> TokenSymbol
Constructs a new TokenSymbol from a string, panicking on invalid input.
Panics
Panics if:
- The length of the provided string is less than 1 or greater than 12.
- The provided token string contains characters that are not uppercase ASCII.
Sourcepub fn new(symbol: &str) -> Result<TokenSymbol, TokenSymbolError>
pub fn new(symbol: &str) -> Result<TokenSymbol, TokenSymbolError>
Creates a new TokenSymbol instance from the provided token name string.
Errors
Returns an error if:
- The length of the provided string is less than 1 or greater than 12.
- The provided token string contains characters that are not uppercase ASCII.
Sourcepub fn as_element(&self) -> Felt
pub fn as_element(&self) -> Felt
Returns the Felt encoding of this token symbol.
The alphabet used in the encoding process consists of the Latin capital letters as defined in the ASCII table, having the length of 26 characters.
The encoding is performed by multiplying the intermediate encoded value by the length of the used alphabet and adding the relative index of the character to it. At the end of the encoding process the length of the initial token string is added to the encoded value.
Relative character index is computed by subtracting the index of the character “A” (65)
from the index of the currently processing character, e.g., A = 65 - 65 = 0,
B = 66 - 65 = 1, ... , Z = 90 - 65 = 25.