Re-export the entire miden_client crate so external projects can use a single dependency.
Provides authentication-related types and functionalities for the Miden
network.
Structs
- Auth
Ecdsa K256 Keccak - An
AccountComponentimplementing the ECDSA K256 Keccak signature scheme for authentication of transactions. - Auth
Falcon512 Rpo - An
AccountComponentimplementing the Falcon512Rpo signature scheme for authentication of transactions. - Basic
Authenticator - Represents a signer for AuthSecretKey keys.
- NoAuth
- An
AccountComponentimplementing a no-authentication scheme. - Public
KeyCommitment - Commitment to a public key.
Enums
- Auth
Scheme - Defines authentication schemes available to standard and faucet accounts.
- Auth
Scheme Id - Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
- Auth
Secret Key - Secret keys of the standard
AuthSchemes available in the Miden protocol. - Public
Key - Public keys of the standard authentication schemes available in the Miden protocol.
- Signature
- Represents a signature object ready for native verification.
- Signing
Inputs - Data types on which a signature can be requested.
Constants
Traits
- Transaction
Authenticator - Defines an authenticator for transactions.