pub enum AuthScheme {
NoAuth,
EcdsaK256Keccak {
pub_key: PublicKeyCommitment,
},
EcdsaK256KeccakMultisig {
threshold: u32,
pub_keys: Vec<PublicKeyCommitment>,
},
Falcon512Rpo {
pub_key: PublicKeyCommitment,
},
Falcon512RpoMultisig {
threshold: u32,
pub_keys: Vec<PublicKeyCommitment>,
},
Unknown,
}Expand description
Defines authentication schemes available to standard and faucet accounts.
Variants
NoAuth
A minimal authentication scheme that provides no cryptographic authentication.
It only increments the nonce if the account state has actually changed during transaction execution, avoiding unnecessary nonce increments for transactions that don’t modify the account state.
EcdsaK256Keccak
A single-key authentication scheme which relies on ECDSA signatures.
Fields
pub_key: PublicKeyCommitmentEcdsaK256KeccakMultisig
A multi-signature authentication scheme using ECDSA signatures.
Requires a threshold number of signatures from the provided public keys.
Falcon512Rpo
A single-key authentication scheme which relies Falcon512 RPO signatures.
Falcon512 RPO is a variant of the Falcon signature scheme. This variant differs from the standard in that instead of using SHAKE256 hash function in the hash-to-point algorithm we use RPO256. This makes the signature more efficient to verify in Miden VM.
Fields
pub_key: PublicKeyCommitmentFalcon512RpoMultisig
A multi-signature authentication scheme using Falcon512 RPO signatures.
Requires a threshold number of signatures from the provided public keys.
Unknown
A non-standard authentication scheme.
Implementations
Sourceimpl AuthScheme
impl AuthScheme
Sourcepub fn get_public_key_commitments(&self) -> Vec<PublicKeyCommitment>
pub fn get_public_key_commitments(&self) -> Vec<PublicKeyCommitment>
Returns all public key commitments associated with this authentication scheme.
For unknown schemes, an empty vector is returned.