#[non_exhaustive]#[repr(u8)]pub enum AuthSchemeId {
Falcon512Rpo = 0,
EcdsaK256Keccak = 1,
}Expand description
Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Falcon512Rpo = 0
A deterministic Falcon512 signature scheme.
This version differs from the reference Falcon512 implementation in its use of the RPO algebraic hash function in its hash-to-point algorithm to make signatures very efficient to verify inside Miden VM.
EcdsaK256Keccak = 1
ECDSA signature scheme over secp256k1 curve using Keccak to hash the messages when signing.
Implementations