#[non_exhaustive]#[repr(u8)]pub enum AuthSecretKey {
Falcon512Rpo(SecretKey),
EcdsaK256Keccak(SecretKey),
}Expand description
Secret keys of the standard AuthSchemes available in the Miden protocol.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Implementations
Sourceimpl AuthSecretKey
impl AuthSecretKey
Sourcepub fn new_falcon512_rpo() -> AuthSecretKey
pub fn new_falcon512_rpo() -> AuthSecretKey
Generates an Falcon512Rpo secret key from the OS-provided randomness.
Sourcepub fn new_falcon512_rpo_with_rng<R>(rng: &mut R) -> AuthSecretKeywhere
R: Rng,
pub fn new_falcon512_rpo_with_rng<R>(rng: &mut R) -> AuthSecretKeywhere
R: Rng,
Generates an Falcon512Rpo secrete key using the provided random number generator.
Sourcepub fn new_ecdsa_k256_keccak() -> AuthSecretKey
pub fn new_ecdsa_k256_keccak() -> AuthSecretKey
Generates an EcdsaK256Keccak secret key from the OS-provided randomness.
Sourcepub fn new_ecdsa_k256_keccak_with_rng<R>(rng: &mut R) -> AuthSecretKey
pub fn new_ecdsa_k256_keccak_with_rng<R>(rng: &mut R) -> AuthSecretKey
Generates an EcdsaK256Keccak secret key using the provided random number generator.
Sourcepub fn auth_scheme(&self) -> AuthScheme
pub fn auth_scheme(&self) -> AuthScheme
Returns the authentication scheme of this secret key.
Sourcepub fn public_key(&self) -> PublicKey
pub fn public_key(&self) -> PublicKey
Returns a public key associated with this secret key.