#[repr(u8)]pub enum Signature {
Falcon512Rpo(Signature),
EcdsaK256Keccak(Signature),
}Expand description
Represents a signature object ready for native verification.
In order to use this signature within the Miden VM, a preparation step may be necessary to
convert the native signature into a vector of field elements that can be loaded into the advice
provider. To prepare the signature, use the provided to_prepared_signature method:
use miden_protocol::account::auth::Signature;
use miden_protocol::crypto::dsa::falcon512_rpo::SecretKey;
use miden_protocol::{Felt, Word};
let secret_key = SecretKey::new();
let message = Word::default();
let signature: Signature = secret_key.sign(message).into();
let prepared_signature: Vec<Felt> = signature.to_prepared_signature(message);Variants
Implementations
Sourceimpl Signature
impl Signature
Sourcepub fn auth_scheme(&self) -> AuthScheme
pub fn auth_scheme(&self) -> AuthScheme
Returns the authentication scheme of this signature.
Sourcepub fn to_prepared_signature(&self, msg: Word) -> Vec<BaseElement>
pub fn to_prepared_signature(&self, msg: Word) -> Vec<BaseElement>
Converts this signature to a sequence of field elements in the format expected by the native verification procedure in the VM.
The order of elements in the returned vector is reversed because it is expected that the data will be pushed into the advice stack