pub struct AuthFalcon512Rpo { /* private fields */ }Expand description
An AccountComponent implementing the Falcon512Rpo signature scheme for authentication of
transactions.
It reexports the procedures from miden::standards::auth::falcon512_rpo. When linking against
this component, the miden library (i.e. ProtocolLib) must
be available to the assembler which is the case when using CodeBuilder. The
procedures of this component are:
verify_signatures, which can be used to verify a signature provided via the advice stack to authenticate a transaction.authenticate_transaction, which can be used to authenticate a transaction using the Falcon signature scheme.
This component supports all account types.
Storage Layout
Self::public_key_slot: Public key
Implementations
Sourceimpl AuthFalcon512Rpo
impl AuthFalcon512Rpo
Sourcepub fn new(pub_key: PublicKeyCommitment) -> AuthFalcon512Rpo
pub fn new(pub_key: PublicKeyCommitment) -> AuthFalcon512Rpo
Creates a new AuthFalcon512Rpo component with the given public_key.
Sourcepub fn public_key_slot() -> &'static StorageSlotName
pub fn public_key_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the public key is stored.