pub struct AuthSingleSig { /* private fields */ }Expand description
An AccountComponent implementing the signature scheme for authentication
of transactions.
This component exports auth_tx, which loads the public key and signature scheme id from
storage and delegates transaction authentication to
miden::standards::auth::signature::authenticate_transaction.
When linking against this component, the miden::standards library must be available to the
assembler (which also implies availability of miden::protocol). This is the case when using
CodeBuilder.
This component supports all account types.
Implementations
Sourceimpl AuthSingleSig
impl AuthSingleSig
Sourcepub fn new(
pub_key: PublicKeyCommitment,
auth_scheme: AuthScheme,
) -> AuthSingleSig
pub fn new( pub_key: PublicKeyCommitment, auth_scheme: AuthScheme, ) -> AuthSingleSig
Creates a new AuthSingleSig component with the given public_key.
Sourcepub fn public_key_slot() -> &'static StorageSlotName
pub fn public_key_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the public key is stored.
pub fn scheme_id_slot() -> &'static StorageSlotName
Sourcepub fn public_key_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn public_key_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the public key slot.
Sourcepub fn auth_scheme_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn auth_scheme_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the scheme ID slot.