pub struct BasicAuthenticator { /* private fields */ }Expand description
Represents a signer for AuthSecretKey keys.
Implementations
Sourceimpl BasicAuthenticator
impl BasicAuthenticator
pub fn new(keys: &[AuthSecretKey]) -> BasicAuthenticator
pub fn from_key_pairs(keys: &[(AuthSecretKey, PublicKey)]) -> BasicAuthenticator
Sourcepub fn keys(&self) -> &BTreeMap<PublicKeyCommitment, (AuthSecretKey, PublicKey)>
pub fn keys(&self) -> &BTreeMap<PublicKeyCommitment, (AuthSecretKey, PublicKey)>
Returns a reference to the keys map.
Map keys represent the public key commitments, and values represent the (secret_key, public_key) pair that the authenticator would use to sign messages.