Re-export the entire miden_client crate so external projects can use a single dependency.
Provides types for working with blocks within the Miden network.
Structs
- Block
Header - The header of a block. It contains metadata about the block, commitments to the current state of the chain and the hash of the proof that attests to the integrity of the chain.
- Block
Number - A convenience wrapper around a
u32representing the number of a block. - FeeParameters
- The fee-related parameters of a block.
- Validator
Keys - The ordered set of validator public keys authorized to sign a block.