pub struct BlockNumber(/* private fields */);Expand description
A convenience wrapper around a u32 representing the number of a block.
Each block has a unique number and block numbers increase monotonically by 1.
Implementations
Sourceimpl BlockNumber
impl BlockNumber
Sourcepub const EPOCH_LENGTH_EXPONENT: u8 = 16
pub const EPOCH_LENGTH_EXPONENT: u8 = 16
The length of an epoch expressed as a power of two. 2^(EPOCH_LENGTH_EXPONENT) is the
number of blocks in an epoch.
The epoch of a block can be obtained by shifting the block number to the right by this exponent.
Sourcepub const GENESIS: BlockNumber
pub const GENESIS: BlockNumber
The block height of the genesis block.
Sourcepub fn parent(self) -> Option<BlockNumber>
pub fn parent(self) -> Option<BlockNumber>
Returns the previous block number
Sourcepub fn child(self) -> BlockNumber
pub fn child(self) -> BlockNumber
Returns the next block number
Sourcepub const fn from_epoch(epoch: u16) -> BlockNumber
pub const fn from_epoch(epoch: u16) -> BlockNumber
Creates the BlockNumber corresponding to the epoch block for the provided epoch.
Sourcepub const fn block_epoch(&self) -> u16
pub const fn block_epoch(&self) -> u16
Returns the epoch to which this block number belongs.
Sourcepub fn checked_sub(&self, rhs: u32) -> Option<BlockNumber>
pub fn checked_sub(&self, rhs: u32) -> Option<BlockNumber>
Checked integer subtraction. Computes self - rhs, returning None if underflow occurred.