pub struct FeeParameters { /* private fields */ }Expand description
The fee-related parameters of a block.
This defines how to compute the fees of a transaction and which asset fees can be paid in.
The fee asset is assumed to be a fungible asset
(AssetComposition::Fungible).
Implementations
Sourceimpl FeeParameters
impl FeeParameters
Sourcepub fn new(
fee_faucet_id: AccountId,
verification_base_fee: u32,
) -> FeeParameters
pub fn new( fee_faucet_id: AccountId, verification_base_fee: u32, ) -> FeeParameters
Creates FeeParameters from the provided inputs.
Sourcepub fn fee_faucet_id(&self) -> AccountId
pub fn fee_faucet_id(&self) -> AccountId
Returns the AccountId of the faucet whose assets are accepted for fee payments in the
transaction kernel, or in other words, the fee faucet of the blockchain.
Sourcepub fn verification_base_fee(&self) -> u32
pub fn verification_base_fee(&self) -> u32
Returns the base fee capturing the cost for the verification of a transaction.