Module builder

Module builder 

Re-export the entire miden_client crate so external projects can use a single dependency.

Structs

ClientBuilder
A builder for constructing a Miden client.
NoteTransportConfig
Configuration for lazy note transport initialization.
RemoteTransactionProver
A RemoteTransactionProver is a transaction prover that sends witness data to a remote gRPC server and receives a proven transaction.

Enums

StoreBuilder
Allows the ClientBuilder to accept either an already built store instance or a factory for deferring the store instantiation.

Constants

DEVNET_PROVER_ENDPOINT
Default remote prover endpoint for devnet.
NOTE_TRANSPORT_DEFAULT_TIMEOUT_MS
Default timeout for note transport connections (10 seconds).
TESTNET_PROVER_ENDPOINT
Default remote prover endpoint for testnet.

Traits

BuilderAuthenticator
Marker trait to capture the bounds the builder requires for the authenticator type parameter.
StoreFactory
Trait for building a store instance.