pub struct ClientBuilder<AUTH> {
pub store: Option<StoreBuilder>,
/* private fields */
}Expand description
A builder for constructing a Miden client.
This builder allows you to configure the various components required by the client, such as the
RPC endpoint, store, RNG, and keystore. It is generic over the keystore type. By default, it
uses FilesystemKeyStore.
Fields
store: Option<StoreBuilder>An optional store provided by the user.
Implementations
Sourceimpl<AUTH> ClientBuilder<AUTH>where
AUTH: BuilderAuthenticator,
impl<AUTH> ClientBuilder<AUTH>where
AUTH: BuilderAuthenticator,
Sourcepub fn new() -> ClientBuilder<AUTH>
pub fn new() -> ClientBuilder<AUTH>
Create a new ClientBuilder with default settings.
Sourcepub fn in_debug_mode(self, debug: DebugMode) -> ClientBuilder<AUTH>
pub fn in_debug_mode(self, debug: DebugMode) -> ClientBuilder<AUTH>
Enable or disable debug mode.
Sourcepub fn rpc(self, client: Arc<dyn NodeRpcClient>) -> ClientBuilder<AUTH>
pub fn rpc(self, client: Arc<dyn NodeRpcClient>) -> ClientBuilder<AUTH>
Sets a custom RPC client directly.
Sourcepub fn grpc_client(
self,
endpoint: &Endpoint,
timeout_ms: Option<u64>,
) -> ClientBuilder<AUTH>
pub fn grpc_client( self, endpoint: &Endpoint, timeout_ms: Option<u64>, ) -> ClientBuilder<AUTH>
Sets a gRPC client from the endpoint and optional timeout.
Sourcepub fn store(self, store: Arc<dyn Store>) -> ClientBuilder<AUTH>
pub fn store(self, store: Arc<dyn Store>) -> ClientBuilder<AUTH>
Provide a store to be used by the client.
Sourcepub fn rng(self, rng: Box<dyn ClientFeltRng>) -> ClientBuilder<AUTH>
pub fn rng(self, rng: Box<dyn ClientFeltRng>) -> ClientBuilder<AUTH>
Optionally provide a custom RNG.
Sourcepub fn authenticator(self, authenticator: Arc<AUTH>) -> ClientBuilder<AUTH>
pub fn authenticator(self, authenticator: Arc<AUTH>) -> ClientBuilder<AUTH>
Optionally provide a custom authenticator instance.
Sourcepub fn max_block_number_delta(self, delta: u32) -> ClientBuilder<AUTH>
pub fn max_block_number_delta(self, delta: u32) -> ClientBuilder<AUTH>
Optionally set a maximum number of blocks that the client can be behind the network. By default, there’s no maximum.
Sourcepub fn tx_graceful_blocks(self, delta: Option<u32>) -> ClientBuilder<AUTH>
pub fn tx_graceful_blocks(self, delta: Option<u32>) -> ClientBuilder<AUTH>
Optionally set a maximum number of blocks to wait for a transaction to be confirmed. If
None, there is no limit and transactions will be kept indefinitely.
By default, the maximum is set to TX_GRACEFUL_BLOCKS.
Sourcepub fn filesystem_keystore(self, keystore_path: &str) -> ClientBuilder<AUTH>
pub fn filesystem_keystore(self, keystore_path: &str) -> ClientBuilder<AUTH>
Required: Provide the keystore path as a string.
This stores the keystore path as a configuration option so that actual keystore
initialization is deferred until build(). This avoids panicking during builder chaining.
Sourcepub fn note_transport(
self,
client: Arc<dyn NoteTransportClient>,
) -> ClientBuilder<AUTH>
pub fn note_transport( self, client: Arc<dyn NoteTransportClient>, ) -> ClientBuilder<AUTH>
Sets a custom note transport client directly.
Sourcepub fn prover(
self,
prover: Arc<dyn TransactionProver + Sync + Send>,
) -> ClientBuilder<AUTH>
pub fn prover( self, prover: Arc<dyn TransactionProver + Sync + Send>, ) -> ClientBuilder<AUTH>
Sets a custom transaction prover.