Re-export the entire miden_client crate so external projects can use a single dependency.
Provides cryptographic types and utilities used within the Miden rollup
network. It re-exports commonly used types and random number generators like FeltRng from
the miden_standards crate.
Modules
Structs
- Blake3
Digest - N-bytes output of a blake3 function.
- Blake3_
160 - 160-bit output blake3 hasher.
- Forest
- A compact representation of trees in a forest. Used in the Merkle forest (MMR).
- InOrder
Index - Index of nodes in a perfectly balanced binary tree based on an in-order tree walk.
- Leaf
Index - The index of a leaf, at a depth known at compile-time.
- Merkle
Path - A merkle path container, composed of a sequence of nodes of a Merkle tree.
- Merkle
Store - An in-memory data store for Merkelized data.
- Merkle
Tree - A fully-balanced binary Merkle tree (i.e., a tree where the number of leaves is a power of two).
- MmrDelta
- Container for the update data of a super::PartialMmr
- MmrPeaks
- MmrProof
- Node
Index - Address to an arbitrary node in a binary tree using level order form.
- Partial
Mmr - Partially materialized Merkle Mountain Range (MMR), used to efficiently store and update the authentication paths for a subset of the elements in a full MMR.
- Rpo256
- Implementation of the Rescue Prime Optimized hash function with 256-bit output.
- RpoRandom
Coin - A simplified version of the
SPONGE_PRGreseedable pseudo-random number generator algorithm described in https://eprint.iacr.org/2011/499.pdf. - SmtProof
- A proof which can be used to assert membership (or non-membership) of key-value pairs
in a
super::Smt(Sparse Merkle Tree). - Sparse
Merkle Path - A different representation of
MerklePathdesigned for memory efficiency for Merkle paths with empty nodes.
Enums
- SmtLeaf
- Represents a leaf node in the Sparse Merkle Tree.
Constants
- SMT_
DEPTH - The depth of the sparse Merkle tree.
Traits
- FeltRng
- Pseudo-random element generator.