pub struct PublicKey { /* private fields */ }Expand description
Public key for ECDSA signature verification over secp256k1 curve.
Implementations
Sourceimpl PublicKey
impl PublicKey
Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Returns a commitment to the public key using the Poseidon2 hash function.
Public key serialization remains compressed SEC1. The commitment preimage is not the
compressed SEC1 encoding; it is qx || qy, where each secp256k1 affine coordinate is
represented as eight little-endian numeric u32 limbs, one limb per Felt.
Sourcepub fn as_affine(&self) -> &AffinePoint
pub fn as_affine(&self) -> &AffinePoint
Returns a reference to this public key as an elliptic curve point in affine coordinates.
Sourcepub fn verify(&self, message: Word, signature: &Signature) -> bool
pub fn verify(&self, message: Word, signature: &Signature) -> bool
Verifies a signature against this public key and message.
Sourcepub fn verify_prehash(
&self,
message_digest: [u8; 32],
signature: &Signature,
) -> bool
pub fn verify_prehash( &self, message_digest: [u8; 32], signature: &Signature, ) -> bool
Verifies a signature against this public key and pre-hashed message.
Sourcepub fn recover_from(
message: Word,
signature: &Signature,
) -> Result<PublicKey, PublicKeyError>
pub fn recover_from( message: Word, signature: &Signature, ) -> Result<PublicKey, PublicKeyError>
Recovers from the signature the public key associated to the secret key used to sign the message.