pub struct SigningKey(/* private fields */);Expand description
A secret key for ECDSA signature verification over the secp256k1 curve.
Implementations
Sourceimpl SigningKey
impl SigningKey
Sourcepub fn new() -> SigningKey
pub fn new() -> SigningKey
Generates a new random signing key using the OS random number generator.
This is cryptographically secure as long as rand::rng remains so.
Sourcepub fn with_rng<R>(rng: &mut R) -> SigningKeywhere
R: CryptoRng,
pub fn with_rng<R>(rng: &mut R) -> SigningKeywhere
R: CryptoRng,
Generates a new signing key using the provided random number generator.
Sourcepub fn public_key(&self) -> PublicKey
pub fn public_key(&self) -> PublicKey
Gets the public key that corresponds to this signing key.
Sourcepub fn sign(&self, message: Word) -> Signature
pub fn sign(&self, message: Word) -> Signature
Signs a message (represented as a word) with this signing key.
Sourcepub fn sign_prehash(&self, message_digest: [u8; 32]) -> Signature
pub fn sign_prehash(&self, message_digest: [u8; 32]) -> Signature
Signs a pre-hashed message with this signing key.