pub struct KeyExchangeKey(/* private fields */);Expand description
A key for ECDH key exchange over Curve25519
Implementations
Sourceimpl KeyExchangeKey
impl KeyExchangeKey
Sourcepub fn new() -> KeyExchangeKey
pub fn new() -> KeyExchangeKey
Generates a new random key exchange key using the OS random number generator.
This is cryptographically secure as long as rand::rng remains so.
Sourcepub fn with_rng<R>(rng: &mut R) -> KeyExchangeKeywhere
R: CryptoRng,
pub fn with_rng<R>(rng: &mut R) -> KeyExchangeKeywhere
R: CryptoRng,
Generates a new secret key using RNG.
Sourcepub fn public_key(&self) -> PublicKey
pub fn public_key(&self) -> PublicKey
Gets the corresponding public key for this secret key.
Computes a Diffie-Hellman shared secret from this secret key and the ephemeral public key generated by the other party.