pub struct InOrderIndex { /* private fields */ }Expand description
Index of nodes in a perfectly balanced binary tree based on an in-order tree walk.
Implementations
Sourceimpl InOrderIndex
impl InOrderIndex
Sourcepub fn new(idx: NonZero<usize>) -> InOrderIndex
pub fn new(idx: NonZero<usize>) -> InOrderIndex
Returns a new InOrderIndex instantiated from the provided value.
Sourcepub fn from_leaf_pos(leaf: usize) -> InOrderIndex
pub fn from_leaf_pos(leaf: usize) -> InOrderIndex
Return a new InOrderIndex instantiated from the specified leaf position.
Panics:
If leaf is higher than or equal to usize::MAX / 2.
Sourcepub fn is_leaf(&self) -> bool
pub fn is_leaf(&self) -> bool
True if the index is pointing at a leaf.
Every odd number represents a leaf.
Sourcepub fn is_left_child(&self) -> bool
pub fn is_left_child(&self) -> bool
Returns true if this note is a left child of its parent.
Sourcepub fn level(&self) -> u32
pub fn level(&self) -> u32
Returns the level of the index.
Starts at level zero for leaves and increases by one for each parent.
Sourcepub fn left_child(&self) -> InOrderIndex
pub fn left_child(&self) -> InOrderIndex
Sourcepub fn right_child(&self) -> InOrderIndex
pub fn right_child(&self) -> InOrderIndex
Sourcepub fn parent(&self) -> InOrderIndex
pub fn parent(&self) -> InOrderIndex
Returns the index of the parent node.
Sourcepub fn sibling(&self) -> InOrderIndex
pub fn sibling(&self) -> InOrderIndex
Returns the index of the sibling node.
Sourcepub fn inner(&self) -> usize
pub fn inner(&self) -> usize
Returns the inner value of this InOrderIndex.