pub struct MmrProof { /* private fields */ }Implementations
Sourceimpl MmrProof
impl MmrProof
Sourcepub fn new(path: MmrPath, leaf: Word) -> MmrProof
pub fn new(path: MmrPath, leaf: Word) -> MmrProof
Creates a new MmrProof with the given path and leaf.
Sourcepub fn path(&self) -> &MmrPath
pub fn path(&self) -> &MmrPath
Returns the Merkle path data describing how to authenticate the leaf.
Sourcepub fn merkle_path(&self) -> &MerklePath
pub fn merkle_path(&self) -> &MerklePath
Returns the Merkle opening, starting from the value’s sibling up to and excluding the root of the responsible tree.
Sourcepub fn relative_pos(&self) -> usize
pub fn relative_pos(&self) -> usize
Converts the leaf global position into a local position that can be used to verify the merkle_path.
Sourcepub fn peak_index(&self) -> usize
pub fn peak_index(&self) -> usize
Returns index of the MMR peak against which the Merkle path in this proof can be verified.
Sourcepub fn with_forest(&self, target_forest: Forest) -> Result<MmrProof, MmrError>
pub fn with_forest(&self, target_forest: Forest) -> Result<MmrProof, MmrError>
Returns a new MmrProof adjusted for a smaller target forest.
This is useful when receiving authenticated data from a larger MMR and needing to adjust the proof for a smaller MMR. The path is trimmed to include only the nodes relevant for the target forest.
Errors
Returns an error if:
- The target forest does not include this proof’s position
- The target forest is larger than the current forest