PartialMmr

Struct PartialMmr 

pub struct PartialMmr { /* private fields */ }
Partially materialized Merkle Mountain Range (MMR), used to efficiently store and update the authentication paths for a subset of the elements in a full MMR.

This structure store only the authentication path for a value, the value itself is stored separately.

Implementations

Source

impl PartialMmr

pub fn from_peaks(peaks: MmrPeaks) -> PartialMmr

Returns a new PartialMmr instantiated from the specified peaks.

pub fn from_parts( peaks: MmrPeaks, nodes: BTreeMap<InOrderIndex, Word>, track_latest: bool, ) -> PartialMmr

Returns a new PartialMmr instantiated from the specified components.

This constructor does not check the consistency between peaks and nodes. If the specified peaks are nodes are inconsistent, the returned partial MMR may exhibit undefined behavior.

pub fn forest(&self) -> Forest

Returns the current forest of this PartialMmr.

This value corresponds to the version of the PartialMmr and the number of leaves in the underlying MMR.

pub fn num_leaves(&self) -> usize

Returns the number of leaves in the underlying MMR for this PartialMmr.

pub fn peaks(&self) -> MmrPeaks

Returns the peaks of the MMR for this PartialMmr.

pub fn is_tracked(&self, pos: usize) -> bool

Returns true if this partial MMR tracks an authentication path for the leaf at the specified position.

pub fn open(&self, pos: usize) -> Result<Option<MmrProof>, MmrError>

Given a leaf position, returns the Merkle path to its corresponding peak, or None if this partial MMR does not track an authentication paths for the specified leaf.

Note: The leaf position is the 0-indexed number corresponding to the order the leaves were added, this corresponds to the MMR size prior to adding the element. So the 1st element has position 0, the second position 1, and so on.

Errors

Returns an error if the specified position is greater-or-equal than the number of leaves in the underlying MMR.

pub fn nodes(&self) -> impl Iterator<Item = (&InOrderIndex, &Word)>

Returns an iterator nodes of all authentication paths of this PartialMmr.

pub fn inner_nodes<'a, I>( &'a self, leaves: I, ) -> impl Iterator<Item = InnerNodeInfo> + 'a
where I: Iterator<Item = (usize, Word)> + 'a,

Returns an iterator over inner nodes of this PartialMmr for the specified leaves.

The order of iteration is not defined. If a leaf is not presented in this partial MMR it is silently ignored.

pub fn add(&mut self, leaf: Word, track: bool) -> Vec<(InOrderIndex, Word)>

Adds a new peak and optionally track it. Returns a vector of the authentication nodes inserted into this PartialMmr as a result of this operation.

When track is true the new leaf is tracked.

pub fn track( &mut self, leaf_pos: usize, leaf: Word, path: &MerklePath, ) -> Result<(), MmrError>

Adds the authentication path represented by MerklePath if it is valid.

The leaf_pos refers to the global position of the leaf in the MMR, these are 0-indexed values assigned in a strictly monotonic fashion as elements are inserted into the MMR, this value corresponds to the values used in the MMR structure.

The leaf corresponds to the value at leaf_pos, and path is the authentication path for that element up to its corresponding Mmr peak. The leaf is only used to compute the root from the authentication path to valid the data, only the authentication data is saved in the structure. If the value is required it should be stored out-of-band.

pub fn untrack(&mut self, leaf_pos: usize)

Removes a leaf of the PartialMmr and the unused nodes from the authentication path.

Note: leaf_pos corresponds to the position in the MMR and not on an individual tree.

pub fn apply( &mut self, delta: MmrDelta, ) -> Result<Vec<(InOrderIndex, Word)>, MmrError>

Applies updates to this PartialMmr and returns a vector of new authentication nodes inserted into the partial MMR.