pub struct RpoRandomCoin { /* private fields */ }Expand description
A simplified version of the SPONGE_PRG reseedable pseudo-random number generator algorithm
described in https://eprint.iacr.org/2011/499.pdf.
The simplification is related to the following facts:
- A call to the reseed method implies one and only one call to the permutation function. This is possible because in our case we never reseed with more than 4 field elements.
- As a result of the previous point, we don’t make use of an input buffer to accumulate seed material.
Implementations
Sourceimpl RpoRandomCoin
impl RpoRandomCoin
Sourcepub fn new(seed: Word) -> RpoRandomCoin
pub fn new(seed: Word) -> RpoRandomCoin
Returns a new RpoRandomCoin initialize with the specified seed.
Sourcepub fn from_parts(state: [BaseElement; 12], current: usize) -> RpoRandomCoin
pub fn from_parts(state: [BaseElement; 12], current: usize) -> RpoRandomCoin
Returns an RpoRandomCoin instantiated from the provided components.
Panics
Panics if current is smaller than 4 or greater than or equal to 12.
Sourcepub fn into_parts(self) -> ([BaseElement; 12], usize)
pub fn into_parts(self) -> ([BaseElement; 12], usize)
Returns components of this random coin.
Sourcepub fn fill_bytes(&mut self, dest: &mut [u8])
pub fn fill_bytes(&mut self, dest: &mut [u8])
Fills dest with random data.