pub struct SmtProof { /* private fields */ }Expand description
A proof which can be used to assert membership (or non-membership) of key-value pairs
in a super::Smt (Sparse Merkle Tree).
The proof consists of a sparse Merkle path and a leaf, which describes the node located at the base of the path.
Implementations
Sourceimpl SmtProof
impl SmtProof
Sourcepub fn new(
path: SparseMerklePath,
leaf: SmtLeaf,
) -> Result<SmtProof, SmtProofError>
pub fn new( path: SparseMerklePath, leaf: SmtLeaf, ) -> Result<SmtProof, SmtProofError>
Sourcepub fn verify_membership(&self, key: &Word, value: &Word, root: &Word) -> bool
pub fn verify_membership(&self, key: &Word, value: &Word, root: &Word) -> bool
Returns true if a super::Smt with the specified root contains the provided
key-value pair.
Note: this method cannot be used to assert non-membership. That is, if false is returned, it does not mean that the provided key-value pair is not in the tree.
Sourcepub fn get(&self, key: &Word) -> Option<Word>
pub fn get(&self, key: &Word) -> Option<Word>
Returns the value associated with the specific key according to this proof, or None if this proof does not contain a value for the specified key.
A key-value pair generated by using this method should pass the verify_membership() check.
Sourcepub fn compute_root(&self) -> Word
pub fn compute_root(&self) -> Word
Computes the root of a super::Smt to which this proof resolves.
Sourcepub fn path(&self) -> &SparseMerklePath
pub fn path(&self) -> &SparseMerklePath
Returns the proof’s sparse Merkle path.
Sourcepub fn authenticated_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
pub fn authenticated_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
Returns an iterator over every inner node of this proof’s merkle path.
Sourcepub fn into_parts(self) -> (SparseMerklePath, SmtLeaf)
pub fn into_parts(self) -> (SparseMerklePath, SmtLeaf)
Consume the proof and returns its parts.