pub trait FeltRng: RngCore {
// Required methods
fn draw_element(&mut self) -> Felt;
fn draw_word(&mut self) -> Word;
}Expand description
Pseudo-random element generator.
An instance can be used to draw, uniformly at random, base field elements as well as Words.
Required Methods
Sourcefn draw_element(&mut self) -> Felt
fn draw_element(&mut self) -> Felt
Draw, uniformly at random, a base field element.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".