pub enum AccountError {
Show 33 variants
AccountCodeDeserializationError(DeserializationError),
AccountCodeNoAuthComponent,
AccountCodeMultipleAuthComponents,
AccountCodeNoProcedures,
AccountCodeTooManyProcedures(usize),
AccountComponentAssemblyError(Report),
AccountComponentMastForestMergeError(MastForestError),
AccountComponentMultipleAuthProcedures,
AssetVaultUpdateError(AssetVaultError),
BuildError(String, Option<Box<AccountError>>),
FinalAccountHeaderIdParsingFailed(AccountIdError),
HeaderDataIncorrectLength {
actual: usize,
expected: usize,
},
NonceOverflow {
current: BaseElement,
increment: BaseElement,
new: BaseElement,
},
SeedDigestTooFewTrailingZeros {
expected: u32,
actual: u32,
},
AccountIdSeedMismatch {
actual: AccountId,
expected: AccountId,
},
ExistingAccountWithSeed,
NewAccountMissingSeed,
DeltaFromAccountWithSeed,
SeedConvertsToInvalidAccountId(AccountIdError),
StorageMapRootNotFound(Word),
StorageSlotNotMap(StorageSlotName),
StorageSlotNotValue(StorageSlotName),
DuplicateStorageSlotName(StorageSlotName),
StorageSlotNameMustNotBeFaucetSysdata,
StorageSlotNameNotFound {
slot_name: StorageSlotName,
},
StorageSlotIdNotFound {
slot_id: StorageSlotId,
},
UnsortedStorageSlots,
StorageTooManySlots(u64),
UnsupportedComponentForAccountType {
account_type: AccountType,
component_index: usize,
},
ApplyFullStateDeltaToAccount,
PartialStateDeltaToAccount,
MaxNumStorageMapLeavesExceeded(MerkleError),
Other {
error_msg: Box<str>,
source: Option<Box<dyn Error + Send + Sync>>,
},
}Expand description
Re-export the entire miden_client crate so external projects can use a single dependency.
Variants
AccountCodeDeserializationError(DeserializationError)
AccountCodeNoAuthComponent
AccountCodeMultipleAuthComponents
AccountCodeNoProcedures
AccountCodeTooManyProcedures(usize)
AccountComponentAssemblyError(Report)
AccountComponentMastForestMergeError(MastForestError)
AccountComponentMultipleAuthProcedures
AssetVaultUpdateError(AssetVaultError)
BuildError(String, Option<Box<AccountError>>)
FinalAccountHeaderIdParsingFailed(AccountIdError)
HeaderDataIncorrectLength
NonceOverflow
SeedDigestTooFewTrailingZeros
AccountIdSeedMismatch
ExistingAccountWithSeed
NewAccountMissingSeed
DeltaFromAccountWithSeed
SeedConvertsToInvalidAccountId(AccountIdError)
StorageMapRootNotFound(Word)
StorageSlotNotMap(StorageSlotName)
StorageSlotNotValue(StorageSlotName)
DuplicateStorageSlotName(StorageSlotName)
StorageSlotNameMustNotBeFaucetSysdata
StorageSlotNameNotFound
Fields
slot_name: StorageSlotNameStorageSlotIdNotFound
Fields
slot_id: StorageSlotIdUnsortedStorageSlots
StorageTooManySlots(u64)
UnsupportedComponentForAccountType
ApplyFullStateDeltaToAccount
PartialStateDeltaToAccount
MaxNumStorageMapLeavesExceeded(MerkleError)
Other
This variant can be used by methods that are not inherent to the account but want to return this error type.
Implementations
Sourceimpl AccountError
impl AccountError
Sourcepub fn other(message: impl Into<String>) -> AccountError
pub fn other(message: impl Into<String>) -> AccountError
Creates a custom error using the AccountError::Other variant from an error message.
Sourcepub fn other_with_source(
message: impl Into<String>,
source: impl Error + Send + Sync + 'static,
) -> AccountError
pub fn other_with_source( message: impl Into<String>, source: impl Error + Send + Sync + 'static, ) -> AccountError
Creates a custom error using the AccountError::Other variant from an error message and
a source error.