client_binary_name

Function client_binary_name 

pub fn client_binary_name() -> OsString
Client binary name.

If, for whatever reason, we fail to obtain the client’s executable name, then we simply display the standard “miden-client”.