Module grpc_support

Module grpc_support 

Re-export the entire miden_client crate so external projects can use a single dependency.

Structs

NoteTransportConfig
Configuration for lazy note transport initialization.
RemoteTransactionProver
A RemoteTransactionProver is a transaction prover that sends witness data to a remote gRPC server and receives a proven transaction.

Constants

DEVNET_PROVER_ENDPOINT
Default remote prover endpoint for devnet.
NOTE_TRANSPORT_DEFAULT_TIMEOUT_MS
Default timeout for note transport connections (10 seconds).
TESTNET_PROVER_ENDPOINT
Default remote prover endpoint for testnet.