pub struct FilesystemKeyStore {
pub keys_directory: PathBuf,
}Expand description
A filesystem-based keystore that stores keys in separate files and provides transaction authentication functionality. The public key is hashed and the result is used as the filename and the contents of the file are the serialized public and secret key.
Fields
keys_directory: PathBufThe directory where the keys are stored and read from.
Implementations
Sourceimpl FilesystemKeyStore
impl FilesystemKeyStore
Sourcepub fn new(keys_directory: PathBuf) -> Result<FilesystemKeyStore, KeyStoreError>
pub fn new(keys_directory: PathBuf) -> Result<FilesystemKeyStore, KeyStoreError>
Creates a FilesystemKeyStore on a specific directory.
Sourcepub fn add_key(&self, key: &AuthSecretKey) -> Result<(), KeyStoreError>
pub fn add_key(&self, key: &AuthSecretKey) -> Result<(), KeyStoreError>
Adds a secret key to the keystore.
Sourcepub fn remove_key(
&self,
pub_key: PublicKeyCommitment,
) -> Result<(), KeyStoreError>
pub fn remove_key( &self, pub_key: PublicKeyCommitment, ) -> Result<(), KeyStoreError>
Removes a secret key from the keystore, given the commitment of a public key.
Sourcepub fn get_key(
&self,
pub_key: PublicKeyCommitment,
) -> Result<Option<AuthSecretKey>, KeyStoreError>
pub fn get_key( &self, pub_key: PublicKeyCommitment, ) -> Result<Option<AuthSecretKey>, KeyStoreError>
Retrieves a secret key from the keystore given the commitment of a public key.