pub enum NoteConsumptionStatus {
Consumable,
ConsumableAfter(BlockNumber),
ConsumableWithAuthorization,
UnconsumableConditions,
NeverConsumable(Box<dyn Error + Send + Sync>),
}Expand description
Describes if a note could be consumed under a specific conditions: target account state and block height.
The status does not account for any authorization that may be required to consume the note, nor does it indicate whether the account has sufficient fees to consume it.
Variants
Consumable
The note can be consumed by the account at the specified block height.
ConsumableAfter(BlockNumber)
The note can be consumed by the account after the required block height is achieved.
ConsumableWithAuthorization
The note can be consumed by the account if proper authorization is provided.
UnconsumableConditions
The note cannot be consumed by the account at the specified conditions (i.e., block height and account state).
NeverConsumable(Box<dyn Error + Send + Sync>)
The note cannot be consumed by the specified account under any conditions.