#[repr(u8)]pub enum NoteType {
Private = 2,
Encrypted = 3,
Public = 1,
}Variants
Private = 2
Notes with this type have only their hash published to the network.
Encrypted = 3
Notes with this type are shared with the network encrypted.
Public = 1
Notes with this type are fully shared with the network.