pub enum StandardNote {
P2ID,
P2IDE,
SWAP,
MINT,
BURN,
}Expand description
The enum holding the types of standard notes provided by miden-standards.
Variants
Implementations
Sourceimpl StandardNote
impl StandardNote
Sourcepub fn from_script(script: &NoteScript) -> Option<StandardNote>
pub fn from_script(script: &NoteScript) -> Option<StandardNote>
Returns a StandardNote instance based on the provided NoteScript. Returns None
if the provided script does not match any standard note script.
Sourcepub fn from_script_root(root: Word) -> Option<StandardNote>
pub fn from_script_root(root: Word) -> Option<StandardNote>
Returns a StandardNote instance based on the provided script root. Returns None if
the provided root does not match any standard note script.
Sourcepub fn name(&self) -> &'static str
pub fn name(&self) -> &'static str
Returns the name of this StandardNote variant as a string.
Sourcepub fn expected_num_storage_items(&self) -> usize
pub fn expected_num_storage_items(&self) -> usize
Returns the expected number of storage items of the active note.
Sourcepub fn script(&self) -> NoteScript
pub fn script(&self) -> NoteScript
Returns the note script of the current StandardNote instance.
Sourcepub fn script_root(&self) -> Word
pub fn script_root(&self) -> Word
Returns the script root of the current StandardNote instance.
Sourcepub fn is_compatible_with(&self, account_interface: &AccountInterface) -> bool
pub fn is_compatible_with(&self, account_interface: &AccountInterface) -> bool
Returns a boolean value indicating whether this StandardNote is compatible with the provided AccountInterface.
Sourcepub fn is_consumable(
&self,
note: &Note,
target_account_id: AccountId,
block_ref: BlockNumber,
) -> Option<NoteConsumptionStatus>
pub fn is_consumable( &self, note: &Note, target_account_id: AccountId, block_ref: BlockNumber, ) -> Option<NoteConsumptionStatus>
Performs the inputs check of the provided standard note against the target account and the block number.
This function returns:
Someif we can definitively determine whether the note can be consumed not by the target account.Noneif the consumption status of the note cannot be determined conclusively and further checks are necessary.