pub enum WellKnownNote {
P2ID,
P2IDE,
SWAP,
MINT,
BURN,
}Expand description
The enum holding the types of basic well-known notes provided by the miden-lib.
Variants
Implementations
Sourceimpl WellKnownNote
impl WellKnownNote
Sourcepub fn from_note(note: &Note) -> Option<WellKnownNote>
pub fn from_note(note: &Note) -> Option<WellKnownNote>
Returns a WellKnownNote instance based on the note script of the provided Note. Returns
None if the provided note is not a basic well-known note.
Sourcepub fn num_expected_inputs(&self) -> usize
pub fn num_expected_inputs(&self) -> usize
Returns the expected inputs number of the active note.
Sourcepub fn script(&self) -> NoteScript
pub fn script(&self) -> NoteScript
Returns the note script of the current WellKnownNote instance.
Sourcepub fn script_root(&self) -> Word
pub fn script_root(&self) -> Word
Returns the script root of the current WellKnownNote instance.
Sourcepub fn is_compatible_with(&self, account_interface: &AccountInterface) -> bool
pub fn is_compatible_with(&self, account_interface: &AccountInterface) -> bool
Returns a boolean value indicating whether this WellKnownNote is compatible with the provided AccountInterface.
Sourcepub fn is_consumable(
&self,
note: &Note,
target_account_id: AccountId,
block_ref: BlockNumber,
) -> Option<NoteConsumptionStatus>
pub fn is_consumable( &self, note: &Note, target_account_id: AccountId, block_ref: BlockNumber, ) -> Option<NoteConsumptionStatus>
Performs the inputs check of the provided well-known note against the target account and the block number.
This function returns:
Someif we can definitively determine whether the note can be consumed not by the target account.Noneif the consumption status of the note cannot be determined conclusively and further checks are necessary.