Module standards

Module standards 

Modules

config
The standardized config notes: notes that carry a management action for the account that consumes them.
costs
Benchmarked consumption costs of the standard notes, and helpers turning them into fees.

Structs

AccountTargetNetworkNote
A wrapper around a Note that is guaranteed to target a network account via a NetworkAccountTarget attachment.
BurnNote
A BURN note: instructs a faucet to burn the asset carried by the note and embedded in its storage.
FeeSponsorshipNote
A FEE_SPONSORSHIP note: carries the fee for exactly one feature note.
FeeSponsorshipNoteStorage
Canonical storage representation for a FEE_SPONSORSHIP note.
MintNote
A MINT note: instructs a network faucet to mint the asset embedded in its storage.
NetworkAccountTarget
A NoteAttachment for notes targeted at network accounts.
NoteSyncHint
Hints used by a client to find a note on chain after importing a note file.
P2idNote
A Pay-to-ID (P2ID) note: transfers assets from sender to the target account.
P2idNoteStorage
Canonical storage representation for a P2ID note.
P2ideNote
Pay-to-ID Extended (P2IDE) note abstraction.
P2ideNoteStorage
Canonical storage representation for a P2IDE note.
PswapNote
A partially-fillable swap note for decentralized asset exchange.
PswapNoteAttachment
Typed attachment carried by both PSWAP output notes, encoded as [amount, order_id, depth, 0] under PswapNote::PSWAP_ATTACHMENT_SCHEME.
PswapNoteStorage
Canonical storage representation for a PSWAP note.
SwapNote
A SWAP note: offers offered_asset in exchange for requested_asset.
SwapNoteStorage
Canonical storage representation for a SWAP note.
TxFeeNote
A TX_FEE note: the canonical way for a transaction to pay its fee to a batch builder.

Enums

MintNoteStorage
Represents the different storage formats for MINT notes.
NetworkAccountTargetError
NoteConsumptionStatus
Describes if a note could be consumed under a specific conditions: target account state and block height.
NoteExecutionHint
Specifies the conditions under which a note is ready to be consumed. These conditions are meant to be encoded in the note script as well.
NoteFile
A serialized representation of a note.
NumStorageItems
The number of storage items a StandardNote accepts.
StandardNote
The enum holding the types of standard notes provided by miden-standards.
StandardNoteAttachment
The NoteAttachmentSchemes of standard note attachments.
SwapPayback
Mode-specific payback data embedded in SwapNoteStorage.

Traits

NetworkNoteExt
Convenience helpers for Notes that may target a network account.

Functions

payback_serial_from_swap
Returns the P2ID payback serial derived from a SWAP note’s own serial number.