pub enum MintNoteStorage {
Private {
recipient_digest: Word,
asset: FungibleAsset,
tag: Felt,
},
Public {
recipient: NoteRecipient,
asset: FungibleAsset,
tag: Felt,
},
}Expand description
Represents the different storage formats for MINT notes.
- Private: Creates a private output note using a precomputed recipient digest (13 MINT note storage items: RECIPIENT + ASSET_KEY + ASSET_VALUE + tag).
- Public: Creates a public output note by providing script root, serial number, and variable-length storage (20+ MINT note storage items: 20 fixed + variable output note storage items, with the variable section word-aligned at offset 20).
The asset (ASSET_KEY + ASSET_VALUE, 8 felts) is embedded in storage so that the
faucet executing the MINT note can be checked against the asset’s faucet ID at mint time.
Variants
Implementations
Sourceimpl MintNoteStorage
impl MintNoteStorage
pub fn new_private( recipient_digest: Word, asset: FungibleAsset, tag: Felt, ) -> MintNoteStorage
pub fn new_public( recipient: NoteRecipient, asset: FungibleAsset, tag: Felt, ) -> Result<MintNoteStorage, NoteError>
Sourcepub fn asset(&self) -> FungibleAsset
pub fn asset(&self) -> FungibleAsset
Returns the asset that will be minted on consumption.