pub struct AccountTargetNetworkNote { /* private fields */ }Expand description
A wrapper around a Note that is guaranteed to target a network account via a
NetworkAccountTarget attachment.
This represents a note that is specifically targeted at a single network account. In the future, other types of network notes may exist (e.g., SWAP notes that can be consumed by network accounts but are not targeted at a specific one).
Implementations
Sourceimpl AccountTargetNetworkNote
impl AccountTargetNetworkNote
Sourcepub fn new(
note: Note,
) -> Result<AccountTargetNetworkNote, NetworkAccountTargetError>
pub fn new( note: Note, ) -> Result<AccountTargetNetworkNote, NetworkAccountTargetError>
Attempts to construct an AccountTargetNetworkNote from note.
Returns an error if:
- the note is not
NoteType::Public. - the note’s attachment cannot be decoded as a
NetworkAccountTarget.
Sourcepub fn metadata(&self) -> &NoteMetadata
pub fn metadata(&self) -> &NoteMetadata
Returns the NoteMetadata of the underlying note.
Sourcepub fn target_account_id(&self) -> AccountId
pub fn target_account_id(&self) -> AccountId
Returns the target network AccountId.
Sourcepub fn target(&self) -> NetworkAccountTarget
pub fn target(&self) -> NetworkAccountTarget
Returns the decoded NetworkAccountTarget attachment.
Sourcepub fn execution_hint(&self) -> NoteExecutionHint
pub fn execution_hint(&self) -> NoteExecutionHint
Returns the NoteExecutionHint from the decoded NetworkAccountTarget attachment.
Sourcepub fn attachments(&self) -> &NoteAttachments
pub fn attachments(&self) -> &NoteAttachments
Returns the raw NoteAttachments from the note’s attachments.