pub struct BurnNote;Expand description
TODO: add docs
Implementations
Sourceimpl BurnNote
impl BurnNote
Sourcepub const NUM_STORAGE_ITEMS: usize = 0
pub const NUM_STORAGE_ITEMS: usize = 0
Expected number of storage items of the BURN note.
Sourcepub fn script() -> NoteScript
pub fn script() -> NoteScript
Returns the script of the BURN note.
Sourcepub fn script_root() -> NoteScriptRoot
pub fn script_root() -> NoteScriptRoot
Returns the BURN note script root.
Sourcepub fn create<R>(
sender: AccountId,
faucet_id: AccountId,
fungible_asset: Asset,
attachments: NoteAttachments,
rng: &mut R,
) -> Result<Note, NoteError>where
R: FeltRng,
pub fn create<R>(
sender: AccountId,
faucet_id: AccountId,
fungible_asset: Asset,
attachments: NoteAttachments,
rng: &mut R,
) -> Result<Note, NoteError>where
R: FeltRng,
Generates a BURN note - a note that instructs a faucet to burn a fungible asset.
This script enables the creation of a PUBLIC note that, when consumed by a fungible
faucet, will burn the fungible assets contained in the note. The compiled call targets
fungible::receive_and_burn.
BURN notes are always PUBLIC for network execution.
The passed-in rng is used to generate a serial number for the note. The note’s tag
is automatically set to the faucet’s account ID for proper routing.
Parameters
sender: The account ID of the note creatorfaucet_id: The account ID of the faucet that will burn the assetsfungible_asset: The fungible asset to be burnedattachment: TheNoteAttachmentsof the BURN noterng: Random number generator for creating the serial number
Errors
Returns an error if note creation fails.