pub struct Note { /* private fields */ }Expand description
A note with all the data required for it to be consumed by executing it against the transaction kernel.
Notes consist of note metadata and details. Note metadata is always public, but details may be either public, encrypted, or private, depending on the note type. Note details consist of note assets, script, inputs, and a serial number, the three latter grouped into a recipient object.
Note details can be reduced to two unique identifiers: NoteId and Nullifier. The former is publicly associated with a note, while the latter is known only to entities which have access to full note details.
Fungible and non-fungible asset transfers are done by moving assets to the note’s assets. The note’s script determines the conditions required for the note consumption, i.e. the target account of a P2ID or conditions of a SWAP, and the effects of the note. The serial number has a double duty of preventing double spend, and providing unlikability to the consumer of a note. The note’s inputs allow for customization of its script.
To create a note, the kernel does not require all the information above, a user can create a note only with the commitment to the script, inputs, the serial number (i.e., the recipient), and the kernel only verifies the source account has the assets necessary for the note creation. See NoteRecipient for more details.
Implementations
Sourceimpl Note
impl Note
Sourcepub fn new(
assets: NoteAssets,
metadata: NoteMetadata,
recipient: NoteRecipient,
) -> Note
pub fn new( assets: NoteAssets, metadata: NoteMetadata, recipient: NoteRecipient, ) -> Note
Returns a new Note created with the specified parameters.
Sourcepub fn header(&self) -> &NoteHeader
pub fn header(&self) -> &NoteHeader
Returns the note’s header.
Sourcepub fn id(&self) -> NoteId
pub fn id(&self) -> NoteId
Returns the note’s unique identifier.
This value is both an unique identifier and a commitment to the note.
Sourcepub fn metadata(&self) -> &NoteMetadata
pub fn metadata(&self) -> &NoteMetadata
Returns the note’s metadata.
Sourcepub fn assets(&self) -> &NoteAssets
pub fn assets(&self) -> &NoteAssets
Returns the note’s assets.
Sourcepub fn serial_num(&self) -> Word
pub fn serial_num(&self) -> Word
Returns the note’s recipient serial_num, the secret required to consume the note.
Sourcepub fn script(&self) -> &NoteScript
pub fn script(&self) -> &NoteScript
Returns the note’s recipient script which locks the assets of this note.
Sourcepub fn inputs(&self) -> &NoteInputs
pub fn inputs(&self) -> &NoteInputs
Returns the note’s recipient inputs which customizes the script’s behavior.
Sourcepub fn recipient(&self) -> &NoteRecipient
pub fn recipient(&self) -> &NoteRecipient
Returns the note’s recipient.
Sourcepub fn nullifier(&self) -> Nullifier
pub fn nullifier(&self) -> Nullifier
Returns the note’s nullifier.
This is public data, used to prevent double spend.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns a commitment to the note and its metadata.
hash(NOTE_ID || NOTE_METADATA_COMMITMENT)
This value is used primarily for authenticating notes consumed when the are consumed in a transaction.