pub struct NoteAssets { /* private fields */ }Expand description
An asset container for a note.
A note can contain between 0 and 256 assets. No duplicates are allowed, but the order of assets is unspecified.
All the assets in a note can be reduced to a single commitment which is computed by sequentially hashing the assets. Note that the same list of assets can result in two different commitments if the asset ordering is different.
Implementations
Sourceimpl NoteAssets
impl NoteAssets
Sourcepub const MAX_NUM_ASSETS: usize = MAX_ASSETS_PER_NOTE
pub const MAX_NUM_ASSETS: usize = MAX_ASSETS_PER_NOTE
The maximum number of assets which can be carried by a single note.
Sourcepub fn new(assets: Vec<Asset>) -> Result<NoteAssets, NoteError>
pub fn new(assets: Vec<Asset>) -> Result<NoteAssets, NoteError>
Returns new NoteAssets constructed from the provided list of assets.
Errors
Returns an error if:
- The list contains more than 256 assets.
- There are duplicate assets in the list.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns a commitment to the note’s assets.
Sourcepub fn num_assets(&self) -> usize
pub fn num_assets(&self) -> usize
Returns the number of assets.
Sourcepub fn to_padded_assets(&self) -> Vec<BaseElement>
pub fn to_padded_assets(&self) -> Vec<BaseElement>
Returns all assets represented as a vector of field elements.
The vector is padded with ZEROs so that its length is a multiple of 8. This is useful because hashing the returned elements results in the note asset commitment.
Sourcepub fn iter_fungible(&self) -> impl Iterator<Item = FungibleAsset>
pub fn iter_fungible(&self) -> impl Iterator<Item = FungibleAsset>
Returns an iterator over all FungibleAsset.
Sourcepub fn iter_non_fungible(&self) -> impl Iterator<Item = NonFungibleAsset>
pub fn iter_non_fungible(&self) -> impl Iterator<Item = NonFungibleAsset>
Returns iterator over all NonFungibleAsset.
Sourcepub fn add_asset(&mut self, asset: Asset) -> Result<(), NoteError>
pub fn add_asset(&mut self, asset: Asset) -> Result<(), NoteError>
Adds the provided asset to this list of note assets.
Errors
Returns an error if:
- The same non-fungible asset is already in the list.
- A fungible asset issued by the same faucet exists in the list and adding both assets together results in an invalid asset.
- Adding the asset to the list will push the list beyond the Self::MAX_NUM_ASSETS limit.