pub struct NoteAttachmentHeader { /* private fields */ }Expand description
The header metadata for a single note attachment.
Contains the scheme of an attachment, without the actual content data.
Implementations
Sourceimpl NoteAttachmentHeader
impl NoteAttachmentHeader
Sourcepub fn new(scheme: NoteAttachmentScheme) -> NoteAttachmentHeader
pub fn new(scheme: NoteAttachmentScheme) -> NoteAttachmentHeader
Creates a new NoteAttachmentHeader from a NoteAttachmentScheme.
Sourcepub fn new_maybe(scheme: Option<NoteAttachmentScheme>) -> NoteAttachmentHeader
pub fn new_maybe(scheme: Option<NoteAttachmentScheme>) -> NoteAttachmentHeader
Creates a new NoteAttachmentHeader from a NoteAttachmentScheme.
Sourcepub const fn absent() -> NoteAttachmentHeader
pub const fn absent() -> NoteAttachmentHeader
Returns a header representing the absence of an attachment.
Sourcepub const fn scheme(&self) -> Option<NoteAttachmentScheme>
pub const fn scheme(&self) -> Option<NoteAttachmentScheme>
Returns the attachment scheme.