pub struct NoteAttachmentScheme(/* private fields */);Expand description
The user-defined type of a NoteAttachment.
A note attachment scheme is an arbitrary 32-bit unsigned integer.
Value 0 is reserved to signal that the scheme is none or absent. Whenever the kind of
attachment is not standardized or interoperability is unimportant, this none value can be
used.
Implementations
Sourceimpl NoteAttachmentScheme
impl NoteAttachmentScheme
Sourcepub const fn new(attachment_scheme: u32) -> NoteAttachmentScheme
pub const fn new(attachment_scheme: u32) -> NoteAttachmentScheme
Creates a new NoteAttachmentScheme from a u32.
Sourcepub const fn none() -> NoteAttachmentScheme
pub const fn none() -> NoteAttachmentScheme
Returns the NoteAttachmentScheme that signals the absence of an attachment scheme.