pub struct NoteConsumptionInfo { /* private fields */ }Expand description
Contains information about the successful and failed consumption of notes.
Implementations
Sourceimpl NoteConsumptionInfo
impl NoteConsumptionInfo
Sourcepub fn new_successful(successful: Vec<SuccessfulNote>) -> NoteConsumptionInfo
pub fn new_successful(successful: Vec<SuccessfulNote>) -> NoteConsumptionInfo
Creates a new NoteConsumptionInfo instance with the given successful notes.
Sourcepub fn new(
successful: Vec<SuccessfulNote>,
failed: Vec<FailedNote>,
) -> NoteConsumptionInfo
pub fn new( successful: Vec<SuccessfulNote>, failed: Vec<FailedNote>, ) -> NoteConsumptionInfo
Creates a new NoteConsumptionInfo instance with the given successful and failed notes.
Sourcepub fn successful(&self) -> &[SuccessfulNote]
pub fn successful(&self) -> &[SuccessfulNote]
Returns a reference to the successfully consumed notes.
Sourcepub fn failed(&self) -> &[FailedNote]
pub fn failed(&self) -> &[FailedNote]
Returns a reference to the failed notes.
Sourcepub fn into_parts(self) -> (Vec<SuccessfulNote>, Vec<FailedNote>)
pub fn into_parts(self) -> (Vec<SuccessfulNote>, Vec<FailedNote>)
Consumes the struct and returns the successful and failed notes.