pub struct NoteDetails { /* private fields */ }Expand description
Details of a note consisting of assets, script, inputs, and a serial number.
See super::Note for more details.
Implementations
Sourceimpl NoteDetails
impl NoteDetails
Sourcepub fn new(assets: NoteAssets, recipient: NoteRecipient) -> NoteDetails
pub fn new(assets: NoteAssets, recipient: NoteRecipient) -> NoteDetails
Returns a new note created with the specified parameters.
Sourcepub fn id(&self) -> NoteId
pub fn id(&self) -> NoteId
Returns the note’s unique identifier.
This value is both an unique identifier and a commitment to the note.
Sourcepub fn assets(&self) -> &NoteAssets
pub fn assets(&self) -> &NoteAssets
Returns the note’s assets.
Sourcepub fn serial_num(&self) -> Word
pub fn serial_num(&self) -> Word
Returns the note’s recipient serial_num, the secret required to consume the note.
Sourcepub fn script(&self) -> &NoteScript
pub fn script(&self) -> &NoteScript
Returns the note’s recipient script which locks the assets of this note.
Sourcepub fn inputs(&self) -> &NoteInputs
pub fn inputs(&self) -> &NoteInputs
Returns the note’s recipient inputs which customizes the script’s behavior.
Sourcepub fn recipient(&self) -> &NoteRecipient
pub fn recipient(&self) -> &NoteRecipient
Returns the note’s recipient.
Sourcepub fn nullifier(&self) -> Nullifier
pub fn nullifier(&self) -> Nullifier
Returns the note’s nullifier.
This is public data, used to prevent double spend.
Sourcepub fn into_parts(self) -> (NoteAssets, NoteRecipient)
pub fn into_parts(self) -> (NoteAssets, NoteRecipient)
Decomposes note details into underlying assets and recipient.