pub struct NoteHeader { /* private fields */ }Expand description
Holds the strictly required, public information of a note.
See NoteId and NoteMetadata for additional details.
Implementations
Sourceimpl NoteHeader
impl NoteHeader
Sourcepub fn new(note_id: NoteId, note_metadata: NoteMetadata) -> NoteHeader
pub fn new(note_id: NoteId, note_metadata: NoteMetadata) -> NoteHeader
Returns a new NoteHeader instantiated from the specified note ID and metadata.
Sourcepub fn id(&self) -> NoteId
pub fn id(&self) -> NoteId
Returns the note’s identifier.
The NoteId value is both an unique identifier and a commitment to the note.
Sourcepub fn metadata(&self) -> &NoteMetadata
pub fn metadata(&self) -> &NoteMetadata
Returns the note’s metadata.
Sourcepub fn into_metadata(self) -> NoteMetadata
pub fn into_metadata(self) -> NoteMetadata
Consumes self and returns the note header’s metadata.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns a commitment to the note and its metadata.
hash(NOTE_ID || NOTE_METADATA_COMMITMENT)
This value is used primarily for authenticating notes consumed when they are consumed in a transaction.