pub struct NoteId(/* private fields */);Expand description
Returns a unique identifier of a note, which is simultaneously a commitment to the note.
Note ID is computed as:
hash(recipient, asset_commitment),
where recipient is defined as:
hash(hash(hash(serial_num, ZERO), script_root), input_commitment)
This achieves the following properties:
- Every note can be reduced to a single unique ID.
- To compute a note ID, we do not need to know the note’s serial_num. Knowing the hash of the serial_num (as well as script root, input commitment, and note assets) is sufficient.
Implementations
Sourceimpl NoteId
impl NoteId
Sourcepub fn from_raw(word: Word) -> NoteId
pub fn from_raw(word: Word) -> NoteId
Construct without further checks from a given Word
Warning
This requires the caller to uphold the guarantees/invariants of this type (if any). Check the type-level documentation for guarantees/invariants.
Sourcepub fn as_elements(&self) -> &[BaseElement]
pub fn as_elements(&self) -> &[BaseElement]
Returns the elements representation of this value.