pub struct NoteInclusionProof { /* private fields */ }Expand description
Contains the data required to prove inclusion of a note in the canonical chain.
Implementations
Sourceimpl NoteInclusionProof
impl NoteInclusionProof
Sourcepub fn new(
block_num: BlockNumber,
node_index_in_block: u16,
note_path: SparseMerklePath,
) -> Result<NoteInclusionProof, NoteError>
pub fn new( block_num: BlockNumber, node_index_in_block: u16, note_path: SparseMerklePath, ) -> Result<NoteInclusionProof, NoteError>
Returns a new NoteInclusionProof.
Sourcepub fn location(&self) -> &NoteLocation
pub fn location(&self) -> &NoteLocation
Returns the location of the note.
Sourcepub fn note_path(&self) -> &SparseMerklePath
pub fn note_path(&self) -> &SparseMerklePath
Returns the Sparse Merkle path to the note in the note Merkle tree of the block the note was created in.
Sourcepub fn authenticated_nodes(
&self,
note_commitment: Word,
) -> impl Iterator<Item = InnerNodeInfo>
pub fn authenticated_nodes( &self, note_commitment: Word, ) -> impl Iterator<Item = InnerNodeInfo>
Returns an iterator over inner nodes of this proof assuming that note_commitment is the
value of the node to which this proof opens.