pub struct NoteInputs { /* private fields */ }Expand description
A container for note inputs.
A note can be associated with up to 1024 input values. Each value is represented by a single field element. Thus, note input values can contain up to ~8 KB of data.
All inputs associated with a note can be reduced to a single commitment which is computed as an RPO256 hash over the input elements.
Implementations
Sourceimpl NoteInputs
impl NoteInputs
Sourcepub fn new(values: Vec<BaseElement>) -> Result<NoteInputs, NoteError>
pub fn new(values: Vec<BaseElement>) -> Result<NoteInputs, NoteError>
Returns NoteInputs instantiated from the provided values.
Errors
Returns an error if the number of provided inputs is greater than 1024.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns a commitment to these inputs.
Sourcepub fn num_values(&self) -> u16
pub fn num_values(&self) -> u16
Returns the number of input values.
The returned value is guaranteed to be smaller than or equal to 1024.
Sourcepub fn values(&self) -> &[BaseElement]
pub fn values(&self) -> &[BaseElement]
Returns a reference to the input values.
Sourcepub fn to_elements(&self) -> Vec<BaseElement>
pub fn to_elements(&self) -> Vec<BaseElement>
Returns the note’s input as a vector of field elements.