pub struct NoteMetadata { /* private fields */ }Expand description
The metadata associated with a note.
Note metadata consists of two parts:
- The header of the metadata, which consists of:
- the sender of the note
- the
NoteType - the
NoteTag - type information about the
NoteAttachment.
- The optional
NoteAttachment.
Word layout & validity
NoteMetadata can be encoded into two words, a header and an attachment word.
The header word has the following layout:
0th felt: [sender_id_suffix (56 bits) | 6 zero bits | note_type (2 bit)]
1st felt: [sender_id_prefix (64 bits)]
2nd felt: [32 zero bits | note_tag (32 bits)]
3rd felt: [30 zero bits | attachment_kind (2 bits) | attachment_scheme (32 bits)]The felt validity of each part of the layout is guaranteed:
- 1st felt: The lower 8 bits of the account ID suffix are
0by construction, so that they can be overwritten with other data. The suffix’ most significant bit must be zero such that the entire felt retains its validity even if all of its lower 8 bits are be set to1. So the note type can be comfortably encoded. - 2nd felt: Is equivalent to the prefix of the account ID so it inherits its validity.
- 3rd felt: The upper 32 bits are always zero.
- 4th felt: The upper 30 bits are always zero.
The value of the attachment word depends on the
NoteAttachmentKind:
NoteAttachmentKind::None: Empty word.NoteAttachmentKind::Word: The raw word itself.NoteAttachmentKind::Array: The commitment to the elements.
Implementations
Sourceimpl NoteMetadata
impl NoteMetadata
Sourcepub fn new(sender: AccountId, note_type: NoteType, tag: NoteTag) -> NoteMetadata
pub fn new(sender: AccountId, note_type: NoteType, tag: NoteTag) -> NoteMetadata
Returns a new NoteMetadata instantiated with the specified parameters.
Sourcepub fn attachment(&self) -> &NoteAttachment
pub fn attachment(&self) -> &NoteAttachment
Returns the attachment of the note.
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Returns true if the note is private.
Sourcepub fn to_header_word(&self) -> Word
pub fn to_header_word(&self) -> Word
Returns the Word that represents the header of a NoteMetadata.
See NoteMetadata docs for more details.
Sourcepub fn to_attachment_word(&self) -> Word
pub fn to_attachment_word(&self) -> Word
Returns the Word that represents the attachment of a NoteMetadata.
See NoteMetadata docs for more details.
Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Returns the commitment to the note metadata, which is defined as:
hash(NOTE_METADATA_HEADER || NOTE_METADATA_ATTACHMENT)Sourcepub fn set_attachment(&mut self, attachment: NoteAttachment)
pub fn set_attachment(&mut self, attachment: NoteAttachment)
Overwrites the note’s attachment with the provided one.
Sourcepub fn with_attachment(self, attachment: NoteAttachment) -> NoteMetadata
pub fn with_attachment(self, attachment: NoteAttachment) -> NoteMetadata
Overwrites the note’s attachment with the provided one.