pub struct NoteRecipient { /* private fields */ }Expand description
Value that describes under which condition a note can be consumed.
The recipient is not an account address, instead it is a value that describes when a note can be consumed. Because not all notes have predetermined consumer addresses, e.g. swap notes can be consumed by anyone, the recipient is defined as the code and its inputs, that when successfully executed results in the note’s consumption.
Recipient is computed as:
hash(hash(hash(serial_num, [0; 4]), script_root), input_commitment)
Implementations
Sourceimpl NoteRecipient
impl NoteRecipient
pub fn new( serial_num: Word, script: NoteScript, inputs: NoteInputs, ) -> NoteRecipient
Sourcepub fn serial_num(&self) -> Word
pub fn serial_num(&self) -> Word
The recipient’s serial_num, the secret required to consume the note.
Sourcepub fn script(&self) -> &NoteScript
pub fn script(&self) -> &NoteScript
The recipients’s script which locks the assets of this note.
Sourcepub fn inputs(&self) -> &NoteInputs
pub fn inputs(&self) -> &NoteInputs
The recipient’s inputs which customizes the script’s behavior.