pub struct NoteScreener<AUTH> { /* private fields */ }Expand description
Provides functionality for testing whether a note is relevant to the client or not.
Here, relevance is based on whether the note is able to be consumed by an account that is
tracked in the provided store. This can be derived in a number of ways, such as looking
at the combination of script root and note inputs. For example, a P2ID note is relevant
for a specific account ID if this ID is its first note input.
Implementations
Sourceimpl<AUTH> NoteScreener<AUTH>where
AUTH: TransactionAuthenticator + Sync,
impl<AUTH> NoteScreener<AUTH>where
AUTH: TransactionAuthenticator + Sync,
pub fn new( store: Arc<dyn Store>, authenticator: Option<Arc<AUTH>>, ) -> NoteScreener<AUTH>
Sourcepub fn with_transaction_args(
self,
tx_args: TransactionArgs,
) -> NoteScreener<AUTH>
pub fn with_transaction_args( self, tx_args: TransactionArgs, ) -> NoteScreener<AUTH>
Sets the transaction arguments to use when checking note consumability.
If not set, a default TransactionArgs with an empty advice map is used.
Sourcepub async fn can_consume(
&self,
note: &Note,
) -> Result<Vec<(AccountId, NoteConsumptionStatus)>, NoteScreenerError>
pub async fn can_consume( &self, note: &Note, ) -> Result<Vec<(AccountId, NoteConsumptionStatus)>, NoteScreenerError>
Checks whether the provided note could be consumed by any of the accounts tracked by
this screener. Convenience wrapper around Self::can_consume_batch for a single note.
Returns the NoteConsumptionStatus for each account that could consume the note.
Sourcepub async fn can_consume_batch(
&self,
notes: &[Note],
) -> Result<BTreeMap<NoteId, Vec<(AccountId, NoteConsumptionStatus)>>, NoteScreenerError>
pub async fn can_consume_batch( &self, notes: &[Note], ) -> Result<BTreeMap<NoteId, Vec<(AccountId, NoteConsumptionStatus)>>, NoteScreenerError>
Checks whether the provided notes could be consumed by any of the accounts tracked by this screener, by executing a transaction for each note-account pair.
Returns a map from NoteId to a list of (AccountId, NoteConsumptionStatus) pairs.
Notes that are permanently unconsumable by all accounts are not included in the result.
Sourcepub async fn check_notes_consumability(
&self,
account_id: AccountId,
notes: Vec<Note>,
) -> Result<NoteConsumptionInfo, NoteScreenerError>
pub async fn check_notes_consumability( &self, account_id: AccountId, notes: Vec<Note>, ) -> Result<NoteConsumptionInfo, NoteScreenerError>
Checks whether the provided notes could be consumed by a specific account by attempting to execute them together in a transaction. Notes that fail are progressively removed until a maximal set of successfully consumable notes is found.
Returns a NoteConsumptionInfo splitting notes into those that succeeded and those
that failed.