pub struct NoteScript { /* private fields */ }Expand description
An executable program of a note.
A note’s script represents a program which must be executed for a note to be consumed. As such it defines the rules and side effects of consuming a given note.
Implementations
Sourceimpl NoteScript
impl NoteScript
Sourcepub fn new(code: Program) -> NoteScript
pub fn new(code: Program) -> NoteScript
Returns a new NoteScript instantiated from the provided program.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<NoteScript, NoteError>
pub fn from_bytes(bytes: &[u8]) -> Result<NoteScript, NoteError>
Returns a new NoteScript deserialized from the provided bytes.
Errors
Returns an error if note script deserialization fails.
Sourcepub fn from_parts(mast: Arc<MastForest>, entrypoint: MastNodeId) -> NoteScript
pub fn from_parts(mast: Arc<MastForest>, entrypoint: MastNodeId) -> NoteScript
Returns a new NoteScript instantiated from the provided components.
Panics
Panics if the specified entrypoint is not in the provided MAST forest.
Sourcepub fn root(&self) -> Word
pub fn root(&self) -> Word
Returns the commitment of this note script (i.e., the script’s MAST root).
Sourcepub fn mast(&self) -> Arc<MastForest>
pub fn mast(&self) -> Arc<MastForest>
Returns a reference to the MastForest backing this note script.
Sourcepub fn entrypoint(&self) -> MastNodeId
pub fn entrypoint(&self) -> MastNodeId
Returns an entrypoint node ID of the current script.