pub struct NoteStorage { /* private fields */ }Expand description
A container for note storage items.
A note can be associated with up to 1024 storage items. Each item is represented by a single field element. Thus, note storage can contain up to ~8 KB of data.
All storage items associated with a note can be reduced to a single commitment which is computed as an RPO256 hash over the storage elements.
Implementations
Sourceimpl NoteStorage
impl NoteStorage
Sourcepub fn new(items: Vec<BaseElement>) -> Result<NoteStorage, NoteError>
pub fn new(items: Vec<BaseElement>) -> Result<NoteStorage, NoteError>
Returns NoteStorage instantiated from the provided items.
Errors
Returns an error if the number of provided storage items is greater than 1024.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns a commitment to this storage.
Sourcepub fn num_items(&self) -> u16
pub fn num_items(&self) -> u16
Returns the number of storage items.
The returned value is guaranteed to be smaller than or equal to MAX_NOTE_STORAGE_ITEMS.
Sourcepub fn items(&self) -> &[BaseElement]
pub fn items(&self) -> &[BaseElement]
Returns a reference to the storage items.
Sourcepub fn to_elements(&self) -> Vec<BaseElement>
pub fn to_elements(&self) -> Vec<BaseElement>
Returns the note’s storage as a vector of field elements.