pub struct NoteUpdateTracker { /* private fields */ }Expand description
Contains note changes to apply to the store.
This includes new notes that have been created and existing notes that have been updated. The tracker also lets state changes be applied to the contained notes, this allows for already updated notes to be further updated as new information is received.
Implementations
Sourceimpl NoteUpdateTracker
impl NoteUpdateTracker
Sourcepub fn new(
input_notes: impl IntoIterator<Item = InputNoteRecord>,
output_notes: impl IntoIterator<Item = OutputNoteRecord>,
) -> NoteUpdateTracker
pub fn new( input_notes: impl IntoIterator<Item = InputNoteRecord>, output_notes: impl IntoIterator<Item = OutputNoteRecord>, ) -> NoteUpdateTracker
Creates a NoteUpdateTracker with already-tracked notes.
Sourcepub fn for_transaction_updates(
new_input_notes: impl IntoIterator<Item = InputNoteRecord>,
updated_input_notes: impl IntoIterator<Item = InputNoteRecord>,
new_output_notes: impl IntoIterator<Item = OutputNoteRecord>,
) -> NoteUpdateTracker
pub fn for_transaction_updates( new_input_notes: impl IntoIterator<Item = InputNoteRecord>, updated_input_notes: impl IntoIterator<Item = InputNoteRecord>, new_output_notes: impl IntoIterator<Item = OutputNoteRecord>, ) -> NoteUpdateTracker
Creates a NoteUpdateTracker for updates related to transactions.
A transaction can:
- Create input notes
- Update existing input notes (by consuming them)
- Create output notes
Sourcepub fn updated_input_notes(&self) -> impl Iterator<Item = &InputNoteUpdate>
pub fn updated_input_notes(&self) -> impl Iterator<Item = &InputNoteUpdate>
Returns all input note records that have been updated.
This may include:
- New notes that have been created that should be inserted.
- Existing tracked notes that should be updated.
Sourcepub fn updated_output_notes(&self) -> impl Iterator<Item = &OutputNoteUpdate>
pub fn updated_output_notes(&self) -> impl Iterator<Item = &OutputNoteUpdate>
Returns all output note records that have been updated.
This may include:
- New notes that have been created that should be inserted.
- Existing tracked notes that should be updated.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns whether no new note-related information has been retrieved.
Sourcepub fn unspent_nullifiers(&self) -> impl Iterator<Item = Nullifier>
pub fn unspent_nullifiers(&self) -> impl Iterator<Item = Nullifier>
Returns input and output note unspent nullifiers.