pub struct Nullifier(/* private fields */);Expand description
A note’s nullifier.
A note’s nullifier is computed as:
hash(serial_num, script_root, input_commitment, asset_commitment).
This achieves the following properties:
- Every note can be reduced to a single unique nullifier.
- We cannot derive a note’s commitment from its nullifier, or a note’s nullifier from its hash.
- To compute the nullifier we must know all components of the note: serial_num, script_root, input_commitment and asset_commitment.
Implementations
Sourceimpl Nullifier
impl Nullifier
Sourcepub fn from_raw(word: Word) -> Nullifier
pub fn from_raw(word: Word) -> Nullifier
Construct without further checks from a given Word
Warning
This requires the caller to uphold the guarantees/invariants of this type (if any). Check the type-level documentation for guarantees/invariants.
Sourcepub fn as_elements(&self) -> &[BaseElement]
pub fn as_elements(&self) -> &[BaseElement]
Returns the elements representation of this value.
Sourceimpl Nullifier
impl Nullifier
Sourcepub fn new(
script_root: Word,
inputs_commitment: Word,
asset_commitment: Word,
serial_num: Word,
) -> Nullifier
pub fn new( script_root: Word, inputs_commitment: Word, asset_commitment: Word, serial_num: Word, ) -> Nullifier
Returns a new note Nullifier instantiated from the provided digest.
Sourcepub fn most_significant_felt(&self) -> BaseElement
pub fn most_significant_felt(&self) -> BaseElement
Returns the most significant felt (the last element in array)