pub struct PartialNote { /* private fields */ }Expand description
Partial information about a note.
Partial note consists of NoteMetadata, NoteAssets, and a recipient digest (see super::NoteRecipient). However, it does not contain detailed recipient info, including note script, note inputs, and note’s serial number. This means that a partial note is sufficient to compute note ID and note header, but not sufficient to compute note nullifier, and generally does not have enough info to execute the note.
Implementations
Sourceimpl PartialNote
impl PartialNote
Sourcepub fn new(
metadata: NoteMetadata,
recipient_digest: Word,
assets: NoteAssets,
) -> PartialNote
pub fn new( metadata: NoteMetadata, recipient_digest: Word, assets: NoteAssets, ) -> PartialNote
Returns a new PartialNote instantiated from the provided parameters.
Sourcepub fn metadata(&self) -> &NoteMetadata
pub fn metadata(&self) -> &NoteMetadata
Returns the metadata associated with this note.
Sourcepub fn recipient_digest(&self) -> Word
pub fn recipient_digest(&self) -> Word
Returns the digest of the recipient associated with this note.
See super::NoteRecipient for more info.
Sourcepub fn assets(&self) -> &NoteAssets
pub fn assets(&self) -> &NoteAssets
Returns a list of assets associated with this note.
Sourcepub fn header(&self) -> &NoteHeader
pub fn header(&self) -> &NoteHeader
Returns the NoteHeader of this note.