Module protocol_config

Module protocol_config 

Re-export the entire miden_client crate so external projects can use a single dependency. Stores protocol configurations by their block header commitments.

Structs

NextProtocolConfig
A protocol upgrade that is scheduled but not yet in effect.
ProtocolConfig
The configuration parameters of the protocol that are expected to change rarely over the lifetime of a chain.

Enums

ProtocolConfigError
Error returned when constructing an invalid protocol configuration.