Module remote_prover

Module remote_prover 

Re-export the entire miden_client crate so external projects can use a single dependency.

Structs

RemoteTransactionProver
A RemoteTransactionProver is a transaction prover that sends witness data to a remote gRPC server and receives a proven transaction.

Enums

RemoteProverClientError
Errors that can occur when communicating with a remote prover.