Module note

Module note 

Structs

CommittedNote
Represents a committed note, returned as part of a SyncNotesResponse.
ResolvedSyncNotesBlock
A block’s worth of notes resolved by NodeRpcClient::sync_notes_with_content.
SyncNotesBlock
Represents a single block’s worth of note sync data from the SyncNotesResponse.
SyncedNote
Everything resolved about a single note during a notes sync: its identity, metadata, and inclusion proof (always present, from SyncNotes), its attachments, and the public note body when it was fetched via GetNotesById.

Enums

FetchedNote
Describes the possible responses from the GetNotesById endpoint for a single note.