Module storage_map

Module storage_map 

Structs

StorageMapInfo
Represents a proto::rpc::SyncStorageMapsResponse with fields converted into domain types. Contains information of updated map slots in a given range of blocks specified on request. Also provides the current chain tip while processing the request.
StorageMapUpdate
Represents a proto::rpc::StorageMapUpdate