pub struct StateSyncInfo {
pub chain_tip: BlockNumber,
pub block_header: BlockHeader,
pub mmr_delta: MmrDelta,
pub account_commitment_updates: Vec<(AccountId, Word)>,
pub note_inclusions: Vec<CommittedNote>,
pub transactions: Vec<TransactionInclusion>,
}Expand description
Represents a proto::rpc::SyncStateResponse with fields converted into domain types.
Fields
chain_tip: BlockNumberThe block number of the chain tip at the moment of the response.
block_header: BlockHeaderThe returned block header.
mmr_delta: MmrDeltaMMR delta that contains data for (current_block.num, incoming_block_header.num-1).
account_commitment_updates: Vec<(AccountId, Word)>Tuples of AccountId alongside their new account commitments.
note_inclusions: Vec<CommittedNote>List of tuples of Note ID, Note Index and Merkle Path for all new notes.
transactions: Vec<TransactionInclusion>List of transaction IDs of transaction that were included in (request.block_num,
response.block_num-1) along with the account the tx was executed against and the block
number the transaction was included in.