pub struct TransactionsInfo {
pub chain_tip: BlockNumber,
pub block_num: BlockNumber,
pub transaction_records: Vec<TransactionRecord>,
}Expand description
Represent a list of transaction records that were included in a range of blocks.
Fields
chain_tip: BlockNumberCurrent chain tip
block_num: BlockNumberThe block number of the last check included in this response.
transaction_records: Vec<TransactionRecord>List of transaction records.