pub enum NetworkNoteStatus {
Pending,
NullifierInflight,
Discarded,
NullifierCommitted,
}Variants
Pending
The note is awaiting execution or being retried after transient failures.
NullifierInflight
The note has been consumed by a transaction that was sent to the block producer.
Discarded
The note exceeded the maximum retry count and will not be retried.
NullifierCommitted
The note’s consuming transaction has been committed on-chain.