Module node

Module node 

Enums

AddTransactionError
CheckNullifiersError
EndpointError
Application-level error returned by the node for a specific RPC endpoint.
GetAccountError
GetBlockByNumberError
GetBlockHeaderError
GetNoteScriptByRootError
GetNotesByIdError
NoteSyncError
SyncAccountStorageMapsError
SyncAccountVaultError
SyncNullifiersError
SyncTransactionsError

Functions

parse_node_error
Parses the application-level error code into a typed error for the given endpoint.