pub enum AddTransactionError {
Internal,
InputNotesAlreadyConsumed,
UnauthenticatedNotesNotFound,
OutputNotesAlreadyExist,
IncorrectAccountInitialCommitment,
InvalidTransactionProof,
TransactionDeserializationFailed,
Expired,
CapacityExceeded,
Unknown {
code: u8,
message: String,
},
}Variants
Internal
Internal server error (code 0)
InputNotesAlreadyConsumed
One or more input notes have already been consumed
UnauthenticatedNotesNotFound
Unauthenticated notes were not found in the store
OutputNotesAlreadyExist
One or more output notes already exist in the store
IncorrectAccountInitialCommitment
Account’s initial commitment doesn’t match the current state
InvalidTransactionProof
Transaction proof verification failed
TransactionDeserializationFailed
Failed to deserialize the transaction
Expired
Transaction has expired
CapacityExceeded
Block producer capacity exceeded
Unknown
Error code not recognized by this client version. This can happen if the node is newer than the client and has added new error variants.
Implementations
Sourceimpl AddTransactionError
impl AddTransactionError
pub fn from_code(code: u8, message: &str) -> AddTransactionError