pub enum GetNoteScriptByRootError {
Internal,
DeserializationFailed,
ScriptNotFound,
Unknown {
code: u8,
message: String,
},
}Variants
Internal
Internal server error (code 0)
DeserializationFailed
Failed to deserialize data
ScriptNotFound
Script was not found
Unknown
Error code not recognized by this client version. This can happen if the node is newer than the client and has added new error variants.
Implementations
Sourceimpl GetNoteScriptByRootError
impl GetNoteScriptByRootError
pub fn from_code(code: u8, message: &str) -> GetNoteScriptByRootError