pub enum SyncAccountVaultError {
Internal,
InvalidBlockRange,
DeserializationFailed,
AccountNotPublic,
Unknown {
code: u8,
message: String,
},
}Variants
Internal
Internal server error (code 0)
InvalidBlockRange
Invalid block range specified
DeserializationFailed
Failed to deserialize data
AccountNotPublic
Account is not public
Unknown
Error code not recognized by this client version. This can happen if the node is newer than the client and has added new error variants.
Implementations
Sourceimpl SyncAccountVaultError
impl SyncAccountVaultError
pub fn from_code(code: u8, message: &str) -> SyncAccountVaultError