pub fn parse_node_error(
endpoint: &RpcEndpoint,
details: &[u8],
message: &str,
) -> Option<EndpointError>Expand description
Parses the application-level error code into a typed error for the given endpoint.
Returns None if details are empty or if the endpoint doesn’t have typed errors.