pub struct RpcLimits {
pub note_ids_limit: u32,
pub nullifiers_limit: u32,
pub account_ids_limit: u32,
pub note_tags_limit: u32,
}Expand description
Domain type representing RPC endpoint limits.
These limits define the maximum number of items that can be sent in a single RPC request. Exceeding these limits will result in the request being rejected by the node.
Fields
note_ids_limit: u32Maximum number of note IDs that can be sent in a single GetNotesById request.
nullifiers_limit: u32Maximum number of nullifier prefixes that can be sent in CheckNullifiers or
SyncNullifiers requests.
account_ids_limit: u32Maximum number of account IDs that can be sent in a single SyncTransactions request.
Maximum number of note tags that can be sent in a single SyncNotes request.