Module settings

Module settings 

Re-export the entire miden_client crate so external projects can use a single dependency. The settings module provides methods for managing arbitrary setting values that are persisted in the client’s store.