Module store

Module store 

Re-export the entire miden_client crate so external projects can use a single dependency. Defines the storage interfaces used by the Miden client.

It provides mechanisms for persisting and retrieving data, such as account states, transaction history, block headers, notes, and MMR nodes.

Overview

The storage module is central to the Miden client’s persistence layer. It defines the Store trait which abstracts over any concrete storage implementation. The trait exposes methods to (among others):

  • Retrieve and update transactions, notes, and accounts.
  • Store and query block headers along with MMR peaks and authentication nodes.
  • Manage note tags for synchronizing with the node.

These are all used by the Miden client to provide transaction execution in the correct contexts.

In addition to the main Store trait, the module provides types for filtering queries, such as TransactionFilter, NoteFilter, StorageFilter to narrow down the set of returned transactions, account data, or notes. For more advanced usage, see the documentation of individual methods in the Store trait.

Modules

input_note_states
Contains structures that model all states in which an input note can be.

Structs

AccountRecord
Represents a stored account state along with its status.
AccountUpdates
Contains account changes to apply to the store.
InputNoteRecord
Represents a Note of which the Store can keep track and retrieve.
OutputNoteRecord
Represents a Note which was the result of executing some transaction of which the Store can keep track and retrieve.

Enums

AccountRecordData
Represents types of records retrieved from the store
AccountStatus
Represents the status of an account tracked by the client.
AccountStorageFilter
Filters for narrowing the storage slots returned by the client’s store.
BlockRelevance
Expresses metadata about the block header.
InputNoteState
The possible states of a tracked note.
NoteExportType
Variants of NoteFile that can be exported from an OutputNoteRecord.
NoteFilter
Filters for narrowing the set of notes returned by the client’s store.
NoteRecordError
Errors generated from note records.
OutputNoteState
Possible states for a single output note. They describe the note’s state and dictate its lifecycle.
PartialBlockchainFilter
Filters for searching specific MMR nodes.
StoreError
Errors generated from the store.
TransactionFilter
Filters for narrowing the set of transactions returned by the client’s store.

Traits

Store
The Store trait exposes all methods that the client store needs in order to track the current state.