pub enum AccountStatus {
New {
seed: Word,
},
Tracked,
Locked {
seed: Option<Word>,
},
}Expand description
Represents the status of an account tracked by the client.
The status of an account may change by local or external factors.
Variants
New
The account is new and hasn’t been used yet. The seed used to create the account is stored in this state.
Tracked
The account is tracked by the node and was used at least once.
Locked
The local account state doesn’t match the node’s state, rendering it unusable.
Only used for private accounts.
The seed is preserved for private accounts with nonce=0 that need reconstruction via
Account::new().
Implementations