pub enum InputNoteState {
Expected(ExpectedNoteState),
Unverified(UnverifiedNoteState),
Committed(CommittedNoteState),
Invalid(InvalidNoteState),
ProcessingAuthenticated(ProcessingAuthenticatedNoteState),
ProcessingUnauthenticated(ProcessingUnauthenticatedNoteState),
ConsumedAuthenticatedLocal(ConsumedAuthenticatedLocalNoteState),
ConsumedUnauthenticatedLocal(ConsumedUnauthenticatedLocalNoteState),
ConsumedExternal(ConsumedExternalNoteState),
}Expand description
The possible states of a tracked note.
Variants
Expected(ExpectedNoteState)
Tracked by the client but without a network inclusion proof.
Unverified(UnverifiedNoteState)
The store holds the note’s inclusion proof, but it was not yet verified.
Committed(CommittedNoteState)
The store holds the note’s inclusion proof, which was verified.
Invalid(InvalidNoteState)
The store holds the note’s inclusion proof, which is invalid.
ProcessingAuthenticated(ProcessingAuthenticatedNoteState)
Authenticated note being consumed locally by the client, awaiting network confirmation.
ProcessingUnauthenticated(ProcessingUnauthenticatedNoteState)
Unauthenticated note being consumed locally by the client, awaiting network confirmation.
ConsumedAuthenticatedLocal(ConsumedAuthenticatedLocalNoteState)
Authenticated note consumed locally by the client and confirmed by the network.
ConsumedUnauthenticatedLocal(ConsumedUnauthenticatedLocalNoteState)
Unauthenticated note consumed locally by the client and confirmed by the network.
ConsumedExternal(ConsumedExternalNoteState)
Note consumed by an external account (e.g. an account not tracked by the client) and confirmed by the network.
Implementations
Sourceimpl InputNoteState
impl InputNoteState
pub const STATE_EXPECTED: u8 = 0
pub const STATE_UNVERIFIED: u8 = 1
pub const STATE_COMMITTED: u8 = 2
pub const STATE_INVALID: u8 = 3
pub const STATE_PROCESSING_AUTHENTICATED: u8 = 4
pub const STATE_PROCESSING_UNAUTHENTICATED: u8 = 5
pub const STATE_CONSUMED_AUTHENTICATED_LOCAL: u8 = 6
pub const STATE_CONSUMED_UNAUTHENTICATED_LOCAL: u8 = 7
pub const STATE_CONSUMED_EXTERNAL: u8 = 8
Sourcepub fn discriminant(&self) -> u8
pub fn discriminant(&self) -> u8
Returns a unique identifier for each note state.