pub enum NoteFilter {
All,
Committed,
Consumed,
Expected,
List(Vec<NoteId>),
Nullifiers(Vec<Nullifier>),
Processing,
Unique(NoteId),
Unspent,
Unverified,
}Expand description
Filters for narrowing the set of notes returned by the client’s store.
Variants
All
Return a list of all notes (InputNoteRecord or OutputNoteRecord).
Committed
Return a list of committed notes (InputNoteRecord or OutputNoteRecord). These
represent notes that the blockchain has included in a block.
Consumed
Filter by consumed notes (InputNoteRecord or OutputNoteRecord). notes that have
been used as inputs in transactions.
Expected
Return a list of expected notes (InputNoteRecord or OutputNoteRecord). These
represent notes for which the store doesn’t have anchor data.
List(Vec<NoteId>)
Return a list containing any notes that match with the provided NoteId vector.
Nullifiers(Vec<Nullifier>)
Return a list containing any notes that match the provided Nullifier vector.
Processing
Return a list of notes that are currently being processed. This filter doesn’t apply to output notes.
Unique(NoteId)
Return a list containing the note that matches with the provided NoteId. The query will
return an error if the note isn’t found.
Unspent
Return a list containing notes that haven’t been nullified yet, this includes expected, committed, processing and unverified notes.
Unverified
Return a list containing notes with unverified inclusion proofs. This filter doesn’t apply to output notes.