pub enum OutputNoteState {
ExpectedPartial,
ExpectedFull {
recipient: NoteRecipient,
},
CommittedPartial {
inclusion_proof: NoteInclusionProof,
},
CommittedFull {
recipient: NoteRecipient,
inclusion_proof: NoteInclusionProof,
},
Consumed {
block_height: BlockNumber,
recipient: NoteRecipient,
},
}Expand description
Possible states for a single output note. They describe the note’s state and dictate its lifecycle.
Variants
ExpectedPartial
Note without known recipient is expected to be committed on chain.
ExpectedFull
Note with known recipient is expected to be committed on chain.
Fields
recipient: NoteRecipientDetails needed consume the note.
CommittedPartial
Note without known recipient has been committed on chain, and can be consumed in a transaction.
Fields
inclusion_proof: NoteInclusionProofInclusion proof for the note inside the chain block.
CommittedFull
Note with known recipient has been committed on chain, and can be consumed in a transaction.
Fields
recipient: NoteRecipientDetails needed to consume the note.
inclusion_proof: NoteInclusionProofInclusion proof for the note inside the chain block.
Consumed
Note has been nullified on chain.
Fields
block_height: BlockNumberBlock height at which the note was consumed.
recipient: NoteRecipientDetails needed to consume the note.
Implementations
Sourceimpl OutputNoteState
impl OutputNoteState
pub const STATE_EXPECTED_PARTIAL: u8 = 0
pub const STATE_EXPECTED_FULL: u8 = 1
pub const STATE_COMMITTED_PARTIAL: u8 = 2
pub const STATE_COMMITTED_FULL: u8 = 3
pub const STATE_CONSUMED: u8 = 4
Sourcepub fn discriminant(&self) -> u8
pub fn discriminant(&self) -> u8
Returns a unique identifier for each note state.
pub fn recipient(&self) -> Option<&NoteRecipient>
pub fn inclusion_proof(&self) -> Option<&NoteInclusionProof>
pub fn inclusion_proof_received( &self, inclusion_proof: NoteInclusionProof, ) -> Result<Option<OutputNoteState>, NoteRecordError>
pub fn nullifier_received( &self, block_height: BlockNumber, ) -> Result<Option<OutputNoteState>, NoteRecordError>