pub enum TransactionFilter {
All,
Uncommitted,
Ids(Vec<TransactionId>),
ExpiredBefore(BlockNumber),
}Expand description
Filters for narrowing the set of transactions returned by the client’s store.
Variants
All
Return all transactions.
Uncommitted
Filter by transactions that haven’t yet been committed to the blockchain as per the last sync.
Ids(Vec<TransactionId>)
Return a list of the transaction that matches the provided TransactionIds.
ExpiredBefore(BlockNumber)
Return a list of the expired transactions that were executed before the provided
BlockNumber. Transactions created after the provided block number are not
considered.
A transaction is considered expired if is uncommitted and the transaction’s block number is less than the provided block number.
Implementations