pub struct CommittedNoteState {
pub metadata: NoteMetadata,
pub inclusion_proof: NoteInclusionProof,
pub block_note_root: Word,
}Expand description
Information related to notes in the InputNoteState::Committed state.
Fields
metadata: NoteMetadataMetadata associated with the note, including sender, note type, tag and other additional information.
inclusion_proof: NoteInclusionProofInclusion proof for the note inside the chain block.
block_note_root: WordRoot of the note tree inside the block that verifies the note inclusion proof.