pub struct ConsumedUnauthenticatedLocalNoteState {
pub metadata: NoteMetadata,
pub nullifier_block_height: BlockNumber,
pub submission_data: NoteSubmissionData,
pub consumed_tx_order: Option<u32>,
}Expand description
Information related to notes in the InputNoteState::ConsumedUnauthenticatedLocal state.
Fields
metadata: NoteMetadataMetadata associated with the note, including sender, note type, tag and other additional information.
nullifier_block_height: BlockNumberBlock height at which the note was nullified.
submission_data: NoteSubmissionDataInformation about the submission of the note.
consumed_tx_order: Option<u32>Per-account position of the consuming transaction within the account’s execution chain
for the block. None if the order has not been determined yet.