pub struct ExpectedNoteState {
pub metadata: Option<NoteMetadata>,
pub after_block_num: BlockNumber,
pub tag: Option<NoteTag>,
}Expand description
Information related to notes in the InputNoteState::Expected state.
Fields
metadata: Option<NoteMetadata>Metadata associated with the note, including sender, note type, tag and other additional information. The note metadata is only known if the note was created by the client or by retrieving it from the node. Imported or future notes may not have metadata.
after_block_num: BlockNumberBlock height after which the note is expected to be committed.
tag: Option<NoteTag>A tag used to identify the note. The tag may not be known if the note was imported without it or if it’s a future note.