pub struct InvalidNoteState {
pub metadata: NoteMetadata,
pub invalid_inclusion_proof: NoteInclusionProof,
pub block_note_root: Word,
}Expand description
Information related to notes in the InputNoteState::Invalid state.
Fields
metadata: NoteMetadataMetadata associated with the note, including sender, note type, tag and other additional information.
invalid_inclusion_proof: NoteInclusionProofInclusion proof for the note inside the chain block, verified to be invalid.
block_note_root: WordRoot of the note tree inside the block that invalidates the note inclusion proof.