pub struct NoteSubmissionData {
pub submitted_at: Option<u64>,
pub consumer_account: AccountId,
pub consumer_transaction: TransactionId,
}Expand description
Information about a locally consumed note submitted to the node.
Fields
submitted_at: Option<u64>The timestamp at which the note was submitted.
consumer_account: AccountIdThe ID of the account that is consuming the note.
consumer_transaction: TransactionIdThe ID of the transaction that is consuming the note.