pub struct ProcessingAuthenticatedNoteState {
pub metadata: NoteMetadata,
pub inclusion_proof: NoteInclusionProof,
pub block_note_root: Word,
pub submission_data: NoteSubmissionData,
}Expand description
Information related to notes in the InputNoteState::ProcessingAuthenticated state.
Fields
metadata: NoteMetadataMetadata associated with the note, including sender, note type, tag and other additional information.
inclusion_proof: NoteInclusionProofInclusion proof for the note inside the chain block.
block_note_root: WordRoot of the note tree inside the block that verifies the note inclusion proof.
submission_data: NoteSubmissionDataInformation about the submission of the note.