pub struct ProcessingUnauthenticatedNoteState {
pub metadata: NoteMetadata,
pub after_block_num: BlockNumber,
pub submission_data: NoteSubmissionData,
}Expand description
Information related to notes in the InputNoteState::ProcessingUnauthenticated state.
Fields
metadata: NoteMetadataMetadata associated with the note, including sender, note type, tag and other additional information.
after_block_num: BlockNumberBlock height after which the note is expected to be committed.
submission_data: NoteSubmissionDataInformation about the submission of the note.