pub struct UnverifiedNoteState {
pub metadata: NoteMetadata,
pub inclusion_proof: NoteInclusionProof,
}Expand description
Information related to notes in the InputNoteState::Unverified state.
Fields
metadata: NoteMetadataMetadata associated with the note, including sender, note type, tag and other additional information.
inclusion_proof: NoteInclusionProofInclusion proof for the note inside the chain block. This proof isn’t yet verified.