pub struct InputNoteRecord { /* private fields */ }Expand description
Represents a Note of which the Store can keep track and retrieve.
An InputNoteRecord contains all the information of a NoteDetails, in addition of
specific information about the note state.
Once a proof is received, the InputNoteRecord can be transformed into an InputNote and
used as input for transactions.
It is also possible to convert Note and InputNote into InputNoteRecord (we fill the
metadata and inclusion_proof fields if possible).
Notes can also be consumed as unauthenticated notes, where their existence is verified by the network.
Implementations
Sourceimpl InputNoteRecord
impl InputNoteRecord
pub fn new( details: NoteDetails, created_at: Option<u64>, state: InputNoteState, ) -> InputNoteRecord
Sourcepub fn commitment(&self) -> Option<Word>
pub fn commitment(&self) -> Option<Word>
Returns the note’s commitment, if the record contains the NoteMetadata.
Sourcepub fn assets(&self) -> &NoteAssets
pub fn assets(&self) -> &NoteAssets
Returns the note’s assets.
Sourcepub fn created_at(&self) -> Option<u64>
pub fn created_at(&self) -> Option<u64>
Returns the timestamp in which the note record was created, if available.
Sourcepub fn state(&self) -> &InputNoteState
pub fn state(&self) -> &InputNoteState
Returns the current note state.
Sourcepub fn metadata(&self) -> Option<&NoteMetadata>
pub fn metadata(&self) -> Option<&NoteMetadata>
Returns the note metadata, which will be available depending on the note’s current state.
Sourcepub fn inclusion_proof(&self) -> Option<&NoteInclusionProof>
pub fn inclusion_proof(&self) -> Option<&NoteInclusionProof>
Returns the inclusion proof for the note.
Sourcepub fn details(&self) -> &NoteDetails
pub fn details(&self) -> &NoteDetails
Returns the note’s details.
Sourcepub fn consumer_transaction_id(&self) -> Option<&TransactionId>
pub fn consumer_transaction_id(&self) -> Option<&TransactionId>
If the note was consumed locally, it returns the corresponding transaction ID.
Otherwise, returns None.
Sourcepub fn is_authenticated(&self) -> bool
pub fn is_authenticated(&self) -> bool
Returns true if the note is authenticated, meaning that it has the necessary inclusion proof and block header information to be considered valid.
Sourcepub fn is_consumed(&self) -> bool
pub fn is_consumed(&self) -> bool
Returns true if the note has been nullified on chain.
Sourcepub fn is_processing(&self) -> bool
pub fn is_processing(&self) -> bool
Returns true if the note is currently being processed by a local transaction.
Sourcepub fn is_committed(&self) -> bool
pub fn is_committed(&self) -> bool
Returns true if the note is in a committed state (i.e. it has a valid inclusion proof but isn’t consumed or being processed).