pub struct OutputNoteRecord { /* private fields */ }Expand description
Represents a Note which was the result of executing some transaction of which the Store can keep track and retrieve.
An OutputNoteRecord contains all the information of a Note while it allows for not
knowing the recipient details (nullifier, script, inputs and serial number).
It is also possible to convert Note into OutputNoteRecord with the state
OutputNoteState::ExpectedFull.
Implementations
Sourceimpl OutputNoteRecord
impl OutputNoteRecord
pub fn new( recipient_digest: Word, assets: NoteAssets, metadata: NoteMetadata, state: OutputNoteState, expected_height: BlockNumber, ) -> OutputNoteRecord
pub fn id(&self) -> NoteId
pub fn recipient_digest(&self) -> Word
pub fn assets(&self) -> &NoteAssets
pub fn state(&self) -> &OutputNoteState
pub fn metadata(&self) -> &NoteMetadata
pub fn inclusion_proof(&self) -> Option<&NoteInclusionProof>
pub fn recipient(&self) -> Option<&NoteRecipient>
pub fn nullifier(&self) -> Option<Nullifier>
pub fn expected_height(&self) -> BlockNumber
Sourcepub fn is_consumed(&self) -> bool
pub fn is_consumed(&self) -> bool
Returns true if the note has been nullified on chain.
Sourcepub fn is_committed(&self) -> bool
pub fn is_committed(&self) -> bool
Returns true if the note is in a committed state (i.e. it has a inclusion proof but isn’t consumed) regardless of whether it is full or partial.
Sourceimpl OutputNoteRecord
impl OutputNoteRecord
pub fn from_full_note( note: Note, expected_height: BlockNumber, ) -> OutputNoteRecord
pub fn from_partial_note( partial_note: &PartialNote, expected_height: BlockNumber, ) -> OutputNoteRecord
Sourcepub fn try_from_output_note(
output_note: OutputNote,
expected_height: BlockNumber,
) -> Result<OutputNoteRecord, NoteRecordError>
pub fn try_from_output_note( output_note: OutputNote, expected_height: BlockNumber, ) -> Result<OutputNoteRecord, NoteRecordError>
OutputNote can always be turned into an OutputNoteRecord when they’re either
OutputNote::Full or OutputNote::Partial and always fail the conversion if it’s
OutputNote::Header. This also mean that output_note.try_from() can also be used as a
way to filter the full and partial output notes.
Sourceimpl OutputNoteRecord
impl OutputNoteRecord
Sourcepub fn into_note_file(
self,
export_type: &NoteExportType,
) -> Result<NoteFile, NoteRecordError>
pub fn into_note_file( self, export_type: &NoteExportType, ) -> Result<NoteFile, NoteRecordError>