pub enum NoteUpdateAction {
Commit(CommittedNote),
Insert(InputNoteRecord),
Discard,
}Expand description
The action to be taken when a note update is received as part of the sync response.
Variants
Commit(CommittedNote)
The note commit update is relevant and the specified note should be marked as committed in the store, storing its inclusion proof.
Insert(InputNoteRecord)
The public note is relevant and should be inserted into the store.
Discard
The note update is not relevant and should be discarded.