pub struct PartialBlockchainUpdates {
pub new_peaks: MmrPeaks,
/* private fields */
}Expand description
Contains all the partial blockchain information that needs to be added in the client’s store after a sync: block headers, authentication nodes and the MMR peaks at the new sync height.
Fields
new_peaks: MmrPeaksMMR peaks at the new sync height.
Implementations
Sourceimpl PartialBlockchainUpdates
impl PartialBlockchainUpdates
Sourcepub fn insert(
&mut self,
block_header: BlockHeader,
has_client_notes: bool,
new_authentication_nodes: Vec<(InOrderIndex, Word)>,
)
pub fn insert( &mut self, block_header: BlockHeader, has_client_notes: bool, new_authentication_nodes: Vec<(InOrderIndex, Word)>, )
Adds or updates a block header in this PartialBlockchainUpdates.
If the block header already exists (same block number), the has_client_notes flag is
OR-ed. Otherwise a new entry is added.
Sourcepub fn block_headers(&self) -> impl Iterator<Item = &(BlockHeader, bool)>
pub fn block_headers(&self) -> impl Iterator<Item = &(BlockHeader, bool)>
Returns the new block headers to be stored, along with a flag indicating whether the block contains notes that are relevant to the client.
Sourcepub fn new_authentication_nodes(&self) -> &[(InOrderIndex, Word)]
pub fn new_authentication_nodes(&self) -> &[(InOrderIndex, Word)]
Returns the new authentication nodes that are meant to be stored in order to authenticate block headers.