pub struct StateSync { /* private fields */ }Expand description
The state sync components encompasses the client’s sync logic. It is then used to request updates from the node and apply them to the relevant elements. The updates are then returned and can be applied to the store to persist the changes.
When created it receives a callback that will be executed when a new note inclusion is received in the sync response.
Implementations
Sourceimpl StateSync
impl StateSync
Sourcepub fn new(
rpc_api: Arc<dyn NodeRpcClient>,
note_screener: Arc<dyn OnNoteReceived>,
tx_graceful_blocks: Option<u32>,
) -> StateSync
pub fn new( rpc_api: Arc<dyn NodeRpcClient>, note_screener: Arc<dyn OnNoteReceived>, tx_graceful_blocks: Option<u32>, ) -> StateSync
Creates a new instance of the state sync component.
Arguments
rpc_api- The RPC client used to communicate with the node.on_note_received- A callback to be executed when a new note inclusion is received.tx_graceful_blocks- The number of blocks that are considered old enough to discard.note_screener- The note screener used to check the relevance of notes.
Sourcepub async fn sync_state(
&self,
current_partial_mmr: PartialMmr,
accounts: Vec<AccountHeader>,
note_tags: BTreeSet<NoteTag>,
unspent_input_notes: Vec<InputNoteRecord>,
unspent_output_notes: Vec<OutputNoteRecord>,
uncommitted_transactions: Vec<TransactionRecord>,
) -> Result<StateSyncUpdate, ClientError>
pub async fn sync_state( &self, current_partial_mmr: PartialMmr, accounts: Vec<AccountHeader>, note_tags: BTreeSet<NoteTag>, unspent_input_notes: Vec<InputNoteRecord>, unspent_output_notes: Vec<OutputNoteRecord>, uncommitted_transactions: Vec<TransactionRecord>, ) -> Result<StateSyncUpdate, ClientError>
Syncs the state of the client with the chain tip of the node, returning the updates that should be applied to the store.
During the sync process, the client will go through the following steps:
- A request is sent to the node to get the state updates. This request includes tracked account IDs and the tags of notes that might have changed or that might be of interest to the client.
- A response is received with the current state of the network. The response includes information about new and committed notes, updated accounts, and committed transactions.
- Tracked public accounts are updated and private accounts are validated against the node state.
- Tracked notes are updated with their new states. Notes might be committed or nullified during the sync processing.
- New notes are checked, and only relevant ones are stored. Relevance is determined by the
OnNoteReceivedcallback. - Transactions are updated with their new states. Transactions might be committed or discarded.
- The MMR is updated with the new peaks and authentication nodes.
Arguments
current_partial_blockchain- The current partial view of the blockchain.accounts- All the headers of tracked accounts.note_tags- The note tags to be used in the sync state request.unspent_input_notes- The current state of unspent input notes tracked by the client.unspent_output_notes- The current state of unspent output notes tracked by the client.