pub struct SyncSummary {
pub block_num: BlockNumber,
pub new_public_notes: Vec<NoteId>,
pub committed_notes: Vec<NoteId>,
pub consumed_notes: Vec<NoteId>,
pub updated_accounts: Vec<AccountId>,
pub locked_accounts: Vec<AccountId>,
pub committed_transactions: Vec<TransactionId>,
}Expand description
Contains stats about the sync operation.
Fields
block_num: BlockNumberBlock number up to which the client has been synced.
new_public_notes: Vec<NoteId>IDs of new public notes that the client has received.
committed_notes: Vec<NoteId>IDs of tracked notes that have been committed.
consumed_notes: Vec<NoteId>IDs of notes that have been consumed.
updated_accounts: Vec<AccountId>IDs of on-chain accounts that have been updated.
locked_accounts: Vec<AccountId>IDs of private accounts that have been locked.
committed_transactions: Vec<TransactionId>IDs of committed transactions.
Implementations
Sourceimpl SyncSummary
impl SyncSummary
pub fn new( block_num: BlockNumber, new_public_notes: Vec<NoteId>, committed_notes: Vec<NoteId>, consumed_notes: Vec<NoteId>, updated_accounts: Vec<AccountId>, locked_accounts: Vec<AccountId>, committed_transactions: Vec<TransactionId>, ) -> SyncSummary
pub fn new_empty(block_num: BlockNumber) -> SyncSummary
pub fn is_empty(&self) -> bool
pub fn combine_with(&mut self, other: SyncSummary)