pub struct TransactionUpdateTracker { /* private fields */ }Expand description
Contains transaction changes to apply to the store.
Implementations
Sourceimpl TransactionUpdateTracker
impl TransactionUpdateTracker
Sourcepub fn new(transactions: Vec<TransactionRecord>) -> TransactionUpdateTracker
pub fn new(transactions: Vec<TransactionRecord>) -> TransactionUpdateTracker
Creates a new TransactionUpdateTracker
Sourcepub fn committed_transactions(&self) -> impl Iterator<Item = &TransactionRecord>
pub fn committed_transactions(&self) -> impl Iterator<Item = &TransactionRecord>
Returns a reference to committed transactions.
Sourcepub fn discarded_transactions(&self) -> impl Iterator<Item = &TransactionRecord>
pub fn discarded_transactions(&self) -> impl Iterator<Item = &TransactionRecord>
Returns a reference to discarded transactions.
Sourcepub fn updated_transaction_ids(&self) -> impl Iterator<Item = TransactionId>
pub fn updated_transaction_ids(&self) -> impl Iterator<Item = TransactionId>
Returns transaction IDs of all transactions that have been updated.
Sourcepub fn apply_transaction_inclusion(
&mut self,
transaction_inclusion: &TransactionInclusion,
timestamp: u64,
)
pub fn apply_transaction_inclusion( &mut self, transaction_inclusion: &TransactionInclusion, timestamp: u64, )
Applies the necessary state transitions to the TransactionUpdateTracker when a
transaction is included in a block.
Sourcepub fn apply_sync_height_update(
&mut self,
new_sync_height: BlockNumber,
tx_graceful_blocks: Option<u32>,
)
pub fn apply_sync_height_update( &mut self, new_sync_height: BlockNumber, tx_graceful_blocks: Option<u32>, )
Applies the necessary state transitions to the TransactionUpdateTracker when a the sync
height of the client is updated. This may result in stale or expired transactions.
Sourcepub fn apply_input_note_nullified(&mut self, input_note_nullifier: Nullifier)
pub fn apply_input_note_nullified(&mut self, input_note_nullifier: Nullifier)
Applies the necessary state transitions to the TransactionUpdateTracker when a note is
nullified. this may result in transactions being discarded because they were processing the
nullified note.
Sourcepub fn apply_invalid_initial_account_state(
&mut self,
invalid_account_state: Word,
)
pub fn apply_invalid_initial_account_state( &mut self, invalid_account_state: Word, )
Discards transactions that have the same initial account state as the provided one.