pub enum AccountComponentInterface {
BasicWallet,
BasicFungibleFaucet,
NetworkFungibleFaucet,
AuthEcdsaK256Keccak,
AuthEcdsaK256KeccakAcl,
AuthEcdsaK256KeccakMultisig,
AuthFalcon512Rpo,
AuthFalcon512RpoAcl,
AuthFalcon512RpoMultisig,
AuthNoAuth,
Custom(Vec<AccountProcedureRoot>),
}Expand description
The enum holding all possible account interfaces which could be loaded to some account.
Variants
BasicWallet
Exposes procedures from the BasicWallet module.
BasicFungibleFaucet
Exposes procedures from the
BasicFungibleFaucet module.
NetworkFungibleFaucet
Exposes procedures from the
NetworkFungibleFaucet module.
AuthEcdsaK256Keccak
Exposes procedures from the
AuthEcdsaK256Keccak module.
AuthEcdsaK256KeccakAcl
Exposes procedures from the
AuthEcdsaK256KeccakAcl module.
AuthEcdsaK256KeccakMultisig
Exposes procedures from the
AuthEcdsaK256KeccakMultisig module.
AuthFalcon512Rpo
Exposes procedures from the
AuthFalcon512Rpo module.
AuthFalcon512RpoAcl
Exposes procedures from the
AuthFalcon512RpoAcl module.
AuthFalcon512RpoMultisig
Exposes procedures from the
AuthFalcon512RpoMultisig module.
AuthNoAuth
Exposes procedures from the NoAuth module.
This authentication scheme provides no cryptographic authentication and only increments the nonce if the account state has actually changed during transaction execution.
Custom(Vec<AccountProcedureRoot>)
A non-standard, custom interface which exposes the contained procedures.
Custom interface holds all procedures which are not part of some standard interface which is used by this account.
Implementations
Sourceimpl AccountComponentInterface
impl AccountComponentInterface
Sourcepub fn name(&self) -> String
pub fn name(&self) -> String
Returns a string line with the name of the AccountComponentInterface enum variant.
In case of a AccountComponentInterface::Custom along with the name of the enum variant
the vector of shortened hex representations of the used procedures is returned, e.g.
Custom([0x6d93447, 0x0bf23d8]).
Sourcepub fn is_auth_component(&self) -> bool
pub fn is_auth_component(&self) -> bool
Returns true if this component interface is an authentication component.
TODO: currently this can identify only standard auth components
Sourcepub fn get_auth_schemes(&self, storage: &AccountStorage) -> Vec<AuthScheme>
pub fn get_auth_schemes(&self, storage: &AccountStorage) -> Vec<AuthScheme>
Returns the authentication schemes associated with this component interface.