pub enum ForeignAccount {
Public(AccountId, AccountStorageRequirements),
Private(PartialAccount),
}Expand description
Account types for foreign procedure invocation.
Variants
Public(AccountId, AccountStorageRequirements)
Public account data will be retrieved from the network at execution time, based on the account ID. The second element of the tuple indicates which storage slot indices and map keys are desired to be retrieved.
Private(PartialAccount)
Private account data requires PartialAccount to be passed. An account witness
will be retrieved from the network at execution time so that it can be used as inputs to
the transaction kernel.
Implementations
Sourceimpl ForeignAccount
impl ForeignAccount
Sourcepub fn public(
account_id: AccountId,
storage_requirements: AccountStorageRequirements,
) -> Result<ForeignAccount, TransactionRequestError>
pub fn public( account_id: AccountId, storage_requirements: AccountStorageRequirements, ) -> Result<ForeignAccount, TransactionRequestError>
Creates a new ForeignAccount::Public. The account’s components (code, storage header and
inclusion proof) will be retrieved at execution time, alongside particular storage slot
maps correspondent to keys passed in indices.
Sourcepub fn private(
account: impl Into<PartialAccount>,
) -> Result<ForeignAccount, TransactionRequestError>
pub fn private( account: impl Into<PartialAccount>, ) -> Result<ForeignAccount, TransactionRequestError>
Creates a new ForeignAccount::Private. A proof of the account’s inclusion will be
retrieved at execution time.
pub fn storage_slot_requirements(&self) -> AccountStorageRequirements
Sourcepub fn account_id(&self) -> AccountId
pub fn account_id(&self) -> AccountId
Returns the foreign account’s AccountId.