pub enum InputNote {
Authenticated {
note: Note,
proof: NoteInclusionProof,
},
Unauthenticated {
note: Note,
},
}Expand description
An input note for a transaction.
Variants
Authenticated
Input notes whose existences in the chain is verified by the transaction kernel.
Unauthenticated
Input notes whose existence in the chain is not verified by the transaction kernel, but instead is delegated to the protocol kernels.
Implementations
Sourceimpl InputNote
impl InputNote
Sourcepub fn authenticated(note: Note, proof: NoteInclusionProof) -> InputNote
pub fn authenticated(note: Note, proof: NoteInclusionProof) -> InputNote
Returns an authenticated InputNote.
Sourcepub fn unauthenticated(note: Note) -> InputNote
pub fn unauthenticated(note: Note) -> InputNote
Returns an unauthenticated InputNote.
Sourcepub fn proof(&self) -> Option<&NoteInclusionProof>
pub fn proof(&self) -> Option<&NoteInclusionProof>
Returns a reference to the inclusion proof of the note.
Sourcepub fn location(&self) -> Option<&NoteLocation>
pub fn location(&self) -> Option<&NoteLocation>
Returns a reference to the location of the note.