pub enum OutputNote {
Public(PublicOutputNote),
Private(PrivateNoteHeader),
}Expand description
Output note types that can appear in a proven transaction.
This enum represents the final form of output notes after proving. Unlike RawOutputNote,
this enum:
- Does not include partial notes (they are converted to headers).
- Wraps public notes in
PublicOutputNotewhich enforces size limits. - Contains only the minimal information needed for verification.
Variants
Public(PublicOutputNote)
A public note with full details, size-validated.
Private(PrivateNoteHeader)
A note private header (for private notes).
Implementations
Sourceimpl OutputNote
impl OutputNote
Sourcepub fn id(&self) -> NoteId
pub fn id(&self) -> NoteId
Unique note identifier.
This value is both an unique identifier and a commitment to the note.
Sourcepub fn metadata(&self) -> &NoteMetadata
pub fn metadata(&self) -> &NoteMetadata
Note’s metadata.
Sourcepub fn assets(&self) -> Option<&NoteAssets>
pub fn assets(&self) -> Option<&NoteAssets>
The assets contained in the note, if available.
Returns Some for public notes, None for private notes.
Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Returns a commitment to the note and its metadata.
hash(NOTE_ID || NOTE_METADATA_COMMITMENT)
Sourcepub fn recipient(&self) -> Option<&NoteRecipient>
pub fn recipient(&self) -> Option<&NoteRecipient>
Returns the recipient of the public note, if this is a public note.