pub struct AccountInterface { /* private fields */ }Expand description
An AccountInterface describes the exported, callable procedures of an account.
A note script’s compatibility with this interface can be inspected to check whether the note may result in a successful execution against this account.
Implementations
Sourceimpl AccountInterface
Constructors and public accessors
impl AccountInterface
Constructors and public accessors
Sourcepub fn new(
account_id: AccountId,
auth: Vec<AuthScheme>,
components: Vec<AccountComponentInterface>,
) -> AccountInterface
pub fn new( account_id: AccountId, auth: Vec<AuthScheme>, components: Vec<AccountComponentInterface>, ) -> AccountInterface
Creates a new AccountInterface instance from the provided account ID, authentication
schemes and account component interfaces.
Sourcepub fn account_type(&self) -> AccountType
pub fn account_type(&self) -> AccountType
Returns the type of the reference account.
Sourcepub fn is_regular_account(&self) -> bool
pub fn is_regular_account(&self) -> bool
Returns true if the reference account is a regular.
Sourcepub fn has_public_state(&self) -> bool
pub fn has_public_state(&self) -> bool
Returns true if the full state of the account is public on chain, i.e. if the modes are
AccountStorageMode::Public or
AccountStorageMode::Network,
false otherwise.
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Returns true if the reference account is a private account, false otherwise.
Sourcepub fn is_public(&self) -> bool
pub fn is_public(&self) -> bool
Returns true if the reference account is a public account, false otherwise.
Sourcepub fn is_network(&self) -> bool
pub fn is_network(&self) -> bool
Returns true if the reference account is a network account, false otherwise.
Sourcepub fn auth(&self) -> &Vec<AuthScheme>
pub fn auth(&self) -> &Vec<AuthScheme>
Returns a reference to the vector of used authentication schemes.
Sourcepub fn components(&self) -> &Vec<AccountComponentInterface>
pub fn components(&self) -> &Vec<AccountComponentInterface>
Returns a reference to the set of used component interfaces.
Sourceimpl AccountInterface
Code generation
impl AccountInterface
Code generation
Sourcepub fn build_send_notes_script(
&self,
output_notes: &[PartialNote],
expiration_delta: Option<u16>,
) -> Result<TransactionScript, AccountInterfaceError>
pub fn build_send_notes_script( &self, output_notes: &[PartialNote], expiration_delta: Option<u16>, ) -> Result<TransactionScript, AccountInterfaceError>
Returns a transaction script which sends the specified notes using the procedures available in the current interface.
Provided expiration_delta parameter is used to specify how close to the transaction’s
reference block the transaction must be included into the chain. For example, if the
transaction’s reference block is 100 and transaction expiration delta is 10, the transaction
can be included into the chain by block 110. If this does not happen, the transaction is
considered expired and cannot be included into the chain.
Currently only AccountComponentInterface::BasicWallet and
AccountComponentInterface::BasicFungibleFaucet interfaces are supported for the
send_note script creation. Attempt to generate the script using some other interface will
lead to an error. In case both supported interfaces are available in the account, the script
will be generated for the AccountComponentInterface::BasicFungibleFaucet interface.
Example
Example of the send_note script with specified expiration delta and one output note:
begin
push.{expiration_delta} exec.::miden::protocol::tx::update_expiration_block_delta
push.{note information}
push.{asset amount}
call.::miden::standards::faucets::basic_fungible::distribute dropw dropw drop
endErrors:
Returns an error if:
- the available interfaces does not support the generation of the standard
send_noteprocedure. - the sender of the note isn’t the account for which the script is being built.
- the note created by the faucet doesn’t contain exactly one asset.
- a faucet tries to distribute an asset with a different faucet ID.