pub struct OutputNotes { /* private fields */ }Expand description
Contains a list of output notes of a transaction. The list can be empty if the transaction does not produce any notes.
Implementations
Sourceimpl OutputNotes
impl OutputNotes
Sourcepub fn new(
notes: Vec<OutputNote>,
) -> Result<OutputNotes, TransactionOutputError>
pub fn new( notes: Vec<OutputNote>, ) -> Result<OutputNotes, TransactionOutputError>
Returns new OutputNotes instantiated from the provide vector of notes.
Errors
Returns an error if:
- The total number of notes is greater than
MAX_OUTPUT_NOTES_PER_TX. - The vector of notes contains duplicates.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns the commitment to the output notes.
The commitment is computed as a sequential hash of (hash, metadata) tuples for the notes created in a transaction.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if this OutputNotes does not contain any notes.
Sourcepub fn get_note(&self, idx: usize) -> &OutputNote
pub fn get_note(&self, idx: usize) -> &OutputNote
Returns a reference to the note located at the specified index.
Sourcepub fn iter(&self) -> impl Iterator<Item = &OutputNote>
pub fn iter(&self) -> impl Iterator<Item = &OutputNote>
Returns an iterator over notes in this OutputNotes.