pub struct TransactionId(/* private fields */);Expand description
A unique identifier of a transaction.
Transaction ID is computed as:
hash(init_account_commitment, final_account_commitment, input_notes_commitment, output_notes_commitment)
This achieves the following properties:
- Transactions are identical if and only if they have the same ID.
- Computing transaction ID can be done solely from public transaction data.
Implementations
Sourceimpl TransactionId
impl TransactionId
Sourcepub fn from_raw(word: Word) -> TransactionId
pub fn from_raw(word: Word) -> TransactionId
Construct without further checks from a given Word
Warning
This requires the caller to uphold the guarantees/invariants of this type (if any). Check the type-level documentation for guarantees/invariants.
Sourcepub fn as_elements(&self) -> &[BaseElement]
pub fn as_elements(&self) -> &[BaseElement]
Returns the elements representation of this value.
Sourceimpl TransactionId
impl TransactionId
Sourcepub fn new(
init_account_commitment: Word,
final_account_commitment: Word,
input_notes_commitment: Word,
output_notes_commitment: Word,
) -> TransactionId
pub fn new( init_account_commitment: Word, final_account_commitment: Word, input_notes_commitment: Word, output_notes_commitment: Word, ) -> TransactionId
Returns a new TransactionId instantiated from the provided transaction components.