pub struct TransactionRequest { /* private fields */ }Expand description
Specifies a transaction request that can be executed by an account.
A request contains information about input notes to be consumed by the transaction (if any), description of the transaction script to be executed (if any), and a set of notes expected to be generated by the transaction or by consuming notes generated by the transaction.
Implementations
Sourceimpl TransactionRequest
impl TransactionRequest
Sourcepub fn input_notes(&self) -> &[Note]
pub fn input_notes(&self) -> &[Note]
Returns a reference to the transaction request’s input note list.
Sourcepub fn input_note_ids(&self) -> impl Iterator<Item = NoteId>
pub fn input_note_ids(&self) -> impl Iterator<Item = NoteId>
Returns a list of all input note IDs.
Sourcepub fn incoming_assets(
&self,
) -> (BTreeMap<AccountId, u64>, BTreeSet<NonFungibleAsset>)
pub fn incoming_assets( &self, ) -> (BTreeMap<AccountId, u64>, BTreeSet<NonFungibleAsset>)
Returns the assets held by the transaction’s input notes.
Sourcepub fn get_note_args(&self) -> BTreeMap<NoteId, Word>
pub fn get_note_args(&self) -> BTreeMap<NoteId, Word>
Sourcepub fn expected_output_own_notes(&self) -> Vec<Note>
pub fn expected_output_own_notes(&self) -> Vec<Note>
Returns the expected output own notes of the transaction.
In this context “own notes” refers to notes that are expected to be created directly by the transaction script, rather than notes that are created as a result of consuming other notes.
Sourcepub fn expected_output_recipients(&self) -> impl Iterator<Item = &NoteRecipient>
pub fn expected_output_recipients(&self) -> impl Iterator<Item = &NoteRecipient>
Returns an iterator over the expected output notes.
Sourcepub fn expected_future_notes(
&self,
) -> impl Iterator<Item = &(NoteDetails, NoteTag)>
pub fn expected_future_notes( &self, ) -> impl Iterator<Item = &(NoteDetails, NoteTag)>
Returns an iterator over expected future notes.
Sourcepub fn script_template(&self) -> &Option<TransactionScriptTemplate>
pub fn script_template(&self) -> &Option<TransactionScriptTemplate>
Returns the TransactionScriptTemplate.
Sourcepub fn advice_map(&self) -> &AdviceMap
pub fn advice_map(&self) -> &AdviceMap
Returns the AdviceMap for the transaction request.
Sourcepub fn advice_map_mut(&mut self) -> &mut AdviceMap
pub fn advice_map_mut(&mut self) -> &mut AdviceMap
Returns a mutable reference to the AdviceMap for the transaction request.
Sourcepub fn merkle_store(&self) -> &MerkleStore
pub fn merkle_store(&self) -> &MerkleStore
Returns the MerkleStore for the transaction request.
Sourcepub fn foreign_accounts(&self) -> &BTreeSet<ForeignAccount>
pub fn foreign_accounts(&self) -> &BTreeSet<ForeignAccount>
Returns the IDs of the required foreign accounts for the transaction request.
Sourcepub fn ignore_invalid_input_notes(&self) -> bool
pub fn ignore_invalid_input_notes(&self) -> bool
Returns whether to ignore invalid input notes or not.
Sourcepub fn script_arg(&self) -> &Option<Word>
pub fn script_arg(&self) -> &Option<Word>
Returns the script argument for the transaction request.