pub struct TransactionResult { /* private fields */ }Expand description
Represents the result of executing a transaction by the client.
It contains an ExecutedTransaction, and a list of future_notes that we expect to receive
in the future (you can check at swap notes for an example of this).
Implementations
Sourceimpl TransactionResult
impl TransactionResult
Sourcepub fn new(
transaction: ExecutedTransaction,
future_notes: Vec<(NoteDetails, NoteTag)>,
) -> Result<TransactionResult, ClientError>
pub fn new( transaction: ExecutedTransaction, future_notes: Vec<(NoteDetails, NoteTag)>, ) -> Result<TransactionResult, ClientError>
Screens the output notes to store and track the relevant ones, and instantiates a
TransactionResult.
Sourcepub fn id(&self) -> TransactionId
pub fn id(&self) -> TransactionId
Returns a unique identifier of this transaction.
Sourcepub fn executed_transaction(&self) -> &ExecutedTransaction
pub fn executed_transaction(&self) -> &ExecutedTransaction
Returns the ExecutedTransaction.
Sourcepub fn created_notes(&self) -> &OutputNotes
pub fn created_notes(&self) -> &OutputNotes
Returns the output notes that were generated as a result of the transaction execution.
Sourcepub fn future_notes(&self) -> &[(NoteDetails, NoteTag)]
pub fn future_notes(&self) -> &[(NoteDetails, NoteTag)]
Returns the list of notes that might be created in the future as a result of the transaction execution.
Sourcepub fn block_num(&self) -> BlockNumber
pub fn block_num(&self) -> BlockNumber
Returns the block against which the transaction was executed.
Sourcepub fn transaction_arguments(&self) -> &TransactionArgs
pub fn transaction_arguments(&self) -> &TransactionArgs
Returns transaction’s TransactionArgs.
Sourcepub fn tx_inputs(&self) -> &TransactionInputs
pub fn tx_inputs(&self) -> &TransactionInputs
Returns a reference to the TransactionInputs.
Sourcepub fn account_delta(&self) -> &AccountDelta
pub fn account_delta(&self) -> &AccountDelta
Returns the AccountDelta that describes the change of state for the executing account.
Sourcepub fn consumed_notes(&self) -> &InputNotes<InputNote>
pub fn consumed_notes(&self) -> &InputNotes<InputNote>
Returns input notes that were consumed as part of the transaction.