pub struct TransactionStoreUpdate { /* private fields */ }Expand description
Represents the changes that need to be applied to the client store as a result of a transaction execution.
Implementations
Sourceimpl TransactionStoreUpdate
impl TransactionStoreUpdate
Sourcepub fn new(
executed_transaction: ExecutedTransaction,
submission_height: BlockNumber,
note_updates: NoteUpdateTracker,
future_notes: Vec<(NoteDetails, NoteTag)>,
new_tags: Vec<NoteTagRecord>,
) -> TransactionStoreUpdate
pub fn new( executed_transaction: ExecutedTransaction, submission_height: BlockNumber, note_updates: NoteUpdateTracker, future_notes: Vec<(NoteDetails, NoteTag)>, new_tags: Vec<NoteTagRecord>, ) -> TransactionStoreUpdate
Creates a new TransactionStoreUpdate instance populated with all relevant note data.
Arguments
executed_transaction: The executed transaction details.submission_height: The block number at which the transaction was submitted.note_updates: The note updates that need to be applied to the store after the transaction execution.future_notes: Notes expected to be received in follow-up transactions (e.g. swap paybacks).new_tags: New note tags that need to be tracked because of created notes.
Sourcepub fn executed_transaction(&self) -> &ExecutedTransaction
pub fn executed_transaction(&self) -> &ExecutedTransaction
Returns the executed transaction.
Sourcepub fn submission_height(&self) -> BlockNumber
pub fn submission_height(&self) -> BlockNumber
Returns the block number at which the transaction was submitted.
Sourcepub fn future_notes(&self) -> &[(NoteDetails, NoteTag)]
pub fn future_notes(&self) -> &[(NoteDetails, NoteTag)]
Returns the future notes that should be tracked as a result of the transaction.
Sourcepub fn note_updates(&self) -> &NoteUpdateTracker
pub fn note_updates(&self) -> &NoteUpdateTracker
Returns the note updates that need to be applied after the transaction execution.
Returns the new tags that were created as part of the transaction.