pub struct TransactionSummary { /* private fields */ }Expand description
The summary of the changes that result from executing a transaction.
These are the account delta and the consumed and created notes. Because this data is intended to be used for signing a transaction a user-defined salt is included as well.
Implementations
Sourceimpl TransactionSummary
impl TransactionSummary
Sourcepub fn new(
account_delta: AccountDelta,
input_notes: InputNotes<InputNote>,
output_notes: OutputNotes,
salt: Word,
) -> TransactionSummary
pub fn new( account_delta: AccountDelta, input_notes: InputNotes<InputNote>, output_notes: OutputNotes, salt: Word, ) -> TransactionSummary
Creates a new TransactionSummary from the provided parts.
Sourcepub fn account_delta(&self) -> &AccountDelta
pub fn account_delta(&self) -> &AccountDelta
Returns the account delta of this transaction summary.
Sourcepub fn input_notes(&self) -> &InputNotes<InputNote>
pub fn input_notes(&self) -> &InputNotes<InputNote>
Returns the input notes of this transaction summary.
Sourcepub fn output_notes(&self) -> &OutputNotes
pub fn output_notes(&self) -> &OutputNotes
Returns the output notes of this transaction summary.
Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Computes the commitment to the TransactionSummary.
This can be used to sign the transaction.