Module vm

Module vm 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides types for working with the virtual machine within the Miden network.

Modules

typed
A typed view of a procedure signature.

Structs

AdviceInputs
Inputs container to initialize advice provider for the execution of Miden VM programs.
AdviceMap
Defines a set of non-deterministic (advice) inputs which the VM can access by their keys.
AttributeSet
An AttributeSet provides storage and access to all of the attributes attached to a Miden Assembly item, e.g. procedure definition.
Package
A package is a assembled artifact containing:
PackageManifest
The manifest of a package, containing the set of package dependencies (libraries or packages) exported items (procedures, constants, types), and module surface information, if known.
ProcedureExport
A procedure exported by a package, along with its digest, signature, and attributes.
Program
An executable program for Miden VM.
QualifiedProcedureName
Represents a qualified procedure name, e.g. std::math::u64::add, parsed into it’s constituent Path and ProcedureName components.
Section
SectionId
A unique identifier for optional sections of the Miden package format

Enums

ExecutionError
OperationError
Lightweight error type for operations that can fail.
PackageExport
Represents a named item exported from a package.
TargetType
The type of a specific target provided by the current project

Constants

MIN_STACK_DEPTH
Represents:

Functions

error_code_from_msg
Derives an error code from an error message by hashing the message and returning the 0th element of the resulting Word.