pub struct AdviceInputs {
pub stack: Vec<BaseElement>,
pub map: AdviceMap,
pub store: MerkleStore,
}Expand description
Inputs container to initialize advice provider for the execution of Miden VM programs.
The program may request nondeterministic advice inputs from the prover. These inputs are secret inputs. This means that the prover does not need to share them with the verifier.
There are three types of advice inputs:
- Single advice stack which can contain any number of elements.
- Key-mapped element lists which can be pushed onto the advice stack.
- Merkle store, which is used to provide nondeterministic inputs for instructions that operates with Merkle trees.
Fields
stack: Vec<BaseElement>map: AdviceMapstore: MerkleStoreImplementations
Sourceimpl AdviceInputs
impl AdviceInputs
Sourcepub fn with_stack_values<I>(self, iter: I) -> Result<AdviceInputs, InputError>where
I: IntoIterator<Item = u64>,
pub fn with_stack_values<I>(self, iter: I) -> Result<AdviceInputs, InputError>where
I: IntoIterator<Item = u64>,
Attempts to extend the stack values with the given sequence of integers, returning an error
if any of the numbers fails while converting to an element [Felt].
Sourcepub fn with_stack<I>(self, iter: I) -> AdviceInputswhere
I: IntoIterator<Item = BaseElement>,
pub fn with_stack<I>(self, iter: I) -> AdviceInputswhere
I: IntoIterator<Item = BaseElement>,
Extends the stack with the given elements.
Sourcepub fn with_map<I>(self, iter: I) -> AdviceInputs
pub fn with_map<I>(self, iter: I) -> AdviceInputs
Extends the map of values with the given argument, replacing previously inserted items.
Sourcepub fn with_merkle_store(self, store: MerkleStore) -> AdviceInputs
pub fn with_merkle_store(self, store: MerkleStore) -> AdviceInputs
Replaces the MerkleStore with the provided argument.
Sourcepub fn extend(&mut self, other: AdviceInputs)
pub fn extend(&mut self, other: AdviceInputs)
Extends the contents of this instance with the contents of the other instance.