pub struct Package {
pub name: String,
pub version: Option<Version>,
pub description: Option<String>,
pub kind: PackageKind,
pub mast: MastArtifact,
pub manifest: PackageManifest,
pub sections: Vec<Section>,
}Expand description
Fields
name: StringName of the package
version: Option<Version>An optional semantic version for the package
description: Option<String>An optional description of the package
kind: PackageKindThe kind of project that produced this package.
mast: MastArtifactmanifest: PackageManifestThe package manifest, containing the set of exported procedures and their signatures, if known.
sections: Vec<Section>The set of custom sections included with the package, e.g. debug information, account metadata, etc.
Implementations
Sourceimpl Package
impl Package
Sourcepub fn into_mast_artifact(self) -> MastArtifact
pub fn into_mast_artifact(self) -> MastArtifact
Returns the MastArtifact of the package
Sourcepub fn is_program(&self) -> bool
pub fn is_program(&self) -> bool
Checks if the package’s MAST artifact is a Program
Sourcepub fn is_library(&self) -> bool
pub fn is_library(&self) -> bool
Checks if the package’s MAST artifact is a Library
Sourcepub fn unwrap_program(&self) -> Arc<Program>
pub fn unwrap_program(&self) -> Arc<Program>
Sourcepub fn unwrap_library(&self) -> Arc<Library>
pub fn unwrap_library(&self) -> Arc<Library>
Sourcepub fn make_executable(
&self,
entrypoint: &QualifiedProcedureName,
) -> Result<Package, Report>
pub fn make_executable( &self, entrypoint: &QualifiedProcedureName, ) -> Result<Package, Report>