pub struct PackageManifest { /* private fields */ }Expand description
The manifest of a package, containing the set of package dependencies (libraries or packages) and exported items (procedures, constants, types), if known.
Implementations
Sourceimpl PackageManifest
impl PackageManifest
pub fn new(exports: impl IntoIterator<Item = PackageExport>) -> PackageManifest
Sourcepub fn with_dependencies(
self,
dependencies: impl IntoIterator<Item = Dependency>,
) -> PackageManifest
pub fn with_dependencies( self, dependencies: impl IntoIterator<Item = Dependency>, ) -> PackageManifest
Extend this manifest with the provided dependencies
Sourcepub fn add_dependency(&mut self, dependency: Dependency)
pub fn add_dependency(&mut self, dependency: Dependency)
Add a dependency to the manifest
Sourcepub fn num_dependencies(&self) -> usize
pub fn num_dependencies(&self) -> usize
Get the number of dependencies of this package
Sourcepub fn dependencies(&self) -> impl Iterator<Item = &Dependency>
pub fn dependencies(&self) -> impl Iterator<Item = &Dependency>
Get an iterator over the dependencies of this package
Sourcepub fn num_exports(&self) -> usize
pub fn num_exports(&self) -> usize
Get the number of items exported from this package
Sourcepub fn exports(&self) -> impl Iterator<Item = &PackageExport>
pub fn exports(&self) -> impl Iterator<Item = &PackageExport>
Get an iterator over the exports in this package
Sourcepub fn get_export(&self, name: impl AsRef<Path>) -> Option<&PackageExport>
pub fn get_export(&self, name: impl AsRef<Path>) -> Option<&PackageExport>
Get information about an export by it’s qualified name
Sourcepub fn get_procedures_by_digest(
&self,
digest: &Word,
) -> impl Iterator<Item = &ProcedureExport>
pub fn get_procedures_by_digest( &self, digest: &Word, ) -> impl Iterator<Item = &ProcedureExport>
Get information about all exported procedures of this package with the given MAST root digest