pub struct ProcedureExport {
pub path: Arc<Path>,
pub digest: Word,
pub signature: Option<FunctionType>,
pub attributes: AttributeSet,
}Expand description
A procedure exported by a package, along with its digest, signature, and attributes.
Fields
path: Arc<Path>The fully-qualified path of the procedure exported by this package.
digest: WordThe digest of the procedure exported by this package.
signature: Option<FunctionType>The type signature of the exported procedure.
attributes: AttributeSetAttributes attached to the exported procedure.