Module component

Module component 

Structs

AccountComponent
An AccountComponent defines a Library of code and the initial value and types of the StorageSlots it accesses.
AccountComponentMetadata
Represents the full component metadata configuration.
AuthControlled
An AccountComponent providing configurable mint-policy management for network faucets.
AuthMultisig
An AccountComponent implementing a multisig authentication.
AuthMultisigConfig
Configuration for AuthMultisig component.
AuthMultisigPsm
An AccountComponent implementing a multisig authentication with a private state manager.
AuthMultisigPsmConfig
Configuration for AuthMultisigPsm component.
AuthSingleSig
An AccountComponent implementing the signature scheme for authentication of transactions.
AuthSingleSigAcl
An AccountComponent implementing a procedure-based Access Control List (ACL) using either the EcdsaK256Keccak or Falcon512 Poseidon2 signature scheme for authentication of transactions.
AuthSingleSigAclConfig
Configuration for AuthSingleSigAcl component.
BasicFungibleFaucet
An AccountComponent implementing a basic fungible faucet.
BasicWallet
An AccountComponent implementing a basic wallet.
FeltSchema
Supported element schema descriptors for a component’s storage entries.
InitStorageData
Represents the data required to initialize storage entries when instantiating an AccountComponent from component metadata (either provided directly or extracted from a package).
NetworkFungibleFaucet
An AccountComponent implementing a network fungible faucet.
NoAuth
An AccountComponent implementing a no-authentication scheme.
OwnerControlled
An AccountComponent providing configurable mint-policy management for network faucets.
PsmConfig
Public configuration for the private state manager signer.
PublicKeyCommitment
Commitment to a public key.
SchemaType
A newtype wrapper around a String, representing a schema type.
StorageSchema
Describes the storage schema of an account component in terms of its named storage slots.
StorageValueName
A simple wrapper type around a string key that identifies init-provided values.

Enums

AuthControlledInitConfig
Initial policy configuration for the AuthControlled component.
AuthScheme
Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
AuthSecretKey
Secret keys of the standard AuthSchemes available in the Miden protocol.
OwnerControlledInitConfig
Initial policy configuration for the OwnerControlled component.
PublicKey
Public keys of the standard authentication schemes available in the Miden protocol.
Signature
Represents a signature object ready for native verification.
StorageSlotSchema
Describes the schema for a storage slot. Can describe either a value slot, or a map slot.

Constants

MIDEN_PACKAGE_EXTENSION

Functions

basic_fungible_faucet_library
Returns the Basic Fungible Faucet Library.
basic_wallet_library
Returns the Basic Wallet Library.
multisig_library
Returns the Multisig Library.
network_fungible_faucet_library
Returns the Network Fungible Faucet Library.
no_auth_library
Returns the NoAuth Library.
singlesig_acl_library
Returns the Singlesig ACL Library.
singlesig_library
Returns the Singlesig Library.