Structs
- Account
Component - An
AccountComponentdefines aLibraryof code and the initial value and types of theStorageSlots it accesses. - Account
Component Metadata - Represents the full component metadata configuration.
- Auth
Controlled - An
AccountComponentproviding configurable mint-policy management for network faucets. - Auth
Multisig - An
AccountComponentimplementing a multisig authentication. - Auth
Multisig Config - Configuration for
AuthMultisigcomponent. - Auth
Multisig Psm - An
AccountComponentimplementing a multisig authentication with a private state manager. - Auth
Multisig PsmConfig - Configuration for
AuthMultisigPsmcomponent. - Auth
Single Sig - An
AccountComponentimplementing the signature scheme for authentication of transactions. - Auth
Single SigAcl - An
AccountComponentimplementing a procedure-based Access Control List (ACL) using either the EcdsaK256Keccak or Falcon512 Poseidon2 signature scheme for authentication of transactions. - Auth
Single SigAcl Config - Configuration for
AuthSingleSigAclcomponent. - Basic
Fungible Faucet - An
AccountComponentimplementing a basic fungible faucet. - Basic
Wallet - An
AccountComponentimplementing a basic wallet. - Felt
Schema - Supported element schema descriptors for a component’s storage entries.
- Init
Storage Data - Represents the data required to initialize storage entries when instantiating an AccountComponent from component metadata (either provided directly or extracted from a package).
- Network
Fungible Faucet - An
AccountComponentimplementing a network fungible faucet. - NoAuth
- An
AccountComponentimplementing a no-authentication scheme. - Owner
Controlled - An
AccountComponentproviding configurable mint-policy management for network faucets. - PsmConfig
- Public configuration for the private state manager signer.
- Public
KeyCommitment - Commitment to a public key.
- Schema
Type - A newtype wrapper around a
String, representing a schema type. - Storage
Schema - Describes the storage schema of an account component in terms of its named storage slots.
- Storage
Value Name - A simple wrapper type around a string key that identifies init-provided values.
Enums
- Auth
Controlled Init Config - Initial policy configuration for the
AuthControlledcomponent. - Auth
Scheme - Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
- Auth
Secret Key - Secret keys of the standard
AuthSchemes available in the Miden protocol. - Owner
Controlled Init Config - Initial policy configuration for the
OwnerControlledcomponent. - Public
Key - Public keys of the standard authentication schemes available in the Miden protocol.
- Signature
- Represents a signature object ready for native verification.
- Storage
Slot Schema - Describes the schema for a storage slot. Can describe either a value slot, or a map slot.
Constants
Functions
- basic_
fungible_ faucet_ library - Returns the Basic Fungible Faucet Library.
- basic_
wallet_ library - Returns the Basic Wallet Library.
- multisig_
library - Returns the Multisig Library.
- network_
fungible_ faucet_ library - Returns the Network Fungible Faucet Library.
- no_
auth_ library - Returns the NoAuth Library.
- singlesig_
acl_ library - Returns the Singlesig ACL Library.
- singlesig_
library - Returns the Singlesig Library.