Module component

Module component 

Structs

AccountComponent
An AccountComponent defines a Library of code and the initial value and types of the StorageSlots it accesses.
AccountComponentMetadata
Represents the full component metadata configuration.
AuthEcdsaK256Keccak
An AccountComponent implementing the ECDSA K256 Keccak signature scheme for authentication of transactions.
AuthEcdsaK256KeccakAcl
An AccountComponent implementing a procedure-based Access Control List (ACL) using the EcdsaK256Keccak signature scheme for authentication of transactions.
AuthEcdsaK256KeccakAclConfig
Configuration for AuthEcdsaK256KeccakAcl component.
AuthEcdsaK256KeccakMultisig
An AccountComponent implementing a multisig based on ECDSA signatures.
AuthEcdsaK256KeccakMultisigConfig
Configuration for AuthEcdsaK256KeccakMultisig component.
AuthFalcon512Rpo
An AccountComponent implementing the Falcon512Rpo signature scheme for authentication of transactions.
AuthFalcon512RpoAcl
An AccountComponent implementing a procedure-based Access Control List (ACL) using the Falcon512Rpo signature scheme for authentication of transactions.
AuthFalcon512RpoAclConfig
Configuration for AuthFalcon512RpoAcl component.
AuthFalcon512RpoMultisig
An AccountComponent implementing a multisig based on Falcon512Rpo signatures.
AuthFalcon512RpoMultisigConfig
Configuration for AuthFalcon512RpoMultisig component.
BasicFungibleFaucet
An AccountComponent implementing a basic fungible faucet.
BasicWallet
An AccountComponent implementing a basic wallet.
InitStorageData
Represents the data required to initialize storage entries when instantiating an AccountComponent from component metadata (either provided directly or extracted from a package).
NetworkFungibleFaucet
An AccountComponent implementing a network fungible faucet.
NoAuth
An AccountComponent implementing a no-authentication scheme.
PublicKeyCommitment
Commitment to a public key.
StorageValueName
A simple wrapper type around a string key that identifies init-provided values.

Enums

AuthScheme
Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
AuthSecretKey
Secret keys of the standard AuthSchemes available in the Miden protocol.
PublicKey
Public keys of the standard authentication schemes available in the Miden protocol.
Signature
Represents a signature object ready for native verification.
StorageSlotSchema
Describes the schema for a storage slot. Can describe either a value slot, or a map slot.

Constants

MIDEN_PACKAGE_EXTENSION

Traits

FungibleFaucetExt
Extension trait for fungible faucet accounts. Provides methods to access the fungible faucet account’s reserved storage slot.

Functions

basic_fungible_faucet_library
Returns the Basic Fungible Faucet Library.
basic_wallet_library
Returns the Basic Wallet Library.
ecdsa_k256_keccak_library
Returns the ECDSA K256 Keccak Library.
falcon_512_rpo_acl_library
Returns the Falcon 512 RPO ACL Library.
falcon_512_rpo_library
Returns the Falcon 512 RPO Library.
falcon_512_rpo_multisig_library
Returns the Falcon 512 RPO Multisig Library.
network_fungible_faucet_library
Returns the Network Fungible Faucet Library.
no_auth_library
Returns the NoAuth Library.