Structs
- Account
Component - An
AccountComponentdefines aLibraryof code and the initial value and types of theStorageSlots it accesses. - Account
Component Metadata - Represents the full component metadata configuration.
- Auth
Ecdsa K256 Keccak - An
AccountComponentimplementing the ECDSA K256 Keccak signature scheme for authentication of transactions. - Auth
Ecdsa K256 Keccak Acl - An
AccountComponentimplementing a procedure-based Access Control List (ACL) using the EcdsaK256Keccak signature scheme for authentication of transactions. - Auth
Ecdsa K256 Keccak AclConfig - Configuration for
AuthEcdsaK256KeccakAclcomponent. - Auth
Ecdsa K256 Keccak Multisig - An
AccountComponentimplementing a multisig based on ECDSA signatures. - Auth
Ecdsa K256 Keccak Multisig Config - Configuration for
AuthEcdsaK256KeccakMultisigcomponent. - Auth
Falcon512 Rpo - An
AccountComponentimplementing the Falcon512Rpo signature scheme for authentication of transactions. - Auth
Falcon512 RpoAcl - An
AccountComponentimplementing a procedure-based Access Control List (ACL) using the Falcon512Rpo signature scheme for authentication of transactions. - Auth
Falcon512 RpoAcl Config - Configuration for
AuthFalcon512RpoAclcomponent. - Auth
Falcon512 RpoMultisig - An
AccountComponentimplementing a multisig based on Falcon512Rpo signatures. - Auth
Falcon512 RpoMultisig Config - Configuration for
AuthFalcon512RpoMultisigcomponent. - Basic
Fungible Faucet - An
AccountComponentimplementing a basic fungible faucet. - Basic
Wallet - An
AccountComponentimplementing a basic wallet. - Init
Storage Data - Represents the data required to initialize storage entries when instantiating an AccountComponent from component metadata (either provided directly or extracted from a package).
- Network
Fungible Faucet - An
AccountComponentimplementing a network fungible faucet. - NoAuth
- An
AccountComponentimplementing a no-authentication scheme. - Public
KeyCommitment - Commitment to a public key.
- Storage
Value Name - A simple wrapper type around a string key that identifies init-provided values.
Enums
- Auth
Scheme - Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
- Auth
Secret Key - Secret keys of the standard
AuthSchemes available in the Miden protocol. - Public
Key - Public keys of the standard authentication schemes available in the Miden protocol.
- Signature
- Represents a signature object ready for native verification.
- Storage
Slot Schema - Describes the schema for a storage slot. Can describe either a value slot, or a map slot.
Constants
Traits
- Fungible
Faucet Ext - Extension trait for fungible faucet accounts. Provides methods to access the fungible faucet account’s reserved storage slot.
Functions
- basic_
fungible_ faucet_ library - Returns the Basic Fungible Faucet Library.
- basic_
wallet_ library - Returns the Basic Wallet Library.
- ecdsa_
k256_ keccak_ library - Returns the ECDSA K256 Keccak Library.
- falcon_
512_ rpo_ acl_ library - Returns the Falcon 512 RPO ACL Library.
- falcon_
512_ rpo_ library - Returns the Falcon 512 RPO Library.
- falcon_
512_ rpo_ multisig_ library - Returns the Falcon 512 RPO Multisig Library.
- network_
fungible_ faucet_ library - Returns the Network Fungible Faucet Library.
- no_
auth_ library - Returns the NoAuth Library.