pub struct BasicFungibleFaucet { /* private fields */ }Expand description
An AccountComponent implementing a basic fungible faucet.
It reexports the procedures from miden::standards::faucets::basic_fungible. When linking
against this component, the miden library (i.e.
ProtocolLib) must be available to the assembler which is the
case when using CodeBuilder. The procedures of this component are:
distribute, which mints an assets and create a note for the provided recipient.burn, which burns the provided asset.
The distribute procedure can be called from a transaction script and requires authentication
via the authentication component. The burn procedure can only be called from a note script
and requires the calling note to contain the asset to be burned.
This component must be combined with an authentication component.
This component supports accounts of type AccountType::FungibleFaucet.
Storage Layout
Self::metadata_slot: Fungible faucet metadata
Implementations
Sourceimpl BasicFungibleFaucet
impl BasicFungibleFaucet
Sourcepub const MAX_DECIMALS: u8 = 12
pub const MAX_DECIMALS: u8 = 12
The maximum number of decimals supported by the component.
Sourcepub fn new(
symbol: TokenSymbol,
decimals: u8,
max_supply: BaseElement,
) -> Result<BasicFungibleFaucet, FungibleFaucetError>
pub fn new( symbol: TokenSymbol, decimals: u8, max_supply: BaseElement, ) -> Result<BasicFungibleFaucet, FungibleFaucetError>
Creates a new BasicFungibleFaucet component from the given pieces of metadata.
Errors:
Returns an error if:
- the decimals parameter exceeds maximum value of
Self::MAX_DECIMALS. - the max supply parameter exceeds maximum possible amount for a fungible asset
(
FungibleAsset::MAX_AMOUNT)
Sourcepub fn metadata_slot() -> &'static StorageSlotName
pub fn metadata_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the BasicFungibleFaucet’s metadata is stored.
Sourcepub fn symbol(&self) -> TokenSymbol
pub fn symbol(&self) -> TokenSymbol
Returns the symbol of the faucet.
Sourcepub fn max_supply(&self) -> BaseElement
pub fn max_supply(&self) -> BaseElement
Returns the max supply of the faucet.
Sourcepub fn distribute_digest() -> Word
pub fn distribute_digest() -> Word
Returns the digest of the distribute account procedure.
Sourcepub fn burn_digest() -> Word
pub fn burn_digest() -> Word
Returns the digest of the burn account procedure.