Structs
- Auth
Guarded Multisig - An
AccountComponentimplementing multisig authentication integrated with a state guardian. - Auth
Guarded Multisig Config - Configuration for
AuthGuardedMultisigcomponent. - Auth
Multisig - An
AccountComponentimplementing a multisig authentication. - Auth
Multisig Config - Configuration for
AuthMultisigcomponent. - Auth
Multisig Smart - An
AccountComponentimplementing a multisig auth component with smart-policy slots. - Auth
Multisig Smart Config - Configuration for
AuthMultisigSmartcomponent. - Auth
Network Account - An
AccountComponentimplementing an authentication scheme that restricts what notes an account can consume to a fixed allowlist of note script roots, and what transaction scripts may run against the account to a fixed allowlist of tx script roots. - Auth
Single Sig - An
AccountComponentimplementing the signature scheme for authentication of transactions. - Auth
Single SigAcl - An
AccountComponentimplementing a procedure-based Access Control List (ACL) using either the EcdsaK256Keccak or Falcon512 Poseidon2 signature scheme for authentication of transactions. - Auth
Single SigAcl Config - Configuration for
AuthSingleSigAclcomponent. - Guardian
Config - Public configuration for the guardian signer.
- Network
Account - A wrapper around an
Accountthat is guaranteed to be a network account. - Network
Account Note Allowlist - A standardized storage slot holding the allowlist of input-note script roots that a network account is willing to consume.
- Network
Account TxScript Allowlist - A standardized storage slot holding the allowlist of transaction script roots that a network account is willing to execute.
- NoAuth
- An
AccountComponentimplementing a no-authentication scheme.
Enums
- Network
Account Note Allowlist Error - Errors that can occur when constructing a
NetworkAccountNoteAllowlistor reconstructing one from storage. - Network
Account TxScript Allowlist Error - Errors that can occur when reconstructing a
NetworkAccountTxScriptAllowlistfrom storage.