Fee policy configuration and fee policy account components.
Structs
- Basic
Constant FeePolicy - The
basic_constant_feefee policy account component. - Constant
FeeManager - Account component that exposes the
set_note_feeadmin procedure gated by the account-widecrate::account::access::Authoritycomponent viaexec.authority::assert_authorized. - FeePolicy
- Descriptor for a fee policy registered with a
super::FeePolicyManager. - FeePolicy
Manager - The fee policy configuration of a network account: the policy defining the fee estimation for notes, which policies it may be switched to, and the asset that fees are charged in.
- FeePolicy
Manager Builder - Use builder syntax to set the inputs and finish with
build().
Enums
- FeePolicy
Error - Errors returned by
FeePolicy::custom.