Re-export the entire miden_client crate so external projects can use a single dependency.
Provides AggLayer bridge components, note constructors, and helper types.
Modules
- agglayer_
note - b2agg_
note - Bridge Out note creation utilities.
- bridge
- claim_
note - config_
note - CONFIG_AGG_BRIDGE note creation utilities.
- costs
- Benchmarked consumption costs of the agglayer notes.
- deregister_
note - DEREGISTER_AGG_FAUCET note creation utilities.
- errors
- eth_
types - faucet
- remove_
ger_ note - REMOVE_GER note creation utilities.
- update_
ger_ note - UPDATE_GER note creation utilities.
- utils
Structs
- AggLayer
Bridge - An
AccountComponentimplementing the AggLayer Bridge. - AggLayer
Faucet - An
AccountComponentimplementing the AggLayer Faucet. - B2Agg
Note - B2AGG (Bridge to AggLayer) note.
- Bridge
Roles - The accounts that initially hold each of the bridge’s privileged RBAC roles.
- Claim
Note - CLAIM (Bridge from AggLayer) note.
- Claim
Note Storage - Data for creating a CLAIM note.
- Config
AggBridge Note - CONFIG_AGG_BRIDGE note.
- Conversion
Metadata - The conversion metadata registered on the bridge for a single faucet.
- Deregister
AggFaucet Note - DEREGISTER_AGG_FAUCET note.
- EthAddress
- Represents a plain Ethereum address (20 bytes).
- EthAmount
- Represents an Ethereum uint256 amount as 8 u32 values.
- EthEmbedded
Account Id - Represents a Miden
AccountIdthat can be encoded in the 20-byte Ethereum address format. - Keccak256
Output - Keccak256 output representation (32-byte hash)
- Leaf
Data - Leaf data for CLAIM note creation. Contains network, address, amount, and metadata using typed representations.
- Metadata
Hash - Represents a Keccak256 metadata hash as 32 bytes.
- Proof
Data - Proof data for CLAIM note creation. Contains SMT proofs and root hashes using typed representations.
- Remove
GerNote - REMOVE_GER note.
- Update
GerNote - UPDATE_GER note.
Enums
- Address
Conversion Error - Error type for Ethereum address conversions.
- Agglayer
Bridge Error - AggLayer Bridge related errors.
- Agglayer
Faucet Error - AggLayer Faucet related errors.
- Agglayer
Note - The enum holding the types of notes provided by
miden-agglayer, mirroringStandardNote. - EthAmount
Error - Error type for Ethereum amount conversions.
- Global
Index Error - Error type for GlobalIndex validation.
Functions
- agglayer_
package - Returns the AggLayer package containing all agglayer modules, including the note scripts.
Type Aliases
- CgiChain
Hash - Claimed Global Index (CGI) chain hash representation (32-byte Keccak256 hash)
- Exit
Root - Exit root representation (32-byte Keccak256 hash)
- Global
Index - Represents an AggLayer global index as a 256-bit value (32 bytes).
- Leaf
Value - Leaf value representation (32-byte Keccak256 hash)
- Removed
GerHash Chain - Removed-GER hash chain representation (32-byte Keccak256 hash)
- SmtNode
- SMT node representation (32-byte Keccak256 hash)