pub struct Library { /* private fields */ }Expand description
Represents a library where all modules were compiled into a MastForest.
A library exports a set of one or more procedures. Currently, all exported procedures belong to the same top-level namespace.
Implementations
Sourceimpl Library
Constructors
impl Library
Constructors
Sourcepub fn new(
mast_forest: Arc<MastForest>,
exports: BTreeMap<Arc<Path>, LibraryExport>,
) -> Result<Library, LibraryError>
pub fn new( mast_forest: Arc<MastForest>, exports: BTreeMap<Arc<Path>, LibraryExport>, ) -> Result<Library, LibraryError>
Sourcepub fn with_advice_map(self, advice_map: AdviceMap) -> Library
pub fn with_advice_map(self, advice_map: AdviceMap) -> Library
Produces a new library with the existing MastForest and where all key/values in the
provided advice map are added to the internal advice map.
Sourceimpl Library
Public accessors
impl Library
Public accessors
Sourcepub fn exports(&self) -> impl Iterator<Item = &LibraryExport>
pub fn exports(&self) -> impl Iterator<Item = &LibraryExport>
Returns the fully qualified name and metadata of all procedures exported by the library.
Sourcepub fn num_exports(&self) -> usize
pub fn num_exports(&self) -> usize
Returns the number of exports in this library.
Sourcepub fn get_export_node_id(&self, path: impl AsRef<Path>) -> MastNodeId
pub fn get_export_node_id(&self, path: impl AsRef<Path>) -> MastNodeId
Returns a MAST node ID associated with the specified exported procedure.
Panics
Panics if the specified procedure is not exported from this library.
Sourcepub fn is_reexport(&self, path: impl AsRef<Path>) -> bool
pub fn is_reexport(&self, path: impl AsRef<Path>) -> bool
Returns true if the specified exported procedure is re-exported from a dependency.
Sourcepub fn mast_forest(&self) -> &Arc<MastForest>
pub fn mast_forest(&self) -> &Arc<MastForest>
Returns a reference to the inner MastForest.
Sourceimpl Library
Conversions
impl Library
Conversions
Sourcepub fn module_infos(&self) -> impl Iterator<Item = ModuleInfo>
pub fn module_infos(&self) -> impl Iterator<Item = ModuleInfo>
Returns an iterator over the module infos of the library.
Sourceimpl Library
impl Library
Sourcepub const LIBRARY_EXTENSION: &'static str = "masl"
pub const LIBRARY_EXTENSION: &'static str = "masl"
File extension for the Assembly Library.
Sourcepub fn write_to_file(&self, path: impl AsRef<Path>) -> Result<(), Error>
pub fn write_to_file(&self, path: impl AsRef<Path>) -> Result<(), Error>
Write the library to a target file
NOTE: It is up to the caller to use the correct file extension, but there is no
specific requirement that the extension be set, or the same as
Self::LIBRARY_EXTENSION.
pub fn deserialize_from_file( path: impl AsRef<Path>, ) -> Result<Library, DeserializationError>