Module asset

Module asset 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides types and utilities for working with assets within the Miden network.

Structs

AccountStorageDelta
The AccountStorageDelta stores the differences between two states of account storage.
AccountStorageHeader
The header of an AccountStorage, storing only the slot name, slot type and value of each storage slot.
AccountVaultDelta
AccountVaultDelta stores the difference between the initial and final account vault states.
AssetAmount
A validated fungible asset amount.
AssetCallbacks
Configures the callback procedure roots for asset callbacks.
AssetId
The AssetId in an AssetVaultKey distinguishes different assets issued by the same faucet.
AssetVault
A container for an unlimited number of assets.
AssetVaultKey
The unique identifier of an Asset in the AssetVault.
AssetWitness
A witness of an asset in an AssetVault.
FungibleAsset
A fungible asset.
FungibleAssetDelta
A binary tree map of fungible asset balance changes in the account vault.
NonFungibleAsset
A commitment to a non-fungible asset.
NonFungibleAssetDelta
A binary tree map of non-fungible asset changes (addition and removal) in the account vault.
NonFungibleAssetDetails
Details about a non-fungible asset.
PartialVault
A partial representation of an AssetVault, containing only proofs for a subset of assets.
StorageMapDelta
StorageMapDelta stores the differences between two states of account storage maps.
StorageMapWitness
A witness of an asset in a StorageMap.
StorageSlotHeader
The header of a StorageSlot, storing only the slot name (or ID), slot type and value of the slot.
TokenSymbol
Represents a token symbol (e.g. “POL”, “ETH”).

Enums

Asset
A fungible or a non-fungible asset.
AssetCallbackFlag
The flag in an AssetVaultKey that indicates whether AssetCallbacks are enabled for this asset.
AssetComposition
Indicates how an asset is composed (i.e. how its merge/split semantics are defined).
NonFungibleDeltaAction
StorageSlotContent
Represents the contents of a StorageSlot.
StorageSlotDelta
The delta of a single storage slot.