Module asset

Module asset 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides types and utilities for working with assets within the Miden network.

Structs

AccountStorageDelta
The AccountStorageDelta stores the differences between two states of account storage.
AccountStorageHeader
The header of an AccountStorage, storing only the slot name, slot type and value of each storage slot.
AccountVaultDelta
AccountVaultDelta stores the difference between the initial and final account vault states.
AssetVault
A container for an unlimited number of assets.
AssetVaultKey
The unique identifier of an Asset in the AssetVault.
AssetWitness
A witness of an asset in an AssetVault.
FungibleAsset
A fungible asset.
FungibleAssetDelta
A binary tree map of fungible asset balance changes in the account vault.
NonFungibleAsset
A commitment to a non-fungible asset.
NonFungibleAssetDelta
A binary tree map of non-fungible asset changes (addition and removal) in the account vault.
NonFungibleAssetDetails
Details about a non-fungible asset.
PartialVault
A partial representation of an AssetVault, containing only proofs for a subset of assets.
StorageMapWitness
A witness of an asset in a StorageMap.
StorageSlotHeader
The header of a StorageSlot, storing only the slot name (or ID), slot type and value of the slot.
TokenSymbol
Represents a token symbol (e.g. “POL”, “ETH”).

Enums

Asset
A fungible or a non-fungible asset.
NonFungibleDeltaAction
StorageSlotContent
Represents the contents of a StorageSlot.