Re-export the entire miden_client crate so external projects can use a single dependency.
Provides types and utilities for working with assets within the Miden network.
Structs
- Account
Storage Delta - The
AccountStorageDeltastores the differences between two states of account storage. - Account
Storage Header - The header of an
AccountStorage, storing only the slot name, slot type and value of each storage slot. - Account
Vault Delta - AccountVaultDelta stores the difference between the initial and final account vault states.
- Asset
Vault - A container for an unlimited number of assets.
- Asset
Vault Key - The unique identifier of an
Assetin theAssetVault. - Asset
Witness - A witness of an asset in an
AssetVault. - Fungible
Asset - A fungible asset.
- Fungible
Asset Delta - A binary tree map of fungible asset balance changes in the account vault.
- NonFungible
Asset - A commitment to a non-fungible asset.
- NonFungible
Asset Delta - A binary tree map of non-fungible asset changes (addition and removal) in the account vault.
- NonFungible
Asset Details - Details about a non-fungible asset.
- Partial
Vault - A partial representation of an
AssetVault, containing only proofs for a subset of assets. - Storage
MapWitness - A witness of an asset in a
StorageMap. - Storage
Slot Header - The header of a
StorageSlot, storing only the slot name (or ID), slot type and value of the slot. - Token
Symbol - Represents a token symbol (e.g. “POL”, “ETH”).
Enums
- Asset
- A fungible or a non-fungible asset.
- NonFungible
Delta Action - Storage
Slot Content - Represents the contents of a
StorageSlot.