Module asset

Module asset 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides types and utilities for working with assets within the Miden network.

Structs

AccountStorageDelta
The AccountStorageDelta stores the differences between two states of account storage.
AccountVaultDelta
AccountVaultDelta stores the difference between the initial and final account vault states.
AssetVault
A container for an unlimited number of assets.
AssetWitness
A witness of an asset in an AssetVault.
FungibleAsset
A fungible asset.
FungibleAssetDelta
A binary tree map of fungible asset balance changes in the account vault.
NonFungibleAsset
A commitment to a non-fungible asset.
NonFungibleAssetDelta
A binary tree map of non-fungible asset changes (addition and removal) in the account vault.
NonFungibleAssetDetails
Details about a non-fungible asset.
TokenSymbol
Represents a string token symbol (e.g. “POL”, “ETH”) as a single Felt value.

Enums

Asset
A fungible or a non-fungible asset.
NonFungibleDeltaAction