pub struct AccountVaultDelta { /* private fields */ }Expand description
AccountVaultDelta stores the difference between the initial and final account vault states.
The difference is represented as follows:
- fungible: a binary tree map of fungible asset balance changes in the account vault.
- non_fungible: a binary tree map of non-fungible assets that were added to or removed from the account vault.
Implementations
Sourceimpl AccountVaultDelta
impl AccountVaultDelta
Sourcepub const fn new(
fungible: FungibleAssetDelta,
non_fungible: NonFungibleAssetDelta,
) -> AccountVaultDelta
pub const fn new( fungible: FungibleAssetDelta, non_fungible: NonFungibleAssetDelta, ) -> AccountVaultDelta
Validates and creates an AccountVaultDelta with the given fungible and non-fungible asset deltas.
Errors
Returns an error if the delta does not pass the validation.
Sourcepub fn fungible(&self) -> &FungibleAssetDelta
pub fn fungible(&self) -> &FungibleAssetDelta
Returns a reference to the fungible asset delta.
Sourcepub fn non_fungible(&self) -> &NonFungibleAssetDelta
pub fn non_fungible(&self) -> &NonFungibleAssetDelta
Returns a reference to the non-fungible asset delta.
Sourcepub fn add_asset(&mut self, asset: Asset) -> Result<(), AccountDeltaError>
pub fn add_asset(&mut self, asset: Asset) -> Result<(), AccountDeltaError>
Tracks asset addition.
Sourcepub fn remove_asset(&mut self, asset: Asset) -> Result<(), AccountDeltaError>
pub fn remove_asset(&mut self, asset: Asset) -> Result<(), AccountDeltaError>
Tracks asset removal.
Sourcepub fn merge(
&mut self,
other: AccountVaultDelta,
) -> Result<(), AccountDeltaError>
pub fn merge( &mut self, other: AccountVaultDelta, ) -> Result<(), AccountDeltaError>
Merges another delta into this one, overwriting any existing values.
The result is validated as part of the merge.
Errors
Returns an error if the resulted delta does not pass the validation.