pub struct FungibleAsset { /* private fields */ }Expand description
A fungible asset.
A fungible asset consists of a faucet ID of the faucet which issued the asset as well as the asset amount. Asset amount is guaranteed to be 2^63 - 1 or smaller.
The fungible asset can have callbacks to the faucet enabled or disabled, depending on
AssetCallbackFlag. See AssetCallbacks for more details.
Implementations
Sourceimpl FungibleAsset
impl FungibleAsset
Sourcepub const MAX_AMOUNT: u64
pub const MAX_AMOUNT: u64
Specifies the maximum amount a fungible asset can represent.
This number was chosen so that it can be represented as a positive and negative number in a
field element. See account_delta.masm for more details on how this number was chosen.
Sourcepub const SERIALIZED_SIZE: usize
pub const SERIALIZED_SIZE: usize
The serialized size of a FungibleAsset in bytes.
An account ID (15 bytes) plus an amount (u64) plus a callbacks flag (u8).
Sourcepub fn new(
faucet_id: AccountId,
amount: u64,
) -> Result<FungibleAsset, AssetError>
pub fn new( faucet_id: AccountId, amount: u64, ) -> Result<FungibleAsset, AssetError>
Returns a fungible asset instantiated with the provided faucet ID and amount.
Errors
Returns an error if:
- The faucet ID is not a valid fungible faucet ID.
- The provided amount is greater than
FungibleAsset::MAX_AMOUNT.
Sourcepub fn from_key_value(
key: AssetVaultKey,
value: Word,
) -> Result<FungibleAsset, AssetError>
pub fn from_key_value( key: AssetVaultKey, value: Word, ) -> Result<FungibleAsset, AssetError>
Creates a fungible asset from the provided key and value.
Errors
Returns an error if:
- The provided key does not contain a valid faucet ID.
- The provided key’s asset ID limbs are not zero.
- The faucet ID is not a fungible faucet ID.
- The provided value’s amount is greater than
FungibleAsset::MAX_AMOUNTor its three most significant elements are not zero.
Sourcepub fn from_key_value_words(
key: Word,
value: Word,
) -> Result<FungibleAsset, AssetError>
pub fn from_key_value_words( key: Word, value: Word, ) -> Result<FungibleAsset, AssetError>
Creates a fungible asset from the provided key and value.
Prefer Self::from_key_value for more type safety.
Errors
Returns an error if:
- The provided key does not contain a valid faucet ID.
Self::from_key_valuefails.
Sourcepub fn with_callbacks(self, callbacks: AssetCallbackFlag) -> FungibleAsset
pub fn with_callbacks(self, callbacks: AssetCallbackFlag) -> FungibleAsset
Returns a copy of this asset with the given AssetCallbackFlag.
Sourcepub fn is_same(&self, other: &FungibleAsset) -> bool
pub fn is_same(&self, other: &FungibleAsset) -> bool
Returns true if this and the other asset were issued from the same faucet.
Sourcepub fn callbacks(&self) -> AssetCallbackFlag
pub fn callbacks(&self) -> AssetCallbackFlag
Returns the AssetCallbackFlag of this asset.
Sourcepub fn vault_key(&self) -> AssetVaultKey
pub fn vault_key(&self) -> AssetVaultKey
Returns the key which is used to store this asset in the account vault.
Sourcepub fn to_key_word(&self) -> Word
pub fn to_key_word(&self) -> Word
Returns the asset’s key encoded to a Word.
Sourcepub fn to_value_word(&self) -> Word
pub fn to_value_word(&self) -> Word
Returns the asset’s value encoded to a Word.
Sourcepub fn add(self, other: FungibleAsset) -> Result<FungibleAsset, AssetError>
pub fn add(self, other: FungibleAsset) -> Result<FungibleAsset, AssetError>
Adds two fungible assets together and returns the result.
Errors
Returns an error if:
- The assets do not have the same vault key (i.e. different faucet or callback flags).
- The total value of assets is greater than or equal to 2^63.
Sourcepub fn sub(self, other: FungibleAsset) -> Result<FungibleAsset, AssetError>
pub fn sub(self, other: FungibleAsset) -> Result<FungibleAsset, AssetError>
Subtracts a fungible asset from another and returns the result.
Errors
Returns an error if:
- The assets do not have the same vault key (i.e. different faucet or callback flags).
- The final amount would be negative.