pub struct NonFungibleAsset(/* private fields */);Expand description
A commitment to a non-fungible asset.
The commitment is constructed as follows:
- Hash the asset data producing
[hash0, hash1, hash2, hash3]. - Replace the value of
hash3with the prefix of the faucet id (faucet_id_prefix) producing[hash0, hash1, hash2, faucet_id_prefix]. - This layout ensures that fungible and non-fungible assets are distinguishable by interpreting
the 3rd element of an asset as an
AccountIdPrefixand checking its type.
NonFungibleAsset itself does not contain the actual asset data. The container for this data
is NonFungibleAssetDetails.
Implementations
Sourceimpl NonFungibleAsset
impl NonFungibleAsset
Sourcepub const SERIALIZED_SIZE: usize
pub const SERIALIZED_SIZE: usize
The serialized size of a NonFungibleAsset in bytes.
Currently represented as a word.
Sourcepub fn new(
details: &NonFungibleAssetDetails,
) -> Result<NonFungibleAsset, AssetError>
pub fn new( details: &NonFungibleAssetDetails, ) -> Result<NonFungibleAsset, AssetError>
Returns a non-fungible asset created from the specified asset details.
Errors
Returns an error if the provided faucet ID is not for a non-fungible asset faucet.
Sourcepub fn from_parts(
faucet_id: AccountIdPrefix,
data_hash: Word,
) -> Result<NonFungibleAsset, AssetError>
pub fn from_parts( faucet_id: AccountIdPrefix, data_hash: Word, ) -> Result<NonFungibleAsset, AssetError>
Return a non-fungible asset created from the specified faucet and using the provided hash of the asset’s data.
Hash of the asset’s data is expected to be computed from the binary representation of the asset’s data.
Errors
Returns an error if the provided faucet ID is not for a non-fungible asset faucet.
Sourcepub unsafe fn new_unchecked(value: Word) -> NonFungibleAsset
pub unsafe fn new_unchecked(value: Word) -> NonFungibleAsset
Creates a new NonFungibleAsset without checking its validity.
Safety
This function requires that the provided value is a valid word encoding of a NonFungibleAsset.
Sourcepub fn vault_key(&self) -> AssetVaultKey
pub fn vault_key(&self) -> AssetVaultKey
Returns the vault key of the NonFungibleAsset.
This is the same as the asset with the following modifications, in this order:
- Swaps the faucet ID at index 0 and
hash0at index 3. - Sets the fungible bit for
hash0to0.
Rationale
This means hash0 will be used as the leaf index in the asset SMT which ensures that a
non-fungible faucet’s assets generally end up in different leaves as the key is not based on
the faucet ID.
It also ensures that there is never any collision in the leaf index between a non-fungible
asset and a fungible asset, as the former’s vault key always has the fungible bit set to 0
and the latter’s vault key always has the bit set to 1.
Sourcepub fn faucet_id_prefix(&self) -> AccountIdPrefix
pub fn faucet_id_prefix(&self) -> AccountIdPrefix
Return ID prefix of the faucet which issued this asset.