pub struct TokenSymbol(/* private fields */);Expand description
Represents a string token symbol (e.g. “POL”, “ETH”) as a single Felt value.
Token Symbols can consists of up to 6 capital Latin characters, e.g. “C”, “ETH”, “MIDENC”.
Implementations
Sourceimpl TokenSymbol
impl TokenSymbol
Sourcepub const MAX_SYMBOL_LENGTH: usize = 6
pub const MAX_SYMBOL_LENGTH: usize = 6
Maximum allowed length of the token string.
Sourcepub const ALPHABET_LENGTH: u64 = 26
pub const ALPHABET_LENGTH: u64 = 26
The length of the set of characters that can be used in a token’s name.
Sourcepub const MAX_ENCODED_VALUE: u64 = 8031810156
pub const MAX_ENCODED_VALUE: u64 = 8031810156
The maximum integer value of an encoded TokenSymbol.
This value encodes the “ZZZZZZ” token symbol.
Sourcepub const fn from_static_str(symbol: &'static str) -> TokenSymbol
pub const fn from_static_str(symbol: &'static str) -> TokenSymbol
Constructs a new TokenSymbol from a static string.
This function is const and can be used to define token symbols as constants, e.g.:
const TOKEN: TokenSymbol = TokenSymbol::from_static_str("ETH");This is convenient because using a string that is not a valid token symbol fails to compile.
Panics
Panics if:
- The length of the provided string is less than 1 or greater than 6.
- The provided token string contains characters that are not uppercase ASCII.
Sourcepub fn new(symbol: &str) -> Result<TokenSymbol, TokenSymbolError>
pub fn new(symbol: &str) -> Result<TokenSymbol, TokenSymbolError>
Creates a new TokenSymbol instance from the provided token name string.
Errors
Returns an error if:
- The length of the provided string is less than 1 or greater than 6.
- The provided token string contains characters that are not uppercase ASCII.
Sourcepub fn to_string(&self) -> Result<String, TokenSymbolError>
pub fn to_string(&self) -> Result<String, TokenSymbolError>
Returns the token name string from the encoded TokenSymbol value.
Errors
Returns an error if:
- The encoded value exceeds the maximum value of
Self::MAX_ENCODED_VALUE. - The encoded token string length is less than 1 or greater than 6.
- The encoded token string length is less than the actual string length.