Module auth

Module auth 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides authentication-related types and functionalities for the Miden network.

Structs

Approver
A signer that can approve transactions, identified by its public key commitment and the signature scheme used to verify its signatures.
ApproverSet
A set of Approvers together with the threshold of signatures required to approve a transaction by default.
AuthGuardedMultisig
An AccountComponent implementing multisig authentication integrated with a state guardian.
AuthGuardedMultisigConfig
Configuration for AuthGuardedMultisig component.
AuthMultisig
An AccountComponent implementing a multisig authentication.
AuthMultisigConfig
Configuration for AuthMultisig component.
AuthMultisigSmart
An AccountComponent implementing a multisig auth component with smart-policy slots.
AuthMultisigSmartConfig
Configuration for AuthMultisigSmart component.
AuthSingleSig
An AccountComponent implementing the signature scheme for authentication of transactions.
BasicAuthenticator
Represents a signer for AuthSecretKey keys.
GuardianConfig
Public configuration for the guardian signer.
NoAuth
An AccountComponent implementing a no-authentication scheme.
PublicKeyCommitment
Commitment to a public key.

Enums

AuthScheme
Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
AuthSchemeId
Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
AuthSecretKey
Secret keys of the standard AuthSchemes available in the Miden protocol.
PublicKey
Public keys of the standard authentication schemes available in the Miden protocol.
Signature
Represents a signature object ready for native verification.
SigningInputs
Data types on which a signature can be requested.

Constants

ECDSA_K256_KECCAK_SCHEME_ID
RPO_FALCON_SCHEME_ID

Traits

TransactionAuthenticator
Defines an authenticator for transactions.