Module auth

Module auth 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides authentication-related types and functionalities for the Miden network.

Structs

AuthMultisig
An AccountComponent implementing a multisig based on ECDSA signatures.
AuthMultisigConfig
Configuration for AuthMultisig component.
AuthSingleSig
An AccountComponent implementing the signature scheme for authentication of transactions.
AuthSingleSigAcl
An AccountComponent implementing a procedure-based Access Control List (ACL) using either the EcdsaK256Keccak or Rpo Falcon 512 signature scheme for authentication of transactions.
AuthSingleSigAclConfig
Configuration for AuthSingleSigAcl component.
BasicAuthenticator
Represents a signer for AuthSecretKey keys.
NoAuth
An AccountComponent implementing a no-authentication scheme.
PublicKeyCommitment
Commitment to a public key.

Enums

AuthScheme
Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
AuthSchemeId
Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
AuthSecretKey
Secret keys of the standard AuthSchemes available in the Miden protocol.
PublicKey
Public keys of the standard authentication schemes available in the Miden protocol.
Signature
Represents a signature object ready for native verification.
SigningInputs
Data types on which a signature can be requested.

Constants

ECDSA_K256_KECCAK_SCHEME_ID
RPO_FALCON_SCHEME_ID

Traits

TransactionAuthenticator
Defines an authenticator for transactions.