Re-export the entire miden_client crate so external projects can use a single dependency.
Provides authentication-related types and functionalities for the Miden
network.
Structs
- Auth
Multisig - An
AccountComponentimplementing a multisig based on ECDSA signatures. - Auth
Multisig Config - Configuration for
AuthMultisigcomponent. - Auth
Single Sig - An
AccountComponentimplementing the signature scheme for authentication of transactions. - Auth
Single SigAcl - An
AccountComponentimplementing a procedure-based Access Control List (ACL) using either the EcdsaK256Keccak or Rpo Falcon 512 signature scheme for authentication of transactions. - Auth
Single SigAcl Config - Configuration for
AuthSingleSigAclcomponent. - Basic
Authenticator - Represents a signer for AuthSecretKey keys.
- NoAuth
- An
AccountComponentimplementing a no-authentication scheme. - Public
KeyCommitment - Commitment to a public key.
Enums
- Auth
Scheme - Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
- Auth
Scheme Id - Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
- Auth
Secret Key - Secret keys of the standard
AuthSchemes available in the Miden protocol. - Public
Key - Public keys of the standard authentication schemes available in the Miden protocol.
- Signature
- Represents a signature object ready for native verification.
- Signing
Inputs - Data types on which a signature can be requested.
Constants
Traits
- Transaction
Authenticator - Defines an authenticator for transactions.