Module auth

Module auth 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides authentication-related types and functionalities for the Miden network.

Structs

AuthEcdsaK256Keccak
An AccountComponent implementing the ECDSA K256 Keccak signature scheme for authentication of transactions.
AuthFalcon512Rpo
An AccountComponent implementing the Falcon512Rpo signature scheme for authentication of transactions.
BasicAuthenticator
Represents a signer for AuthSecretKey keys.
NoAuth
An AccountComponent implementing a no-authentication scheme.
PublicKeyCommitment
Commitment to a public key.

Enums

AuthScheme
Defines authentication schemes available to standard and faucet accounts.
AuthSchemeId
Defines standard authentication schemes (i.e., signature schemes) available in the Miden protocol.
AuthSecretKey
Secret keys of the standard AuthSchemes available in the Miden protocol.
PublicKey
Public keys of the standard authentication schemes available in the Miden protocol.
Signature
Represents a signature object ready for native verification.
SigningInputs
Data types on which a signature can be requested.

Constants

ECDSA_K256_KECCAK_SCHEME_ID
RPO_FALCON_SCHEME_ID

Traits

TransactionAuthenticator
Defines an authenticator for transactions.