Module block

Module block 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides types for working with blocks within the Miden network.

Structs

BlockHeader
The header of a block. It contains metadata about the block, commitments to the current state of the chain and the hash of the proof that attests to the integrity of the chain.
BlockNumber
A convenience wrapper around a u32 representing the number of a block.