Re-export the entire miden_client crate so external projects can use a single dependency.
Structs
- Client
Builder - A builder for constructing a Miden client.
- Note
Transport Config - Configuration for lazy note transport initialization.
- Remote
Transaction Prover - A
RemoteTransactionProveris a transaction prover that sends witness data to a remote gRPC server and receives a proven transaction.
Enums
- Store
Builder - Allows the
ClientBuilderto accept either an already built store instance or a factory for deferring the store instantiation.
Constants
- DEVNET_
PROVER_ ENDPOINT - Default remote prover endpoint for devnet.
- NOTE_
TRANSPORT_ DEFAULT_ TIMEOUT_ MS - Default timeout for note transport connections (10 seconds).
- TESTNET_
PROVER_ ENDPOINT - Default remote prover endpoint for testnet.
Traits
- Builder
Authenticator - Marker trait to capture the bounds the builder requires for the authenticator type parameter.
- Store
Factory - Trait for building a store instance.