Module config

Module config 

Structs

CliConfig
CliEndpoint
NoteTransportConfig
Settings for the note transport client.
RpcConfig
Settings for the RPC client.

Enums

Network
Represents the network to which the client connects. It is used to determine the RPC endpoint and network ID for the CLI.

Constants

CLIENT_CONFIG_FILE_NAME
DEFAULT_PACKAGES_DIR
DEFAULT_REMOTE_PROVER_TIMEOUT
KEYSTORE_DIRECTORY
MIDEN_DIR
STORE_FILENAME
TOKEN_SYMBOL_MAP_FILENAME

Functions

get_global_miden_dir
Returns the global miden directory path in the user’s home directory
get_local_miden_dir
Returns the local miden directory path relative to the current working directory