Structs
- CliConfig
- CliEndpoint
- Note
Transport Config - Settings for the note transport client.
- RpcConfig
- Settings for the RPC client.
Enums
- Network
- Represents the network to which the client connects. It is used to determine the RPC endpoint and network ID for the CLI.
Constants
- CLIENT_
CONFIG_ FILE_ NAME - DEFAULT_
PACKAGES_ DIR - DEFAULT_
REMOTE_ PROVER_ TIMEOUT - KEYSTORE_
DIRECTORY - MIDEN_
DIR - STORE_
FILENAME - TOKEN_
SYMBOL_ MAP_ FILENAME
Functions
- get_
global_ miden_ dir - Returns the global miden directory path in the user’s home directory
- get_
local_ miden_ dir - Returns the local miden directory path relative to the current working directory