Module crypto

Module crypto 

Re-export the entire miden_client crate so external projects can use a single dependency. Provides cryptographic types and utilities used within the Miden rollup network. It re-exports commonly used types and random number generators like FeltRng from the miden_standards crate.

Modules

rpo_falcon512

Structs

Blake3Digest
N-bytes output of a blake3 function.
Blake3_160
160-bit output blake3 hasher.
EmptySubtreeRoots
Contains precomputed roots of empty subtrees in a Merkle tree.
Forest
A compact representation of trees in a forest. Used in the Merkle forest (MMR).
InOrderIndex
Index of nodes in a perfectly balanced binary tree based on an in-order tree walk.
LeafIndex
The index of a leaf, at a depth known at compile-time.
MerklePath
A merkle path container, composed of a sequence of nodes of a Merkle tree.
MerkleStore
An in-memory data store for Merkelized data.
MerkleTree
A fully-balanced binary Merkle tree (i.e., a tree where the number of leaves is a power of two).
MmrDelta
Container for the update data of a super::PartialMmr
MmrPeaks
MmrProof
NodeIndex
Address to an arbitrary node in a binary tree using level order form.
PartialMmr
Partially materialized Merkle Mountain Range (MMR), used to efficiently store and update the authentication paths for a subset of the elements in a full MMR.
Rpo256
Implementation of the Rescue Prime Optimized hash function with 256-bit output.
RpoRandomCoin
A simplified version of the SPONGE_PRG reseedable pseudo-random number generator algorithm described in https://eprint.iacr.org/2011/499.pdf.
Smt
Sparse Merkle tree mapping 256-bit keys to 256-bit values. Both keys and values are represented by 4 field elements.
SmtForest
An in-memory data collection of sparse Merkle trees (SMTs).
SmtProof
A proof which can be used to assert membership (or non-membership) of key-value pairs in a super::Smt (Sparse Merkle Tree).
SparseMerklePath
A different representation of MerklePath designed for memory efficiency for Merkle paths with empty nodes.

Enums

MerkleError
SmtLeaf
Represents a leaf node in the Sparse Merkle Tree.

Constants

SMT_DEPTH
The depth of the sparse Merkle tree.

Traits

FeltRng
Pseudo-random element generator.