pub enum SmtLeaf {
Empty(LeafIndex<miden_crypto::::merkle::smt::full::leaf::SmtLeaf::{constant#0}>),
Single((Word, Word)),
Multiple(Vec<(Word, Word)>),
}Expand description
Represents a leaf node in the Sparse Merkle Tree.
A leaf can be empty, hold a single key-value pair, or multiple key-value pairs.
Variants
Empty(LeafIndex<miden_crypto::::merkle::smt::full::leaf::SmtLeaf::{constant#0}>)
An empty leaf at the specified index.
Single((Word, Word))
A leaf containing a single key-value pair.
Multiple(Vec<(Word, Word)>)
A leaf containing multiple key-value pairs.
Implementations
Sourceimpl SmtLeaf
impl SmtLeaf
Sourcepub fn new(
entries: Vec<(Word, Word)>,
leaf_index: LeafIndex<miden_crypto::::merkle::smt::full::leaf::{impl#0}::new::{constant#1}>,
) -> Result<SmtLeaf, SmtLeafError>
pub fn new( entries: Vec<(Word, Word)>, leaf_index: LeafIndex<miden_crypto::::merkle::smt::full::leaf::{impl#0}::new::{constant#1}>, ) -> Result<SmtLeaf, SmtLeafError>
Returns a new leaf with the specified entries
Errors
- Returns an error if 2 keys in
entriesmap to a different leaf index - Returns an error if 1 or more keys in
entriesmap to a leaf index different fromleaf_index
Sourcepub fn new_empty(
leaf_index: LeafIndex<miden_crypto::::merkle::smt::full::leaf::{impl#0}::new_empty::{constant#0}>,
) -> SmtLeaf
pub fn new_empty( leaf_index: LeafIndex<miden_crypto::::merkle::smt::full::leaf::{impl#0}::new_empty::{constant#0}>, ) -> SmtLeaf
Returns a new empty leaf with the specified leaf index
Sourcepub fn new_single(key: Word, value: Word) -> SmtLeaf
pub fn new_single(key: Word, value: Word) -> SmtLeaf
Returns a new single leaf with the specified entry. The leaf index is derived from the entry’s key.
Sourcepub fn new_multiple(entries: Vec<(Word, Word)>) -> Result<SmtLeaf, SmtLeafError>
pub fn new_multiple(entries: Vec<(Word, Word)>) -> Result<SmtLeaf, SmtLeafError>
Returns a new multiple leaf with the specified entries. The leaf index is derived from the entries’ keys.
Errors
- Returns an error if 2 keys in
entriesmap to a different leaf index - Returns an error if the number of entries exceeds
MAX_LEAF_ENTRIES
Sourcepub fn index(
&self,
) -> LeafIndex<miden_crypto::::merkle::smt::full::leaf::{impl#0}::index::{constant#0}>
pub fn index( &self, ) -> LeafIndex<miden_crypto::::merkle::smt::full::leaf::{impl#0}::index::{constant#0}>
Returns the leaf’s index in the super::Smt
Sourcepub fn num_entries(&self) -> usize
pub fn num_entries(&self) -> usize
Returns the number of entries stored in the leaf
Sourcepub fn to_elements(&self) -> Vec<BaseElement>
pub fn to_elements(&self) -> Vec<BaseElement>
Converts a leaf to a list of field elements
pub fn to_entries(&self) -> impl Iterator<Item = (&Word, &Word)>
Sourcepub fn into_elements(self) -> Vec<BaseElement>
pub fn into_elements(self) -> Vec<BaseElement>
Converts a leaf to a list of field elements
Sourcepub fn into_entries(self) -> Vec<(Word, Word)>
pub fn into_entries(self) -> Vec<(Word, Word)>
Converts a leaf the key-value pairs in the leaf