pub struct MmrPeaks { /* private fields */ }Implementations
Sourceimpl MmrPeaks
impl MmrPeaks
Sourcepub fn num_leaves(&self) -> usize
pub fn num_leaves(&self) -> usize
Returns a count of leaves in the underlying MMR.
Sourcepub fn get_peak(&self, peak_idx: usize) -> Result<&Word, MmrError>
pub fn get_peak(&self, peak_idx: usize) -> Result<&Word, MmrError>
Returns the peak by the provided index.
Errors
Returns an error if the provided peak index is greater or equal to the current number of peaks in the Mmr.
Sourcepub fn into_parts(self) -> (Forest, Vec<Word>)
pub fn into_parts(self) -> (Forest, Vec<Word>)
Sourcepub fn hash_peaks(&self) -> Word
pub fn hash_peaks(&self) -> Word
Hashes the peaks.
The procedure will:
- Flatten and pad the peaks to a vector of Felts.
- Hash the vector of Felts.
Sourcepub fn verify(&self, value: Word, opening: MmrProof) -> Result<(), MmrError>
pub fn verify(&self, value: Word, opening: MmrProof) -> Result<(), MmrError>
Verifies the Merkle opening proof.
Errors
Returns an error if:
- provided opening proof is invalid.
- Mmr root value computed using the provided leaf value differs from the actual one.
Sourcepub fn flatten_and_pad_peaks(&self) -> Vec<BaseElement>
pub fn flatten_and_pad_peaks(&self) -> Vec<BaseElement>
Flattens and pads the peaks to make hashing inside of the Miden VM easier.
The procedure will:
- Flatten the vector of Words into a vector of Felts.
- Pad the peaks with ZERO to an even number of words, this removes the need to handle RPO padding.
- Pad the peaks to a minimum length of 16 words, which reduces the constant cost of hashing.