pub struct SmtProof { /* private fields */ }Expand description
A proof which can be used to assert presence (or absence) of key-value pairs
in a super::Smt (Sparse Merkle Tree).
The proof consists of a sparse Merkle path and a leaf, which describes the node located at the base of the path.
Implementations
Sourceimpl SmtProof
impl SmtProof
Sourcepub fn new(
path: SparseMerklePath,
leaf: SmtLeaf,
) -> Result<SmtProof, SmtProofError>
pub fn new( path: SparseMerklePath, leaf: SmtLeaf, ) -> Result<SmtProof, SmtProofError>
Sourcepub fn verify_presence(
&self,
key: &Word,
value: &Word,
root: &Word,
) -> Result<(), SmtProofError>
pub fn verify_presence( &self, key: &Word, value: &Word, root: &Word, ) -> Result<(), SmtProofError>
Verifies that a super::Smt with the specified root contains the provided key-value pair.
Errors
SmtProofError::InvalidKeyForProofif the key maps to a different leaf index than this proof’s leaf.SmtProofError::ConflictingRootsif the computed root doesn’t match the expected root.SmtProofError::ValueMismatchif the value doesn’t match the value in the leaf.
Sourcepub fn verify_unset(&self, key: &Word, root: &Word) -> Result<(), SmtProofError>
pub fn verify_unset(&self, key: &Word, root: &Word) -> Result<(), SmtProofError>
Verifies that a super::Smt with the specified root does not contain any value
for the provided key (i.e., the key is unset).
This is equivalent to calling verify_presence(key, &EMPTY_WORD, root), but makes
the intent clearer.
Errors
SmtProofError::InvalidKeyForProofif the key maps to a different leaf index than this proof’s leaf.SmtProofError::ConflictingRootsif the computed root doesn’t match the expected root.SmtProofError::ValueMismatchif the key has a value in the tree (i.e., is not empty).
Sourcepub fn verify_absence(
&self,
key: &Word,
value: &Word,
root: &Word,
) -> Result<(), SmtProofError>
pub fn verify_absence( &self, key: &Word, value: &Word, root: &Word, ) -> Result<(), SmtProofError>
Verifies that a specific key-value pair is not in the tree.
This succeeds if the key exists with a different value, or if the key is unset.
Errors
SmtProofError::InvalidKeyForProofif the key maps to a different leaf index than this proof’s leaf.SmtProofError::ConflictingRootsif the computed root doesn’t match the expected root.SmtProofError::ValuePresentif the key-value pair exists in the tree.
Sourcepub fn get(&self, key: &Word) -> Option<Word>
pub fn get(&self, key: &Word) -> Option<Word>
Returns the value associated with the specific key according to this proof, or None if this proof does not contain a value for the specified key.
A key-value pair generated by using this method should pass the verify_presence() check.
Sourcepub fn compute_root(&self) -> Word
pub fn compute_root(&self) -> Word
Computes the root of a super::Smt to which this proof resolves.
Sourcepub fn path(&self) -> &SparseMerklePath
pub fn path(&self) -> &SparseMerklePath
Returns the proof’s sparse Merkle path.
Sourcepub fn authenticated_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
pub fn authenticated_nodes(&self) -> impl Iterator<Item = InnerNodeInfo>
Returns an iterator over every inner node of this proof’s merkle path.
Sourcepub fn into_parts(self) -> (SparseMerklePath, SmtLeaf)
pub fn into_parts(self) -> (SparseMerklePath, SmtLeaf)
Consume the proof and returns its parts.