Re-export the entire miden_client crate so external projects can use a single dependency.
Structs
- Note
Transport Config - Configuration for lazy note transport initialization.
- Remote
Transaction Prover - A
RemoteTransactionProveris a transaction prover that sends witness data to a remote gRPC server and receives a proven transaction.
Constants
- DEVNET_
PROVER_ ENDPOINT - Default remote prover endpoint for devnet.
- NOTE_
TRANSPORT_ DEFAULT_ TIMEOUT_ MS - Default timeout for note transport connections (10 seconds).
- TESTNET_
PROVER_ ENDPOINT - Default remote prover endpoint for testnet.