Module keystore

Module keystore 

Re-export the entire miden_client crate so external projects can use a single dependency.

Structs

FilesystemKeyStore
A filesystem-based keystore that stores keys in separate files and provides transaction authentication functionality. The public key is hashed and the result is used as the filename and the contents of the file are the serialized public and secret key.

Enums

KeyStoreError