Modules
- config
- The standardized config notes: notes that carry a management action for the account that consumes them.
- costs
- Benchmarked consumption costs of the standard notes, and helpers turning them into fees.
Structs
- Account
Target Network Note - A wrapper around a
Notethat is guaranteed to target a network account via aNetworkAccountTargetattachment. - Burn
Note - A BURN note: instructs a faucet to burn the asset carried by the note and embedded in its storage.
- FeeSponsorship
Note - A FEE_SPONSORSHIP note: carries the fee for exactly one feature note.
- FeeSponsorship
Note Storage - Canonical storage representation for a FEE_SPONSORSHIP note.
- Mint
Note - A MINT note: instructs a network faucet to mint the asset embedded in its storage.
- Network
Account Target - A
NoteAttachmentfor notes targeted at network accounts. - Note
Sync Hint - Hints used by a client to find a note on chain after importing a note file.
- P2id
Note - A Pay-to-ID (P2ID) note: transfers
assetsfromsenderto thetargetaccount. - P2id
Note Storage - Canonical storage representation for a P2ID note.
- P2ide
Note - Pay-to-ID Extended (P2IDE) note abstraction.
- P2ide
Note Storage - Canonical storage representation for a P2IDE note.
- Pswap
Note - A partially-fillable swap note for decentralized asset exchange.
- Pswap
Note Attachment - Typed attachment carried by both PSWAP output notes, encoded as
[amount, order_id, depth, 0]underPswapNote::PSWAP_ATTACHMENT_SCHEME. - Pswap
Note Storage - Canonical storage representation for a PSWAP note.
- Swap
Note - A SWAP note: offers
offered_assetin exchange forrequested_asset. - Swap
Note Storage - Canonical storage representation for a SWAP note.
- TxFee
Note - A TX_FEE note: the canonical way for a transaction to pay its fee to a batch builder.
Enums
- Mint
Note Storage - Represents the different storage formats for MINT notes.
- Network
Account Target Error - Note
Consumption Status - Describes if a note could be consumed under a specific conditions: target account state and block height.
- Note
Execution Hint - Specifies the conditions under which a note is ready to be consumed. These conditions are meant to be encoded in the note script as well.
- Note
File - A serialized representation of a note.
- NumStorage
Items - The number of storage items a
StandardNoteaccepts. - Standard
Note - The enum holding the types of standard notes provided by
miden-standards. - Standard
Note Attachment - The
NoteAttachmentSchemes of standard note attachments. - Swap
Payback - Mode-specific payback data embedded in
SwapNoteStorage.
Traits
- Network
Note Ext - Convenience helpers for
Notes that may target a network account.
Functions
- payback_
serial_ from_ swap - Returns the P2ID payback serial derived from a SWAP note’s own serial number.