Modules
- costs
- Benchmarked consumption costs of the standard notes, and helpers turning them into fees.
Structs
- Account
Target Network Note - A wrapper around a
Notethat is guaranteed to target a network account via aNetworkAccountTargetattachment. - Allowlist
Config Note - An AllowlistConfig note: triggers an
AllowlistManageradmin action on the account that consumes it. - Blocklist
Config Note - A BlocklistConfig note: triggers a
BlocklistManageradmin action on the account that consumes it. - Burn
Note - A BURN note: instructs a faucet to burn the asset carried by the note and embedded in its storage.
- Constant
FeePolicy Config Note - A ConstantFeePolicyConfig note: schedules a fee for a note script root in a
BasicConstantFeePolicy’s fee schedule by calling theConstantFeeManager’sset_note_feeprocedure on the account that consumes it. - Faucet
Metadata Config Note - A FaucetMetadataConfig note: triggers a token metadata admin action on the faucet that consumes it.
- Faucet
Policy Config Note - A FaucetPolicyConfig note: triggers a
TokenPolicyManagerpolicy switch on the faucet that consumes it. - FeeSponsorship
Note - A FEE_SPONSORSHIP note: carries the fee for exactly one feature note.
- FeeSponsorship
Note Storage - Canonical storage representation for a FEE_SPONSORSHIP note.
- MinBurn
Amount Config Note - A MinBurnAmountConfig note: updates the minimum burn amount of a faucet’s
MinBurnAmountburn policy by calling itsset_min_burn_amountprocedure on the faucet that consumes it. - Mint
Note - A MINT note: instructs a network faucet to mint the asset embedded in its storage.
- Network
Account Config Note - A NetworkAccountConfig note: adds or removes a root from a network account’s note-script allowlist, tx-script allowlist, or allowed fee policy roots map.
- Network
Account Target - A
NoteAttachmentfor notes targeted at network accounts. - Note
Sync Hint - Hints used by a client to find a note on chain after importing a note file.
- Owner
Config Note - An OwnerConfig note: triggers an
Ownable2Stepmanagement action on the account that consumes it. - P2id
Note - A Pay-to-ID (P2ID) note: transfers
assetsfromsenderto thetargetaccount. - P2id
Note Storage - Canonical storage representation for a P2ID note.
- P2ide
Note - Pay-to-ID Extended (P2IDE) note abstraction.
- P2ide
Note Storage - Canonical storage representation for a P2IDE note.
- Pause
Config Note - A PauseConfig note: triggers a
PausableManageradmin action on the account that consumes it. - Pswap
Note - A partially-fillable swap note for decentralized asset exchange.
- Pswap
Note Attachment - Typed attachment carried by both PSWAP output notes, encoded as
[amount, order_id, depth, 0]underPswapNote::PSWAP_ATTACHMENT_SCHEME. - Pswap
Note Storage - Canonical storage representation for a PSWAP note.
- Rbac
Config Note - An RbacConfig note: triggers a
RoleBasedAccessControlmanagement action on the account that consumes it. - Swap
Note - A SWAP note: offers
offered_assetin exchange forrequested_asset. - Swap
Note Storage - Canonical storage representation for a SWAP note.
- TxFee
Note - A TX_FEE note: the canonical way for a transaction to pay its fee to a batch builder.
Enums
- Allowlist
Config - A management action of the
AllowlistManagercomponent that anAllowlistConfigNotetriggers on the account that consumes it. - Blocklist
Config - A management action of the
BlocklistManagercomponent that aBlocklistConfigNotetriggers on the account that consumes it. - Faucet
Metadata Config - A token metadata management action that a
FaucetMetadataConfigNotetriggers on the faucet that consumes it. - Faucet
Policy Config - A policy-switch action of the
TokenPolicyManagercomponent that aFaucetPolicyConfigNotetriggers on the faucet that consumes it. - Mint
Note Storage - Represents the different storage formats for MINT notes.
- Network
Account Config - A configuration action of the
AuthNetworkAccountcomponent that aNetworkAccountConfigNotetriggers on the network account that consumes it. - Network
Account Target Error - Note
Consumption Status - Describes if a note could be consumed under a specific conditions: target account state and block height.
- Note
Execution Hint - Specifies the conditions under which a note is ready to be consumed. These conditions are meant to be encoded in the note script as well.
- Note
File - A serialized representation of a note.
- Owner
Config - A management action of the
Ownable2Stepcomponent that anOwnerConfigNotetriggers on the account that consumes it. - Pause
Config - A management action of the
PausableManagercomponent that aPauseConfigNotetriggers on the account that consumes it. - Rbac
Config - A management action of the
RoleBasedAccessControlcomponent that anRbacConfigNotetriggers on the account that consumes it. - Standard
Note - The enum holding the types of standard notes provided by
miden-standards. - Standard
Note Attachment - The
NoteAttachmentSchemes of standard note attachments. - Swap
Payback - Mode-specific payback data embedded in
SwapNoteStorage.
Traits
- Network
Note Ext - Convenience helpers for
Notes that may target a network account.
Functions
- payback_
serial_ from_ swap - Returns the P2ID payback serial derived from a SWAP note’s own serial number.