Module standards

Module standards 

Modules

costs
Benchmarked consumption costs of the standard notes, and helpers turning them into fees.

Structs

AccountTargetNetworkNote
A wrapper around a Note that is guaranteed to target a network account via a NetworkAccountTarget attachment.
AllowlistConfigNote
An AllowlistConfig note: triggers an AllowlistManager admin action on the account that consumes it.
BlocklistConfigNote
A BlocklistConfig note: triggers a BlocklistManager admin action on the account that consumes it.
BurnNote
A BURN note: instructs a faucet to burn the asset carried by the note and embedded in its storage.
ConstantFeePolicyConfigNote
A ConstantFeePolicyConfig note: schedules a fee for a note script root in a BasicConstantFeePolicy’s fee schedule by calling the ConstantFeeManager’s set_note_fee procedure on the account that consumes it.
FaucetMetadataConfigNote
A FaucetMetadataConfig note: triggers a token metadata admin action on the faucet that consumes it.
FaucetPolicyConfigNote
A FaucetPolicyConfig note: triggers a TokenPolicyManager policy switch on the faucet that consumes it.
FeeSponsorshipNote
A FEE_SPONSORSHIP note: carries the fee for exactly one feature note.
FeeSponsorshipNoteStorage
Canonical storage representation for a FEE_SPONSORSHIP note.
MinBurnAmountConfigNote
A MinBurnAmountConfig note: updates the minimum burn amount of a faucet’s MinBurnAmount burn policy by calling its set_min_burn_amount procedure on the faucet that consumes it.
MintNote
A MINT note: instructs a network faucet to mint the asset embedded in its storage.
NetworkAccountConfigNote
A NetworkAccountConfig note: adds or removes a root from a network account’s note-script allowlist, tx-script allowlist, or allowed fee policy roots map.
NetworkAccountTarget
A NoteAttachment for notes targeted at network accounts.
NoteSyncHint
Hints used by a client to find a note on chain after importing a note file.
OwnerConfigNote
An OwnerConfig note: triggers an Ownable2Step management action on the account that consumes it.
P2idNote
A Pay-to-ID (P2ID) note: transfers assets from sender to the target account.
P2idNoteStorage
Canonical storage representation for a P2ID note.
P2ideNote
Pay-to-ID Extended (P2IDE) note abstraction.
P2ideNoteStorage
Canonical storage representation for a P2IDE note.
PauseConfigNote
A PauseConfig note: triggers a PausableManager admin action on the account that consumes it.
PswapNote
A partially-fillable swap note for decentralized asset exchange.
PswapNoteAttachment
Typed attachment carried by both PSWAP output notes, encoded as [amount, order_id, depth, 0] under PswapNote::PSWAP_ATTACHMENT_SCHEME.
PswapNoteStorage
Canonical storage representation for a PSWAP note.
RbacConfigNote
An RbacConfig note: triggers a RoleBasedAccessControl management action on the account that consumes it.
SwapNote
A SWAP note: offers offered_asset in exchange for requested_asset.
SwapNoteStorage
Canonical storage representation for a SWAP note.
TxFeeNote
A TX_FEE note: the canonical way for a transaction to pay its fee to a batch builder.

Enums

AllowlistConfig
A management action of the AllowlistManager component that an AllowlistConfigNote triggers on the account that consumes it.
BlocklistConfig
A management action of the BlocklistManager component that a BlocklistConfigNote triggers on the account that consumes it.
FaucetMetadataConfig
A token metadata management action that a FaucetMetadataConfigNote triggers on the faucet that consumes it.
FaucetPolicyConfig
A policy-switch action of the TokenPolicyManager component that a FaucetPolicyConfigNote triggers on the faucet that consumes it.
MintNoteStorage
Represents the different storage formats for MINT notes.
NetworkAccountConfig
A configuration action of the AuthNetworkAccount component that a NetworkAccountConfigNote triggers on the network account that consumes it.
NetworkAccountTargetError
NoteConsumptionStatus
Describes if a note could be consumed under a specific conditions: target account state and block height.
NoteExecutionHint
Specifies the conditions under which a note is ready to be consumed. These conditions are meant to be encoded in the note script as well.
NoteFile
A serialized representation of a note.
OwnerConfig
A management action of the Ownable2Step component that an OwnerConfigNote triggers on the account that consumes it.
PauseConfig
A management action of the PausableManager component that a PauseConfigNote triggers on the account that consumes it.
RbacConfig
A management action of the RoleBasedAccessControl component that an RbacConfigNote triggers on the account that consumes it.
StandardNote
The enum holding the types of standard notes provided by miden-standards.
StandardNoteAttachment
The NoteAttachmentSchemes of standard note attachments.
SwapPayback
Mode-specific payback data embedded in SwapNoteStorage.

Traits

NetworkNoteExt
Convenience helpers for Notes that may target a network account.

Functions

payback_serial_from_swap
Returns the P2ID payback serial derived from a SWAP note’s own serial number.