Module standards

Module standards 

Structs

AccountTargetNetworkNote
A wrapper around a Note that is guaranteed to target a network account via a NetworkAccountTarget attachment.
BurnNote
A BURN note: instructs a faucet to burn the asset carried by the note.
FaucetPolicyActionNote
A FaucetPolicyAction note: triggers a TokenPolicyManager policy switch on the faucet that consumes it.
MintNote
A MINT note: instructs a network faucet to mint the asset embedded in its storage.
NetworkAccountTarget
A NoteAttachment for notes targeted at network accounts.
NoteSyncHint
Hints used by a client to find a note on chain after importing a note file.
OwnerActionNote
An OwnerAction note: triggers an Ownable2Step management action on the account that consumes it.
P2idNote
A Pay-to-ID (P2ID) note: transfers assets from sender to the target account.
P2idNoteStorage
Canonical storage representation for a P2ID note.
P2ideNote
Pay-to-ID Extended (P2IDE) note abstraction.
P2ideNoteStorage
Canonical storage representation for a P2IDE note.
PauseActionNote
A PauseAction note: triggers a PausableManager admin action on the account that consumes it.
PswapNote
A partially-fillable swap note for decentralized asset exchange.
PswapNoteAttachment
Typed attachment carried by both PSWAP output notes, encoded as [amount, order_id, depth, 0] under PswapNote::PSWAP_ATTACHMENT_SCHEME.
PswapNoteStorage
Canonical storage representation for a PSWAP note.
RbacActionNote
An RbacAction note: triggers a RoleBasedAccessControl management action on the account that consumes it.
SwapNote
TODO: add docs
SwapNoteStorage
Canonical storage representation for a SWAP note.

Enums

FaucetPolicyAction
A policy-switch action of the TokenPolicyManager component that a FaucetPolicyActionNote triggers on the faucet that consumes it.
MintNoteStorage
Represents the different storage formats for MINT notes.
NetworkAccountTargetError
NoteConsumptionStatus
Describes if a note could be consumed under a specific conditions: target account state and block height.
NoteExecutionHint
Specifies the conditions under which a note is ready to be consumed. These conditions are meant to be encoded in the note script as well.
NoteFile
A serialized representation of a note.
OwnerAction
A management action of the Ownable2Step component that an OwnerActionNote triggers on the account that consumes it.
PauseAction
A management action of the PausableManager component that a PauseActionNote triggers on the account that consumes it.
RbacAction
A management action of the RoleBasedAccessControl component that an RbacActionNote triggers on the account that consumes it.
StandardNote
The enum holding the types of standard notes provided by miden-standards.
StandardNoteAttachment
The NoteAttachmentSchemes of standard note attachments.
SwapPayback
Mode-specific payback data embedded in SwapNoteStorage.

Traits

NetworkNoteExt
Convenience helpers for Notes that may target a network account.

Functions

payback_serial_from_swap
Returns the P2ID payback serial derived from a SWAP note’s own serial number.