Module standards

Module standards 

Structs

AccountTargetNetworkNote
A wrapper around a Note that is guaranteed to target a network account via a NetworkAccountTarget attachment.
BurnNote
TODO: add docs
MintNote
TODO: add docs
NetworkAccountTarget
A NoteAttachment for notes targeted at network accounts.
P2idNote
TODO: add docs
P2idNoteStorage
Canonical storage representation for a P2ID note.
P2ideNote
Pay-to-ID Extended (P2IDE) note abstraction.
P2ideNoteStorage
Canonical storage representation for a P2IDE note.
PswapNote
A partially-fillable swap note for decentralized asset exchange.
PswapNoteAttachment
Typed attachment carried by both PSWAP output notes, encoded as [amount, order_id, depth, 0] under PswapNote::PSWAP_ATTACHMENT_SCHEME.
PswapNoteStorage
Canonical storage representation for a PSWAP note.
SwapNote
TODO: add docs
SwapNoteStorage
Canonical storage representation for a SWAP note.

Enums

MintNoteStorage
Represents the different storage formats for MINT notes.
NetworkAccountTargetError
NoteConsumptionStatus
Describes if a note could be consumed under a specific conditions: target account state and block height.
NoteExecutionHint
Specifies the conditions under which a note is ready to be consumed. These conditions are meant to be encoded in the note script as well.
StandardNote
The enum holding the types of standard notes provided by miden-standards.
StandardNoteAttachment
The NoteAttachmentSchemes of standard note attachments.

Traits

NetworkNoteExt
Convenience helpers for Notes that may target a network account.