pub struct NoteScreener<AUTH> { /* private fields */ }Expand description
Provides functionality for testing whether a note is relevant to the client or not.
Here, relevance is based on whether the note is able to be consumed by an account that is
tracked in the provided store. This can be derived in a number of ways, such as looking
at the combination of script root and note inputs. For example, a P2ID note is relevant
for a specific account ID if this ID is its first note input.
Implementations
Sourceimpl<AUTH> NoteScreener<AUTH>where
AUTH: TransactionAuthenticator + Sync,
impl<AUTH> NoteScreener<AUTH>where
AUTH: TransactionAuthenticator + Sync,
pub fn new( store: Arc<dyn Store>, authenticator: Option<Arc<AUTH>>, ) -> NoteScreener<AUTH>
Sourcepub async fn check_relevance(
&self,
note: &Note,
) -> Result<Vec<(AccountId, NoteConsumptionStatus)>, NoteScreenerError>
pub async fn check_relevance( &self, note: &Note, ) -> Result<Vec<(AccountId, NoteConsumptionStatus)>, NoteScreenerError>
Returns a vector of tuples describing the relevance of the provided note to the accounts monitored by this screener.
The relevance is determined by NoteConsumptionChecker::can_consume and is based on
current conditions (for example, it takes the latest block in the client as reference).
Sourcepub async fn check_standard_consumability(
&self,
account: &Account,
note: &Note,
) -> Result<NoteConsumptionStatus, NoteScreenerError>
pub async fn check_standard_consumability( &self, account: &Account, note: &Note, ) -> Result<NoteConsumptionStatus, NoteScreenerError>
Tries to execute a standard consume transaction to check if the note is consumable by the account.