pub struct NoteSyncHint { /* private fields */ }Expand description
Hints used by a client to find a note on chain after importing a note file.
The values in this type are intended to guide note synchronization without requiring an exact
NoteId lookup. A client can sync notes by tag (starting from after_block_num) and get a
set of notes that may contain the expected note. Because a tag does not uniquely identify a note
but rather expresses a use-case, the client does not need to leak a commitment to a specific
note (i.e., its ID) when syncing.
Implementations
Sourceimpl NoteSyncHint
impl NoteSyncHint
Sourcepub fn new(after_block_num: BlockNumber, tag: NoteTag) -> NoteSyncHint
pub fn new(after_block_num: BlockNumber, tag: NoteTag) -> NoteSyncHint
Returns a new NoteSyncHint instantiated from the provided parameters.
Sourcepub fn after_block_num(&self) -> BlockNumber
pub fn after_block_num(&self) -> BlockNumber
Returns the block after which the note is expected to appear on chain.