pub struct SwapNote;Expand description
TODO: add docs
Implementations
Sourceimpl SwapNote
impl SwapNote
Sourcepub const NUM_STORAGE_ITEMS: usize = 16
pub const NUM_STORAGE_ITEMS: usize = 16
Expected number of storage items of the SWAP note.
Sourcepub fn script() -> NoteScript
pub fn script() -> NoteScript
Returns the script of the SWAP note.
Sourcepub fn script_root() -> Word
pub fn script_root() -> Word
Returns the SWAP note script root.
Sourcepub fn create<R>(
sender: AccountId,
offered_asset: Asset,
requested_asset: Asset,
swap_note_type: NoteType,
swap_note_attachment: NoteAttachment,
payback_note_type: NoteType,
payback_note_attachment: NoteAttachment,
rng: &mut R,
) -> Result<(Note, NoteDetails), NoteError>where
R: FeltRng,
pub fn create<R>(
sender: AccountId,
offered_asset: Asset,
requested_asset: Asset,
swap_note_type: NoteType,
swap_note_attachment: NoteAttachment,
payback_note_type: NoteType,
payback_note_attachment: NoteAttachment,
rng: &mut R,
) -> Result<(Note, NoteDetails), NoteError>where
R: FeltRng,
Generates a SWAP note - swap of assets between two accounts - and returns the note as well
as NoteDetails for the payback note.
This script enables a swap of 2 assets between the sender account and any other account
that is willing to consume the note. The consumer will receive the offered_asset and
will create a new P2ID note with sender as target, containing the requested_asset.
Errors
Returns an error if deserialization or compilation of the SWAP script fails.
Sourcepub fn build_tag(
note_type: NoteType,
offered_asset: &Asset,
requested_asset: &Asset,
) -> NoteTag
pub fn build_tag( note_type: NoteType, offered_asset: &Asset, requested_asset: &Asset, ) -> NoteTag
Returns a note tag for a swap note with the specified parameters.
The tag is laid out as follows:
[
note_type (2 bits) | script_root (14 bits)
| offered_asset_faucet_id (8 bits) | requested_asset_faucet_id (8 bits)
]The script root serves as the use case identifier of the SWAP tag.