pub enum NoteFile {
NoteId(NoteId),
NoteDetails {
details: NoteDetails,
after_block_num: BlockNumber,
tag: Option<NoteTag>,
},
NoteWithProof(Note, NoteInclusionProof),
}Expand description
A serialized representation of a note.
Variants
NoteId(NoteId)
The note’s details aren’t known.
NoteDetails
The note may or may not have already been recorded on chain.
The after_block_num specifies the block after which the note is expected to appear on
chain. Though this should be treated as a hint (i.e., there is no guarantee that the note
will appear on chain or that it will in fact appear after the specified block).
An optional tag specifies the tag associated with the note, though this also should be treated as a hint.
NoteWithProof(Note, NoteInclusionProof)
The note has been recorded on chain.
Implementations