Re-export the entire miden_client crate so external projects can use a single dependency.
Stores protocol configurations by their block header commitments.
Structs
- Next
Protocol Config - A protocol upgrade that is scheduled but not yet in effect.
- Protocol
Config - The configuration parameters of the protocol that are expected to change rarely over the lifetime of a chain.
Enums
- Protocol
Config Error - Error returned when constructing an invalid protocol configuration.