Re-export the entire miden_client crate so external projects can use a single dependency.
Structs
- Remote
Transaction Prover - A
RemoteTransactionProveris a transaction prover that sends witness data to a remote gRPC server and receives a proven transaction.
Enums
- Remote
Prover Client Error - Errors that can occur when communicating with a remote prover.