Module note
miden_
client_
cli
0.16.0
Module note
Module Items
Structs
Enums
In miden_
client_
cli::
rpc::
domain
miden_client_cli
::
rpc
::
domain
Module
note
Structs

Committed
Note
Represents a committed note, returned as part of a
SyncNotesResponse
.
Resolved
Sync
Notes
Block
A block’s worth of notes resolved by
NodeRpcClient::sync_notes_with_content
.
Sync
Notes
Block
Represents a single block’s worth of note sync data from the
SyncNotesResponse
.
Synced
Note
Everything resolved about a single note during a notes sync: its identity, metadata, and inclusion proof (always present, from
SyncNotes
), its attachments, and the public note body when it was fetched via
GetNotesById
.
Enums

Fetched
Note
Describes the possible responses from the
GetNotesById
endpoint for a single note.