Module note

Module note 

Structs

CommittedNote
Represents a committed note, returned as part of a SyncNotesResponse.
NoteSyncBlock
Represents a single block’s worth of note sync data from the SyncNotesResponse.

Enums

FetchedNote
Describes the possible responses from the GetNotesById endpoint for a single note.
SyncedNoteDetails
Content resolved for a single note during NodeRpcClient::sync_notes_with_details as response from GetNotesById.