Module note

Module note 

Structs

CommittedNote
Represents a committed note, returned as part of a SyncNotesResponse.
NoteSyncBlock
Represents a single block’s worth of note sync data from the SyncNotesResponse.
NoteSyncInfo
Represents a SyncNotesResponse with fields converted into domain types.
SyncNotesResult
Result of NodeRpcClient::sync_notes_with_details.

Enums

CommittedNoteMetadata
The metadata state of a committed note.
FetchedNote
Describes the possible responses from the GetNotesById endpoint for a single note.