Structs
- Block
Producer Status Info - Represents block producer status info with fields converted into domain types.
- Mempool
Stats Info - Represents mempool stats with fields converted into domain types.
- RpcStatus
Info - Represents node status info with fields converted into domain types.
- Store
Status Info - Represents store status info with fields converted into domain types.