pub enum EndpointError {
AddTransaction(AddTransactionError),
GetBlockHeader(GetBlockHeaderError),
GetBlockByNumber(GetBlockByNumberError),
NoteSync(NoteSyncError),
SyncNullifiers(SyncNullifiersError),
SyncAccountVault(SyncAccountVaultError),
SyncStorageMaps(SyncAccountStorageMapsError),
SyncTransactions(SyncTransactionsError),
GetNotesById(GetNotesByIdError),
GetNoteScriptByRoot(GetNoteScriptByRootError),
CheckNullifiers(CheckNullifiersError),
GetAccount(GetAccountError),
}Expand description
Application-level error returned by the node for a specific RPC endpoint.
Each variant wraps a typed error parsed from the error code in the node’s gRPC response.
Variants
AddTransaction(AddTransactionError)
Error from the SubmitProvenTransaction endpoint
GetBlockHeader(GetBlockHeaderError)
Error from the GetBlockHeaderByNumber endpoint
GetBlockByNumber(GetBlockByNumberError)
Error from the GetBlockByNumber endpoint
NoteSync(NoteSyncError)
Error from the SyncNotes endpoint
SyncNullifiers(SyncNullifiersError)
Error from the SyncNullifiers endpoint
SyncAccountVault(SyncAccountVaultError)
Error from the SyncAccountVault endpoint
SyncStorageMaps(SyncAccountStorageMapsError)
Error from the SyncStorageMaps endpoint
SyncTransactions(SyncTransactionsError)
Error from the SyncTransactions endpoint
GetNotesById(GetNotesByIdError)
Error from the GetNotesById endpoint
GetNoteScriptByRoot(GetNoteScriptByRootError)
Error from the GetNoteScriptByRoot endpoint
CheckNullifiers(CheckNullifiersError)
Error from the CheckNullifiers endpoint
GetAccount(GetAccountError)
Error from the GetAccount endpoint