Enums
- AddTransaction
Error - Check
Nullifiers Error - Endpoint
Error - Application-level error returned by the node for a specific RPC endpoint.
- GetAccount
Error - GetBlock
ByNumber Error - GetBlock
Header Error - GetNote
Script ByRoot Error - GetNotes
ById Error - Note
Sync Error - Sync
Account Storage Maps Error - Sync
Account Vault Error - Sync
Nullifiers Error - Sync
Transactions Error
Functions
- parse_
node_ error - Parses the application-level error code into a typed error for the given endpoint.