GrpcClient

Struct GrpcClient 

pub struct GrpcClient { /* private fields */ }
Client for the Node RPC API using gRPC.

If the tonic feature is enabled, this client will use a tonic::transport::Channel to communicate with the node. In this case the connection will be established lazily when the first request is made. If the web-tonic feature is enabled, this client will use a tonic_web_wasm_client::Client to communicate with the node.

In both cases, the GrpcClient depends on the types inside the generated module, which are generated by the build script and also depend on the target architecture.

Implementations

Source

impl GrpcClient

pub fn new(endpoint: &Endpoint, timeout_ms: u64) -> GrpcClient

Returns a new instance of GrpcClient that’ll do calls to the provided Endpoint with the given timeout in milliseconds.

pub async fn fetch_full_account_proof( &self, account_id: AccountId, ) -> Result<(BlockNumber, AccountProof), RpcError>

Given an AccountId, return the proof for the account.

If the account also has public state, its details will also be retrieved