Re-export the entire miden_client crate so external projects can use a single dependency.
Defines the storage interfaces used by the Miden client.
It provides mechanisms for persisting and retrieving data, such as account states, transaction history, block headers, notes, and MMR nodes.
Overview
The storage module is central to the Miden client’s persistence layer. It defines the
Store trait which abstracts over any concrete storage implementation. The trait exposes
methods to (among others):
- Retrieve and update transactions, notes, and accounts.
- Store and query block headers along with MMR peaks and authentication nodes.
- Manage note tags for synchronizing with the node.
These are all used by the Miden client to provide transaction execution in the correct contexts.
In addition to the main Store trait, the module provides types for filtering queries, such
as TransactionFilter, NoteFilter, StorageFilter to narrow down the set of returned
transactions, account data, or notes. For more advanced usage, see the documentation of
individual methods in the Store trait.
Modules
- input_
note_ states - Contains structures that model all states in which an input note can be.
Structs
- Account
Record - Represents a stored account state along with its status.
- Account
SmtForest - Thin wrapper around
SmtForestfor account vault/storage proofs and updates. - Account
Updates - Contains account changes to apply to the store.
- Input
Note Record - Represents a Note of which the Store can keep track and retrieve.
- Output
Note Record - Represents a Note which was the result of executing some transaction of which the Store can keep track and retrieve.
Enums
- Account
Record Data - Represents types of records retrieved from the store
- Account
Status - Represents the status of an account tracked by the client.
- Account
Storage Filter - Filters for narrowing the storage slots returned by the client’s store.
- Block
Relevance - Expresses metadata about the block header.
- Input
Note State - The possible states of a tracked note.
- Note
Export Type - Variants of
NoteFilethat can be exported from anOutputNoteRecord. - Note
Filter - Filters for narrowing the set of notes returned by the client’s store.
- Note
Record Error - Errors generated from note records.
- Output
Note State - Possible states for a single output note. They describe the note’s state and dictate its lifecycle.
- Partial
Blockchain Filter - Filters for searching specific MMR nodes.
- Store
Error - Errors generated from the store.
- Transaction
Filter - Filters for narrowing the set of transactions returned by the client’s store.