pub struct BlockUpdates { /* private fields */ }Expand description
Contains all the block information that needs to be added in the client’s store after a sync.
Implementations
Sourceimpl BlockUpdates
impl BlockUpdates
Sourcepub fn new(
block_headers: Vec<(BlockHeader, bool, MmrPeaks)>,
new_authentication_nodes: Vec<(InOrderIndex, Word)>,
) -> BlockUpdates
pub fn new( block_headers: Vec<(BlockHeader, bool, MmrPeaks)>, new_authentication_nodes: Vec<(InOrderIndex, Word)>, ) -> BlockUpdates
Creates a new instance of BlockUpdates.
Sourcepub fn insert(
&mut self,
block_header: BlockHeader,
has_client_notes: bool,
peaks: MmrPeaks,
new_authentication_nodes: Vec<(InOrderIndex, Word)>,
)
pub fn insert( &mut self, block_header: BlockHeader, has_client_notes: bool, peaks: MmrPeaks, new_authentication_nodes: Vec<(InOrderIndex, Word)>, )
Adds a new block header and its corresponding data to this BlockUpdates.
Parameters
block_header: The block header to add.has_client_notes: Whether this block contains input notes that the client could use.peaks: The MMR peaks after includingblock_header.new_authentication_nodes: Authentication (MMR) nodes produced while addingblock_headerto the client’s MMR.
Sourcepub fn block_headers(&self) -> &[(BlockHeader, bool, MmrPeaks)]
pub fn block_headers(&self) -> &[(BlockHeader, bool, MmrPeaks)]
Returns the new block headers to be stored, along with a flag indicating whether the block contains notes that are relevant to the client and the MMR peaks for the block.
Sourcepub fn extend_authentication_nodes(&mut self, nodes: Vec<(InOrderIndex, Word)>)
pub fn extend_authentication_nodes(&mut self, nodes: Vec<(InOrderIndex, Word)>)
Adds authentication nodes without an associated block header.
This is used when a synced block is not stored (no relevant notes and not the chain tip)
but the MMR authentication nodes it produced must still be persisted so that the on-disk
state stays consistent with the in-memory PartialMmr.
Sourcepub fn new_authentication_nodes(&self) -> &[(InOrderIndex, Word)]
pub fn new_authentication_nodes(&self) -> &[(InOrderIndex, Word)]
Returns the new authentication nodes that are meant to be stored in order to authenticate block headers.