pub trait ClientFeltRng:
FeltRng
+ Send
+ Sync { }Expand description
Re-export the entire miden_client crate so external projects can use a single dependency.
Marker trait for RNGs that can be shared across threads and used by the client.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".