pub enum OutputNote {
Full(Note),
Partial(PartialNote),
Header(NoteHeader),
}Expand description
The types of note outputs supported by the transaction kernel.
Variants
Implementations
Sourceimpl OutputNote
impl OutputNote
Sourcepub fn assets(&self) -> Option<&NoteAssets>
pub fn assets(&self) -> Option<&NoteAssets>
The assets contained in the note.
Sourcepub fn id(&self) -> NoteId
pub fn id(&self) -> NoteId
Unique note identifier.
This value is both an unique identifier and a commitment to the note.
Sourcepub fn recipient(&self) -> Option<&NoteRecipient>
pub fn recipient(&self) -> Option<&NoteRecipient>
Returns the recipient of the processed Full output note, None if
the note type is not Full.
See crate::note::NoteRecipient for more details.
Sourcepub fn recipient_digest(&self) -> Option<Word>
pub fn recipient_digest(&self) -> Option<Word>
Returns the recipient digest of the processed Full or
Partial output note. Returns None if the note type is
Header.
See crate::note::NoteRecipient for more details.
Sourcepub fn metadata(&self) -> &NoteMetadata
pub fn metadata(&self) -> &NoteMetadata
Note’s metadata.
Sourcepub fn shrink(&self) -> OutputNote
pub fn shrink(&self) -> OutputNote
Erase private note information.
Specifically:
- Full private notes are converted into note headers.
- All partial notes are converted into note headers.
Sourcepub fn header(&self) -> &NoteHeader
pub fn header(&self) -> &NoteHeader
Returns a reference to the NoteHeader of this note.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns a commitment to the note and its metadata.
hash(NOTE_ID || NOTE_METADATA_COMMITMENT)