notes_from_output

Function notes_from_output 

pub fn notes_from_output(
    output_notes: &OutputNotes,
) -> impl Iterator<Item = &Note>
Extracts notes from OutputNotes. Used for:

  • Checking the relevance of notes to save them as input notes.
  • Validate hashes versus expected output notes after a transaction is executed.