pub struct TransactionScript { /* private fields */ }Expand description
Transaction script.
A transaction script is a program that is executed in a transaction after all input notes have been executed.
The TransactionScript object is composed of an executable program defined by a MastForest and an associated entrypoint.
Implementations
Sourceimpl TransactionScript
impl TransactionScript
Sourcepub fn new(code: Program) -> TransactionScript
pub fn new(code: Program) -> TransactionScript
Returns a new TransactionScript instantiated with the provided code.
Sourcepub fn from_parts(
mast: Arc<MastForest>,
entrypoint: MastNodeId,
) -> TransactionScript
pub fn from_parts( mast: Arc<MastForest>, entrypoint: MastNodeId, ) -> TransactionScript
Returns a new TransactionScript instantiated from the provided MAST forest and entrypoint.
Panics
Panics if the specified entrypoint is not in the provided MAST forest.
Sourcepub fn mast(&self) -> Arc<MastForest>
pub fn mast(&self) -> Arc<MastForest>
Returns a reference to the MastForest backing this transaction script.