Re-export the entire miden_client crate so external projects can use a single dependency.
Provides types for working with the virtual machine within the Miden network.
Structs
- Advice
Inputs - Inputs container to initialize advice provider for the execution of Miden VM programs.
- Advice
Map - Defines a set of non-deterministic (advice) inputs which the VM can access by their keys.
- Attribute
Set - An AttributeSet provides storage and access to all of the attributes attached to a Miden Assembly item, e.g. procedure definition.
- Package
- A package containing a Program/Library, and a manifest (exports and dependencies).
- Package
Manifest - The manifest of a package, containing the set of package dependencies (libraries or packages) and exported items (procedures, constants, types), if known.
- Procedure
Export - A procedure exported by a package, along with its digest, signature, and attributes.
- Program
- An executable program for Miden VM.
- Qualified
Procedure Name - Represents a qualified procedure name, e.g.
std::math::u64::add, parsed into it’s constituent Path and ProcedureName components. - Section
- Section
Id - A unique identifier for optional sections of the Miden package format
Enums
- Mast
Artifact - The artifact produced by lowering a program or library to a Merkelized Abstract Syntax Tree
- Package
Export - Represents a named item exported from a package.
- Package
Kind - The kind of project that produced this package.