pub enum MastArtifact {
Executable(Arc<Program>),
Library(Arc<Library>),
}Expand description
The artifact produced by lowering a program or library to a Merkelized Abstract Syntax Tree
This type is used in compilation pipelines to abstract over the type of output requested.
Variants
Executable(Arc<Program>)
A MAST artifact which can be executed by the VM directly
Library(Arc<Library>)
A MAST artifact which can be used as a dependency by a Program
Implementations
Sourceimpl MastArtifact
impl MastArtifact
Sourcepub fn unwrap_program(self) -> Arc<Program>
pub fn unwrap_program(self) -> Arc<Program>
Sourcepub fn unwrap_library(self) -> Arc<Library>
pub fn unwrap_library(self) -> Arc<Library>
Sourcepub fn mast_forest(&self) -> &MastForest
pub fn mast_forest(&self) -> &MastForest
Get the underlying MastForest for this artifact